@@ -1,5 +1,5 @@
 <?php
-/* $Id: afrikaans-utf-8.inc.php,v 2.93 2005/10/30 10:03:47 nijel Exp $ */
+/* $Id: afrikaans-utf-8.inc.php,v 2.115.2.3 2006/03/23 17:42:09 lem9 Exp $ */
 
 /*
      translated by Andreas Pauley <pauley@buitegroep.org.za>
@@ -196,9 +196,7 @@ $strModifyIndexTopic = 'Verander \'n indeks';
 $strMoveTable = 'Skuif tabel na (databasis<b>.</b>tabel):';
 $strMoveTableOK = 'Tabel %s is geskuif na %s.';
 $strMySQLCharset = 'MySQL Karakterstel';
-$strMySQLReloaded = 'MySQL is herlaai.';
 $strMySQLSaid = 'MySQL het gepraat: ';
-$strMySQLServerProcess = 'MySQL %pma_s1% hardloop op %pma_s2% as %pma_s3%';
 $strMySQLShowProcess = 'Wys prosesse';
 $strMySQLShowStatus = 'Wys MySQL in-proses informasie';
 $strMySQLShowVars = 'Wys MySQL stelsel veranderlikes';
@@ -265,7 +263,6 @@ $strRecords = 'Rekords';
 $strReferentialIntegrity = 'Toets referential integrity:';
 $strRelationNotWorking = 'Die addisionele funksies om met geskakelde tabelle te werk is ge deaktiveer. Om uit te vind hoekom kliek %shier%s.';
 $strRelationView = 'Relasie uitsig';
-$strReloadFailed = 'MySQL herlaai het misluk.';
 $strReloadMySQL = 'Herlaai MySQL';
 $strRenameTable = 'Hernoem tabel na';
 $strRenameTableOK = 'Tabel %s is vernoem na %s';
@@ -502,7 +499,6 @@ $strAddedColumnComment = 'Added comment for column';  //to translate
 $strWritingCommentNotPossible = 'Writing of comment not possible';  //to translate
 $strAddedColumnRelation = 'Added relation for column';  //to translate
 $strWritingRelationNotPossible = 'Writing of relation not possible';  //to translate
-$strImportFinished = 'Import finished';  //to translate
 $strFileCouldNotBeRead = 'File could not be read';  //to translate
 $strIgnoringFile = 'Ignoring file %s';  //to translate
 $strThisNotDirectory = 'This was not a directory';  //to translate
@@ -525,7 +521,6 @@ $strDatabasesStatsHeavyTraffic = 'Note: Enabling the Database statistics here mi
 $strDatabasesStatsDisable = 'Disable Statistics';  //to translate
 $strDatabasesStatsEnable = 'Enable Statistics';  //to translate
 $strJumpToDB = 'Jump to database &quot;%s&quot;.';  //to translate
-$strDropSelectedDatabases = 'Drop Selected Databases';  //to translate
 $strNoDatabasesSelected = 'No databases selected.';  //to translate
 $strDatabasesDropped = '%s databases have been dropped successfully.';  //to translate
 $strGlobal = 'global';  //to translate
@@ -572,7 +567,6 @@ $strAutomaticLayout = 'Automatic layout';  //to translate
 $strDelOld = 'The current Page has References to Tables that no longer exist. Would you like to delete those References?';  //to translate
 $strFileNameTemplate = 'File name template';//to translate
 $strFileNameTemplateRemember = 'remember template';//to translate
-$strFileNameTemplateHelp = 'Use __DB__ for database name, __TABLE__ for table name and %sany strftime%s options for time specification, extension will be automagically added. Any other text will be preserved.';//to translate
 $strTransformation_text_plain__dateformat = 'Takes a TIME, TIMESTAMP or DATETIME field and formats it using your local dateformat. First option is the offset (in hours) which will be added to the timestamp (Default: 0). Second option is a different dateformat according to the parameters available for PHPs strftime().';//to translate
 $strTransformation_text_plain__substr = 'Only shows part of a string. First option is an offset to define where the output of your text starts (Default 0). Second option is an offset how much text is returned. If empty, returns all the remaining text. The third option defines which chars will be appended to the output when a substring is returned (Default: ...) .';//to translate
 $strTransformation_text_plain__external = 'LINUX ONLY: Launches an external application and feeds the fielddata via standard input. Returns standard output of the application. Default is Tidy, to pretty print HTML code. For security reasons, you have to manually edit the file libraries/transformations/text_plain__external.inc.php and insert the tools you allow to be run. The first option is then the number of the program you want to use and the second option are the parameters for the program. The third parameter, if set to 1 will convert the output using htmlspecialchars() (Default is 1). A fourth parameter, if set to 1 will put a NOWRAP to the content cell so that the whole output will be shown without reformatting (Default 1)';//to translate
@@ -814,7 +808,6 @@ $strImportFormat = 'Format of imported file';  //to translate
 $strFileToImport = 'File to import';  //to translate
 $strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
 $strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
-$strEnclosingOptional = 'Enclosing of fields is optional';  //to translate
 $strCSVImportOptions = 'CSV options';  //to translate
 $strPartialImport = 'Partial import';  //to translate
 $strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
@@ -826,7 +819,6 @@ $strNothingToImport = 'You didn\'t enter any data to import!';  //to translate
 $strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
 $strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
 $strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
-$strInvalidCSVInput = 'Invalid CSV input, could not parse!';  //to translate
 $strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
 $strErrorInZipFile = 'Error in ZIP archive:';  //to translate
 $strFlushQueryCache = 'Flush query cache';  //to translate
@@ -967,4 +959,34 @@ $strBookmarkCreated = 'Bookmark %s created';  //to translate
 $strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
 $strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
 $strEsperanto = 'Esperanto';  //to translate
+$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate
+$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
+$strFileNameTemplateDescriptionTable = 'table name';  //to translate
+$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
+$strFileNameTemplateDescriptionServer = 'server name';  //to translate
+$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
+$strProtocolVersion = 'Protocol version';  //to translate
+$strMysqlClientVersion = 'MySQL client version';  //to translate
+$strUsedPhpExtensions = 'Used PHP extensions';  //to translate
+$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
+$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
+$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
+$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
+$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
+$strPDF = 'PDF';  //to translate
+$strPDFOptions = 'PDF options';  //to translate
+$strPDFReportTitle = 'Report title';  //to translate
+$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
+$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
+$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
+$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
+$strThemeNotFound = 'Theme %s not found!';  //to translate
+$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
+$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
+$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
+$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
+$strSQLImportOptions = 'SQL options';  //to translate
+$strBrowseDistinctValues = 'Browse distinct values';  //to translate
+$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
+$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
 ?>
