@@ -1,5 +1,5 @@
 <?php
-/* $Id: belarusian_cyrillic-windows-1251.inc.php,v 1.2 2005/06/12 10:09:56 swix Exp $ */
+/* $Id: belarusian_cyrillic-windows-1251.inc.php,v 1.49.2.3 2006/03/23 17:42:10 lem9 Exp $ */
 
 /**
  *     Translated by:
@@ -23,17 +23,19 @@ $month = array('', '', '', '', '', '', '˳', '', '', '', '˳', '');
 $datefmt = '%d %B %Y, %H:%M';
 $timespanfmt = '%s , %s , %s   %s ';
 
-$strAPrimaryKey = '     %s';
 $strAbortedClients = '';
 $strAbsolutePathToDocSqlDir = ' ,     -   docSQL';
-$strAccessDenied = '  ';
+$strAccessDeniedCreateConfig = ',    ,     .   ,   %1$s %2$s.';
 $strAccessDeniedExplanation = 'phpMyAdmin     MySQL,   볢 .   ,     config.inc.php  ,    ,    MySQL-.';
+$strAccessDenied = '  ';
 $strAction = '';
 $strAddAutoIncrement = '  AUTO_INCREMENT';
 $strAddConstraints = ' ';
 $strAddDeleteColumn = '/  ';
 $strAddDeleteRow = '/  ';
 $strAddDropDatabase = ' DROP DATABASE';
+$strAddedColumnComment = '   ';
+$strAddedColumnRelation = '   ';
 $strAddFields = '  ';
 $strAddHeaderComment = '     (\\n  )';
 $strAddIfNotExists = ' IF NOT EXISTS';
@@ -45,8 +47,6 @@ $strAddSearchConditions = '   (   "where"):';
 $strAddToIndex = '   &nbsp;%s&nbsp;()';
 $strAddUser = '  ';
 $strAddUserMessage = '   .';
-$strAddedColumnComment = '   ';
-$strAddedColumnRelation = '   ';
 $strAdministration = '';
 $strAffectedRows = ' :';
 $strAfter = ' %s';
@@ -55,15 +55,18 @@ $strAfterInsertNewInsert = '   ';
 $strAfterInsertNext = '  ';
 $strAfterInsertSame = '   ';
 $strAll = '';
+$strAllowInterrupt = '    ,   ,    .        , ,    .';
 $strAllTableSameWidth = '    ?';
 $strAlterOrderBy = '  ';
-$strAnIndex = '    %s';
 $strAnalyzeTable = ' ';
 $strAnd = '';
+$strAndThen = ' ';
+$strAnIndex = '    %s';
 $strAny = '';
 $strAnyHost = ' ';
 $strAnyUser = ' ';
 $strApproximateCount = '  . . FAQ 3.11';
+$strAPrimaryKey = '     %s';
 $strArabic = '';
 $strArmenian = '';
 $strAscending = '';
@@ -77,26 +80,28 @@ $strBack = '';
 $strBaltic = '';
 $strBeginCut = 'BEGIN CUT';
 $strBeginRaw = 'BEGIN RAW';
+$strBinary = '';
+$strBinaryDoNotEdit = '    ';
+$strBinaryLog = ' ';
 $strBinLogEventType = ' ';
 $strBinLogInfo = '';
 $strBinLogName = ' ';
 $strBinLogOriginalPosition = ' ';
 $strBinLogPosition = '';
 $strBinLogServerId = 'ID ';
-$strBinary = '';
-$strBinaryDoNotEdit = '    ';
-$strBinaryLog = ' ';
 $strBookmarkAllUsers = '      ';
+$strBookmarkCreated = ' %s ';
 $strBookmarkDeleted = '  .';
 $strBookmarkLabel = '';
-$strBookmarkOptions = ' ';
 $strBookmarkQuery = ' SQL-';
+$strBookmarkReplace = '      ';
 $strBookmarkThis = '  SQL-  ';
 $strBookmarkView = ' ';
-$strBrowse = '';
+$strBrowseDistinctValues = '  ';
 $strBrowseForeignValues = '  ';
-$strBufferPool = ' ';
+$strBrowse = '';
 $strBufferPoolActivity = '  ';
+$strBufferPool = ' ';
 $strBufferPoolUsage = '  ';
 $strBufferReadMisses = ' ';
 $strBufferReadMissesInPercent = '   %';
@@ -107,31 +112,30 @@ $strBusyPages = ' ';
 $strBzError = 'phpMyAdmin     -    Bz2    PHP.      <code>$cfg[\'BZipDump\']</code>     phpMyAdmin  <code>FALSE</code>.     Bz2-,     PHP.   PHP bug report %s    .';
 $strBzip = '  bzip';
 
-$strCSVOptions = ' CSV';
 $strCalendar = '';
+$strCanNotLoadImportPlugins = '   ,  ,  븢!';
 $strCannotLogin = '    MySQL';
 $strCantLoad = '   %s;<br /> ,   PHP';
 $strCantLoadRecodeIconv = '   iconv   recode,    .  PHP           phpMyAdmin.';
 $strCantRenameIdxToPrimary = '    PRIMARY!';
 $strCantUseRecodeIconv = '    iconv,  libiconvr,  recode_string   ,   ,   .    PHP.';
 $strCardinality = ' ';
-$strCarriage = '  : \\r';
 $strCaseInsensitive = '  ';
 $strCaseSensitive = '  ';
 $strCentralEuropean = '';
-$strChange = '';
-$strChangeCopyMode = '        ...';
 $strChangeCopyModeCopy = '...  .';
 $strChangeCopyModeDeleteAndReload = ' ...         .';
 $strChangeCopyModeJustDelete = ' ...     .';
+$strChangeCopyMode = '        ...';
 $strChangeCopyModeRevoke = ' ...         .';
 $strChangeCopyUser = '   /  ';
+$strChange = '';
 $strChangeDisplay = '   ';
 $strChangePassword = ' ';
 $strCharset = '';
 $strCharsetOfFile = ' :';
-$strCharsets = '';
 $strCharsetsAndCollations = '  ';
+$strCharsets = '';
 $strCheckAll = ' ';
 $strCheckOverhead = ' ,   ';
 $strCheckPrivs = ' ';
@@ -148,6 +152,8 @@ $strCommentsForTable = '  ';
 $strCompatibleHashing = '  MySQL&nbsp;4.0';
 $strCompleteInserts = ' ';
 $strCompression = '';
+$strCompressionWillBeDetected = '       : %s';
+$strConfigDefaultFileError = '     : "%1$s"';
 $strConfigFileError = 'phpMyAdmin     !<br />    ,  PHP        PHP    .<br /> ,    ,  ,  ,    PHP  .   ,       .<br />    , ,  .';
 $strConfigureTableCoord = ' ,     %s';
 $strConnectionError = ' :  .';
@@ -156,25 +162,45 @@ $strConstraintsForDumped = '   ';
 $strConstraintsForTable = '  ';
 $strCookiesRequired = 'Cookies      .';
 $strCopyDatabaseOK = '  %s    %s';
+$strCopy = '';
 $strCopyTable = '   ( <b>.</b>):';
 $strCopyTableOK = ' %s    %s.';
 $strCopyTableSameNames = '     !';
 $strCouldNotKill = 'phpMyAdmin     %s. ,   .';
-$strCreate = '';
 $strCreateDatabaseBeforeCopying = ' CREATE DATABASE  ';
 $strCreateIndex = '  &nbsp;%s&nbsp;';
 $strCreateIndexTopic = '  ';
 $strCreateNewDatabase = '   ';
 $strCreateNewTable = '     %s';
+$strCreate = '';
 $strCreatePage = '  ';
 $strCreatePdfFeat = ' PDF-';
 $strCreationDates = '// ';
 $strCriteria = '';
 $strCroatian = '';
+$strCSV = 'CSV';
+$strCSVImportOptions = ' CSV';
+$strCSVOptions = ' CSV';
 $strCyrillic = 'ʳ';
-$strCzech = '';
 $strCzechSlovak = '';
+$strCzech = '';
 
+$strDanish = '';
+$strData = '';
+$strDatabase = ' ';
+$strDatabaseEmpty = '    !';
+$strDatabaseExportOptions = '   ';
+$strDatabaseHasBeenDropped = '  %s  .';
+$strDatabaseNoTable = '     !';
+$strDatabases = ' ';
+$strDatabasesDropped = '%s     .';
+$strDatabasesStatsDisable = ' ';
+$strDatabasesStatsEnable = ' ';
+$strDatabasesStatsHeavyTraffic = ':           -   MySQL.';
+$strDatabasesStats = '  ';
+$strDataDict = ' ';
+$strDataOnly = ' ';
+$strDataPages = '  ';
 $strDBComment = '   : ';
 $strDBCopy = '   ';
 $strDBGContext = '';
@@ -186,77 +212,63 @@ $strDBGMinTimeMs = '̳ , ';
 $strDBGModule = '';
 $strDBGTimePerHitMs = '/, ';
 $strDBGTotalTimeMs = ' , ';
-$strDBRename = '   ';
-$strDanish = '';
-$strData = '';
-$strDataDict = ' ';
-$strDataOnly = ' ';
-$strDataPages = '  ';
-$strDatabase = ' ';
-$strDatabaseEmpty = '    !';
-$strDatabaseExportOptions = '   ';
-$strDatabaseHasBeenDropped = '  %s  .';
-$strDatabaseNoTable = '     !';
-$strDatabases = ' ';
-$strDatabasesDropped = '%s     .';
-$strDatabasesStats = '  ';
-$strDatabasesStatsDisable = ' ';
-$strDatabasesStatsEnable = ' ';
-$strDatabasesStatsHeavyTraffic = ':           -   MySQL.';
 $strDbPrivileges = '   ';
+$strDBRename = '   ';
 $strDbSpecific = '   ';
-$strDefault = ' ';
 $strDefaultEngine = '%s         MySQL-.';
+$strDefault = ' ';
 $strDefaultValueHelp = '   ,  ,   ,      ,  : a';
 $strDefragment = ' ';
-$strDelOld = '     ,    . ֳ     ?';
 $strDelayedInserts = '  ';
-$strDelete = '';
 $strDeleteAndFlush = '     .';
 $strDeleteAndFlushDescr = '  ,       .';
+$strDelete = '';
 $strDeleted = '  ';
 $strDeletedRows = ' :';
+$strDeleteNoUsersSelected = '    !';
 $strDeleting = ' %s';
+$strDelOld = '     ,    . ֳ     ?';
 $strDescending = '';
 $strDescription = '';
 $strDictionary = '';
 $strDirtyPages = ' ';
-$strDisableForeignChecks = '   ';
 $strDisabled = '';
+$strDisableForeignChecks = '   ';
 $strDisplayFeat = ' ';
 $strDisplayOrder = ' :';
 $strDisplayPDF = ' PDF-';
 $strDoAQuery = ' "  " ( : "%")';
-$strDoYouReally = 'ֳ    ';
 $strDocu = '';
+$strDoYouReally = 'ֳ    ';
 $strDrop = '';
 $strDropDatabaseStrongWarning = '  ˲   !';
-$strDropSelectedDatabases = '   ';
 $strDropUsersDb = '  ,        .';
+$strDumpingData = '  ';
 $strDumpSaved = '    %s.';
 $strDumpXRows = ' %s ,   %s.';
-$strDumpingData = '  ';
 $strDynamic = '';
 
-$strEdit = '';
 $strEditPDFPages = ' PDF-';
 $strEditPrivileges = ' ';
+$strEdit = '';
 $strEffective = '';
 $strEmpty = '';
 $strEmptyResultSet = 'MySQL    (   ).';
 $strEnabled = '';
 $strEncloseInTransaction = '   ';
-$strEnd = '';
 $strEndCut = 'END CUT';
+$strEnd = '';
 $strEndRaw = 'END RAW';
 $strEngineAvailable = '%s    MySQL-.';
 $strEngineDisabled = '%s     MySQL-.';
-$strEngineUnsupported = '  MySQL      %s.';
 $strEngines = '';
+$strEngineUnsupported = '  MySQL      %s.';
 $strEnglish = '';
 $strEnglishPrivileges = ' :   MySQL  - ';
 $strError = '';
+$strErrorInZipFile = '  ZIP-:';
 $strEscapeWildcards = '  _  %     \    ';
+$strEsperanto = '';
 $strEstonian = '';
 $strExcelEdition = ' Excel';
 $strExcelOptions = ' Excel';
@@ -267,30 +279,38 @@ $strExtendedInserts = ' ';
 $strExtra = '';
 
 $strFailedAttempts = ' ';
-$strField = '';
 $strFieldHasBeenDropped = ' %s  ';
-$strFields = '';
+$strField = '';
 $strFieldsEmpty = '    븢! ';
 $strFieldsEnclosedBy = '  ';
 $strFieldsEscapedBy = ' ';
+$strFields = '';
 $strFieldsTerminatedBy = ' ';
 $strFileAlreadyExists = ' %s    ,       .';
 $strFileCouldNotBeRead = '  ';
+$strFileNameTemplateDescription = '     %1$sstrftime%2$s,      .  ,    : %3$s.     .';
+$strFileNameTemplateDescriptionDatabase = '  ';
+$strFileNameTemplateDescriptionServer = ' ';
+$strFileNameTemplateDescriptionTable = ' ';
 $strFileNameTemplate = '  ';
-$strFileNameTemplateHelp = ' __DB__    , __TABLE__     %s strftime%s     ,    .     .';
 $strFileNameTemplateRemember = ' ';
+$strFileToImport = ' ';
 $strFixed = '';
 $strFlushPrivilegesNote = ': phpMyAdmin        MySQL.       ,   ,     .      %s %s  ,   .';
+$strFlushQueryCache = '  ';
 $strFlushTable = '   ("FLUSH")';
-$strFormEmpty = '    !';
+$strFlushTables = ' ()  ';
 $strFormat = '';
+$strFormEmpty = '    !';
 $strFreePages = ' ';
 $strFullText = ' ';
 $strFunction = '';
 
 $strGenBy = '';
-$strGenTime = ' ';
 $strGeneralRelationFeat = '  ';
+$strGenerate = '';
+$strGeneratePassword = ' ';
+$strGenTime = ' ';
 $strGeorgian = '';
 $strGerman = '';
 $strGlobal = '';
@@ -301,10 +321,7 @@ $strGrantOption = 'Grant';
 $strGreek = '';
 $strGzip = '  gzip';
 
-$strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = ' Microsoft Excel 2000';
-$strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = ' Microsoft Word 2000';
+$strHandler = '';
 $strHasBeenAltered = ' .';
 $strHasBeenCreated = ' .';
 $strHaveToShow = '       ';
@@ -312,22 +329,28 @@ $strHebrew = '';
 $strHexForBinary = '     븢';
 $strHome = ' ';
 $strHomepageOfficial = '  phpMyAdmin';
-$strHost = '';
 $strHostEmpty = '  !';
+$strHost = '';
+$strHTMLExcel = 'Microsoft Excel 2000';
+$strHTMLExcelOptions = ' Microsoft Excel 2000';
+$strHTMLWord = 'Microsoft Word 2000';
+$strHTMLWordOptions = ' Microsoft Word 2000';
 $strHungarian = '';
 
 $strIcelandic = '';
 $strId = 'ID';
 $strIdxFulltext = '';
-$strIfYouWish = '       ,     븢.';
 $strIgnore = '';
+$strIgnoreDuplicates = ' ,  ';
 $strIgnoreInserts = '  ';
 $strIgnoringFile = ' %s ';
+$strImport = '';
 $strImportDocSQL = '  docSQL';
 $strImportFiles = ' ';
-$strImportFinished = ' ';
-$strInUse = '';
+$strImportFormat = '  ';
+$strImportSuccessfullyFinished = '  ,  %d .';
 $strIndex = '';
+$strIndexes = '';
 $strIndexHasBeenDropped = ' %s  ';
 $strIndexName = ' :';
 $strIndexType = ' :';
@@ -335,117 +358,127 @@ $strIndexWarningMultiple = '   %s      `%s`';
 $strIndexWarningPrimary = '  PRIMARY  INDEX      `%s`';
 $strIndexWarningTable = '     `%s`';
 $strIndexWarningUnique = '  UNIQUE  INDEX      `%s`';
-$strIndexes = '';
 $strInnoDBAutoextendIncrement = ' ';
 $strInnoDBAutoextendIncrementDesc = '        ,   .';
-$strInnoDBBufferPoolSize = '  ';
 $strInnoDBBufferPoolSizeDesc = '   ,  InnoDB       .';
+$strInnoDBBufferPoolSize = '  ';
 $strInnoDBDataFilePath = ' ';
-$strInnoDBDataHomeDir = '  ';
 $strInnoDBDataHomeDirDesc = '        InnoDB.';
+$strInnoDBDataHomeDir = '  ';
 $strInnoDBPages = '';
 $strInnodbStat = ' InnoDB';
 $strInsecureMySQL = '     ( root  ),     MySQL  .   MySQL            ,          .';
-$strInsert = '';
 $strInsertAsNewRow = '   ';
-$strInsertBookmarkTitle = ' ,   ';
-$strInsertNewRow = '  ';
-$strInsertTextfiles = '      ';
 $strInsertedRowId = 'Id  :';
 $strInsertedRows = ' :';
-$strInstructions = '';
+$strInsertNewRow = '  ';
+$strInsert = '';
 $strInternalNotNecessary = '*     ,      InnoDB.';
 $strInternalRelations = ' ';
+$strInUse = '';
+$strInvalidAuthMethod = '     :';
+$strInvalidColumn = '   (%s)!';
+$strInvalidColumnCount = '      .';
+$strInvalidCSVFieldCount = '  븢  CSV-   %d.';
+$strInvalidCSVFormat = '  CSV-   %d.';
+$strInvalidCSVParameter = '      CSV: %s';
+$strInvalidFieldAddCount = '    .';
+$strInvalidFieldCount = '     .';
+$strInvalidLDIImport = '     !';
+$strInvalidRowNumber = '%d     .';
+$strInvalidServerHostname = '     %1$s.  ,  .';
+$strInvalidServerIndex = '  : "%s"';
 
 $strJapanese = '';
+$strJoins = '\'';
 $strJumpToDB = '    &quot;%s&quot;.';
-$strJustDelete = '     .';
 $strJustDeleteDescr = '&quot;&quot;          ,     .';
+$strJustDelete = '     .';
 
 $strKeepPass = '  ';
+$strKeyCache = ' ';
 $strKeyname = ' ';
 $strKill = '';
 $strKorean = '';
 
-$strLaTeX = 'LaTeX';
-$strLaTeXOptions = ' LaTeX';
 $strLandscape = '';
+$strLanguageFileNotFound = '  "%1$s"  .';
+$strLanguageUnknown = ' : %1$s.';
 $strLatchedPages = 'Գ ';
 $strLatexCaption = ' ';
 $strLatexContent = '  __TABLE__';
-$strLatexContinued = '()';
 $strLatexContinuedCaption = '  ';
+$strLatexContinued = '()';
 $strLatexIncludeCaption = '  ';
 $strLatexLabel = ' ';
+$strLaTeX = 'LaTeX';
+$strLaTeXOptions = ' LaTeX';
 $strLatexStructure = '  __TABLE__';
 $strLatvian = '';
+$strLDI = 'CSV   LOAD DATA';
+$strLDIImportOptions = ' CSV-,  LOAD DATA';
+$strLDILocal = '   LOCAL';
 $strLengthSet = '/*';
 $strLimitNumRows = '   ';
-$strLineFeed = '  : \\n';
 $strLinesTerminatedBy = ' ';
 $strLinkNotFound = '  ';
 $strLinksTo = ' ';
 $strLithuanian = '˳';
-$strLoadExplanation = '    ,     ,    .';
-$strLoadMethod = ' ';
 $strLocalhost = '';
 $strLocationTextfile = '  ';
+$strLoginInformation = '  ';
+$strLogin = '  ';
+$strLogout = '  ';
 $strLogPassword = ':';
 $strLogServer = '';
 $strLogUsername = ' :';
-$strLogin = '  ';
-$strLoginInformation = '  ';
-$strLogout = '  ';
 $strLongOperation = '     . ?';
 
-$strMIMETypesForTable = 'MIME- ';
-$strMIME_MIMEtype = 'MIME-';
+$strMaxConnects = '  ';
+$strMaximalQueryLength = '   ';
+$strMaximumSize = ' : %s%s';
+$strMbExtensionMissing = ' PHP mbstring  ,  , ,   .   mbstring phpMyAdmin     ,       .';
+$strMbOverloadWarning = '  mbstring.func_overload     PHP.     phpMyAdmin     !';
 $strMIME_available_mime = ' MIME-';
 $strMIME_available_transform = ' ';
 $strMIME_description = '';
+$strMIME_MIMEtype = 'MIME-';
 $strMIME_nodescription = '     .<br /> ,  ,   %s.';
 $strMIME_transformation = ' MIME- ';
 $strMIME_transformation_note = '         MIME-,   %s %s';
 $strMIME_transformation_options = ' ';
 $strMIME_transformation_options_note = ' ,       : \'a\',\'b\',\'c\'...<br />      ("\")   ("\'")   ,      (, \'\\\\xyz\'  \'a\\\'b\').';
+$strMIMETypesForTable = 'MIME- ';
 $strMIME_without = 'MIME-,  ,     ';
-$strMaximumSize = ' : %s%s';
-$strMbExtensionMissing = ' PHP mbstring  ,  , ,   .   mbstring phpMyAdmin     ,       .';
-$strMbOverloadWarning = '  mbstring.func_overload     PHP.     phpMyAdmin     !';
 $strModifications = '  ';
 $strModify = '';
 $strModifyIndexTopic = ' ';
-$strMoreStatusVars = '  ';
 $strMoveTable = '   ( <b>.</b>):';
 $strMoveTableOK = ' %s    %s.';
 $strMoveTableSameNames = '     !';
 $strMultilingual = '';
-$strMustSelectFile = '   ,    .';
-$strMyISAMDataPointerSize = '   ';
 $strMyISAMDataPointerSizeDesc = '      ,    CREATE TABLE   MyISAM,     MAX_ROWS.';
-$strMyISAMMaxExtraSortFileSize = '      ';
+$strMyISAMDataPointerSize = '   ';
 $strMyISAMMaxExtraSortFileSizeDesc = '   ,       MyISAM,  ,      ,  ,    .';
-$strMyISAMMaxSortFileSize = '     ';
+$strMyISAMMaxExtraSortFileSize = '      ';
 $strMyISAMMaxSortFileSizeDesc = '    MySQL,       MyISAM ( REPAIR TABLE, ALTER TABLE,  LOAD DATA INFILE).';
-$strMyISAMRecoverOptions = '  ';
+$strMyISAMMaxSortFileSize = '     ';
 $strMyISAMRecoverOptionsDesc = '      MyISAM,     --myisam-recover  .';
-$strMyISAMRepairThreads = ' ';
+$strMyISAMRecoverOptions = '  ';
 $strMyISAMRepairThreadsDesc = '     1,   MyISAM    (     )    .';
-$strMyISAMSortBufferSize = '  ';
+$strMyISAMRepairThreads = ' ';
 $strMyISAMSortBufferSizeDesc = ',      MyISAM  REPAIR TABLE    ,  CREATE INDEX  ALTER TABLE.';
+$strMyISAMSortBufferSize = '  ';
 $strMySQLCharset = ' MySQL';
+$strMysqlClientVersion = '  MySQL';
 $strMySQLConnectionCollation = '   MySQL';
-$strMySQLReloaded = 'MySQL .';
 $strMySQLSaid = ' MySQL: ';
-$strMySQLServerProcess = 'MySQL %pma_s1%  %pma_s2%  %pma_s3%';
 $strMySQLShowProcess = ' ';
 $strMySQLShowStatus = '  MySQL';
 $strMySQLShowVars = '   MySQL';
 
 $strName = '';
-$strNeedPrimaryKey = '       .';
 $strNext = '';
-$strNo = '';
 $strNoActivity = '      %s .  ,  ';
 $strNoDatabases = '  ';
 $strNoDatabasesSelected = '   .';
@@ -453,64 +486,68 @@ $strNoDescription = ' ';
 $strNoDetailsForEngine = '        .';
 $strNoDropDatabases = ' "DROP DATABASE" .';
 $strNoExplain = '  SQL';
+$strNoFilesFoundInZip = '  ZIP-  !';
 $strNoFrames = '  phpMyAdmin     <b></b>.';
+$strNo = '';
 $strNoIndex = '  !';
 $strNoIndexPartsDefined = '   !';
 $strNoModification = ' ';
+$strNone = '';
 $strNoOptions = '    ';
 $strNoPassword = ' ';
 $strNoPermission = '-        %s.';
 $strNoPhp = ' PHP-';
 $strNoPrivileges = ' ';
-$strNoQuery = ' SQL-!';
 $strNoRights = '           !';
 $strNoRowsSelected = 'ͳ   ';
 $strNoSpace = '      %s.';
 $strNoTablesFound = '     .';
 $strNoThemeSupport = '  ;  ,    /     %s.';
-$strNoUsersFound = '  .';
-$strNoValidateSQL = '  SQL';
-$strNone = '';
+$strNothingToImport = '    !';
 $strNotNumber = '  !';
 $strNotOK = ' OK';
 $strNotSet = ' <b>%s</b>       %s';
-$strNotValidNumber = '     !';
+$strNoUsersFound = '  .';
+$strNoValidateSQL = '  SQL';
 $strNull = '';
+$strNumberOfFields = ' 븢';
 $strNumSearchResultsInTable = '%s    <i>%s</i>';
 $strNumSearchResultsTotal = '<b>:</b> <i>%s</i> ';
 $strNumTables = '';
 
 $strOK = 'OK';
-$strOftenQuotation = ', . " " ,    char  varchar   .';
+$strOpenNewWindow = '   phpMyAdmin';
 $strOperations = '';
 $strOperator = '';
 $strOptimizeTable = ' ';
-$strOptionalControls = ' . ,      .';
-$strOptionally = ' ';
 $strOr = '';
 $strOverhead = ' ';
 $strOverwriteExisting = ' () ()';
 
-$strPHP40203 = '  PHP 4.2.3,   \'       (mbstring).     PHP 19404.   PHP      phpMyAdmin.';
-$strPHPVersion = ' PHP';
 $strPageNumber = ':';
 $strPagesToBeFlushed = '  ';
 $strPaperSize = ' ';
+$strPartialImport = ' ';
 $strPartialText = ' ';
-$strPassword = '';
 $strPasswordChanged = '  %s  .';
 $strPasswordEmpty = ' !';
 $strPasswordHashing = ' ';
+$strPassword = '';
 $strPasswordNotSame = '  !';
 $strPdfDbSchema = '  "%s"   %s';
 $strPdfInvalidTblName = ' "%s"  !';
 $strPdfNoTables = ' ';
+$strPDFOptions = ' PDF';
+$strPDF = 'PDF';
+$strPDFReportTitle = ' ';
 $strPerHour = ' ';
 $strPerMinute = ' ';
 $strPerSecond = ' ';
 $strPersian = '';
 $strPhoneBook = ' ';
+$strPHP40203 = '  PHP 4.2.3,   \'       (mbstring).     PHP 19404.   PHP      phpMyAdmin.';
 $strPhp = ' PHP-';
+$strPHPVersion = ' PHP';
 $strPmaDocumentation = '  phpMyAdmin';
 $strPmaUriError = ' <tt>$cfg[\'PmaAbsoluteUri\']</tt> ²      !';
 $strPolish = '';
@@ -526,7 +563,6 @@ $strPrintView = '  ';
 $strPrintViewFull = '   (  )';
 $strPrivDescAllPrivileges = '  ,  GRANT.';
 $strPrivDescAlter = '    .';
-$strPrivDescAlterDb = '    ,         .';
 $strPrivDescAlterRoutine = '    ,  .';
 $strPrivDescCreateDb = '      .';
 $strPrivDescCreateRoutine = '  ,  .';
@@ -537,8 +573,8 @@ $strPrivDescCreateView = '   .';
 $strPrivDescDelete = '  .';
 $strPrivDescDropDb = '     .';
 $strPrivDescDropTbl = '  .';
-$strPrivDescExecute = '   ;      MySQL.';
 $strPrivDescExecute5 = '  ,  .';
+$strPrivDescExecute = '   ;      MySQL.';
 $strPrivDescFile = '         .';
 $strPrivDescGrant = '        .';
 $strPrivDescIndex = '    .';
@@ -547,6 +583,7 @@ $strPrivDescLockTables = '     .';
 $strPrivDescMaxConnections = '   ,       .';
 $strPrivDescMaxQuestions = '  ,         .';
 $strPrivDescMaxUpdates = '  ,      ,       .';
+$strPrivDescMaxUserConnections = '   ,    .';
 $strPrivDescProcess3 = '    .';
 $strPrivDescProcess4 = '      .';
 $strPrivDescReferences = '     MySQL.';
@@ -563,11 +600,13 @@ $strPrivDescUsage = ' .';
 $strPrivileges = '';
 $strPrivilegesReloaded = '   .';
 $strProcesslist = ' ';
+$strProtocolVersion = ' ';
 $strPutColNames = '  븢   ';
 
 $strQBE = '  ';
 $strQBEDel = '';
 $strQBEIns = '';
+$strQueryCache = ' ';
 $strQueryFrame = ' ';
 $strQueryOnDb = 'SQL-   <b>%s</b>:';
 $strQuerySQLHistory = 'ó SQL';
@@ -576,66 +615,54 @@ $strQueryTime = '  %01.4f ';
 $strQueryType = ' ';
 $strQueryWindowLock = '      ';
 
-$strReType = '';
 $strReadRequests = ' ';
 $strReceived = '';
 $strRecords = '';
 $strReferentialIntegrity = '  :';
 $strRefresh = '';
-$strRelationNotWorking = '       .   ,  %s%s.';
-$strRelationView = ' ';
 $strRelationalSchema = ' ';
-$strRelations = '';
+$strRelationNotWorking = '       .   ,  %s%s.';
 $strRelationsForTable = '  ';
-$strReloadFailed = ' MySQL  .';
-$strReloadMySQL = ' MySQL';
+$strRelations = '';
+$strRelationView = ' ';
 $strReloadingThePrivileges = ' ';
+$strReloadMySQL = ' MySQL';
 $strRemoveSelectedUsers = '  ';
 $strRenameDatabaseOK = '  %s    %s';
 $strRenameTable = '  ';
 $strRenameTableOK = ' %s    %s';
 $strRepairTable = ' ';
-$strReplace = '';
 $strReplaceNULLBy = ' NULL ';
 $strReplaceTable = '     ';
+$strReplication = '';
 $strReset = '';
 $strResourceLimits = ' ';
+$strReType = '';
 $strRevoke = '';
 $strRevokeAndDelete = '        .';
 $strRevokeAndDeleteDescr = '       (USAGE),     .';
 $strRevokeMessage = '    %s';
 $strRomanian = '';
-$strRoutines = '';
 $strRowLength = ' ';
-$strRowSize = '   ';
 $strRows = '';
 $strRowsFrom = ',    #';
+$strRowSize = '   ';
 $strRowsModeFlippedHorizontal = ' ( )';
 $strRowsModeHorizontal = '';
 $strRowsModeOptions = '  %s      %s ';
 $strRowsModeVertical = '';
 $strRowsStatistic = ' ';
+$strRunning = ' %s';
 $strRunQuery = ' ';
 $strRunSQLQuery = ' SQL-()    %s';
-$strRunning = ' %s';
+$strRunSQLQueryOnServer = ' SQL-()   %s';
 $strRussian = '';
 
-$strSQL = 'SQL';
-$strSQLExportCompatibility = '  SQL';
-$strSQLExportType = ' ';
-$strSQLOptions = ' SQL';
-$strSQLParserBugMessage = ',     SQL-.  ,         .       ,        -  ,  .           MySQL.     MySQL  ,       .           ,      ,  ,    SQL-   ,   ,        ,    CUT :';
-$strSQLParserUserError = ',  SQL-  .     MySQL  , ,      ';
-$strSQLQuery = 'SQL-';
-$strSQLResult = 'SQL-';
-$strSQPBugInvalidIdentifer = ' ';
-$strSQPBugUnclosedQuote = ' ';
-$strSQPBugUnknownPunctuation = '  ';
 $strSave = '';
 $strSaveOnServer = '     %s';
 $strScaleFactorSmall = '   ,     ';
-$strSearch = '';
 $strSearchFormTitle = '   ';
+$strSearch = '';
 $strSearchInTables = ' ():';
 $strSearchNeedle = '()  ()   (: "%"):';
 $strSearchOption1 = '   ';
@@ -653,10 +680,11 @@ $strSelectNumRows = ' ';
 $strSelectTables = ' ()';
 $strSend = '  ';
 $strSent = '';
-$strServer = '';
 $strServerChoice = ' ';
 $strServerNotResponding = '  ';
+$strServer = '';
 $strServerStatus = ' ';
+$strServerStatusDelayedInserts = ' ';
 $strServerStatusUptime = '  MySQL  %s.    %s.';
 $strServerTabProcesslist = '';
 $strServerTabVariables = '';
@@ -665,32 +693,158 @@ $strServerVars = '   ';
 $strServerVersion = ' ';
 $strSessionValue = ' ';
 $strSetEnumVal = '   "enum"  "set",  ,     : \'a\',\'b\',\'c\'...<br />      ("\")   ("\'")   ,      (, \'\\\\xyz\'  \'a\\\'b\').';
-$strShow = '';
 $strShowAll = ' ';
 $strShowColor = ' ';
 $strShowDatadictAs = '  ';
 $strShowFullQueries = '  ';
 $strShowGrid = ' ';
+$strShow = '';
+$strShowingBookmark = ' ';
+$strShowingRecords = ' ';
+$strShowOpenTables = '  ';
 $strShowPHPInfo = '   PHP';
+$strShowSlaveHosts = '  ';
+$strShowSlaveStatus = '   ';
+$strShowStatusBinlog_cache_disk_useDescr = ' ,      ,     binlog_cache_size        .';
+$strShowStatusBinlog_cache_useDescr = ' ,      .';
+$strShowStatusCreated_tmp_disk_tablesDescr = '    ,      .   Created_tmp_disk_tables ,     tmp_table_size,      ,    .';
+$strShowStatusCreated_tmp_filesDescr = '  ,  mysqld.';
+$strShowStatusCreated_tmp_tablesDescr = '  ,   ,        .';
+$strShowStatusDelayed_errorsDescr = ' ,   INSERT DELAYED, -     (,  ).';
+$strShowStatusDelayed_insert_threadsDescr = '   INSERT DELAYED,  .  ,    INSERT DELAYED    .';
+$strShowStatusDelayed_writesDescr = '  INSERT DELAYED .';
+$strShowStatusFlush_commandsDescr  = '  FLUSH-.';
+$strShowStatusHandler_commitDescr = '  COMMIT-.';
+$strShowStatusHandler_deleteDescr = '     .';
+$strShowStatusHandler_discoverDescr = ' MySQL      NDB Cluster,       .   . Handler_discover    .';
+$strShowStatusHandler_read_firstDescr = '       .    ,       ; , SELECT col1 FROM foo, ,  col1 .';
+$strShowStatusHandler_read_keyDescr = '       .   ,    ,      .';
+$strShowStatusHandler_read_nextDescr = '       .  ,              .';
+$strShowStatusHandler_read_prevDescr = '       .        ORDER BY ... DESC.';
+$strShowStatusHandler_read_rndDescr = '     .  ,    ,    . ,   ,    MySQL      \',    .';
+$strShowStatusHandler_read_rnd_nextDescr = '       .  ,     .     ,         ,    .';
+$strShowStatusHandler_rollbackDescr = '   ROLLBACK.';
+$strShowStatusHandler_updateDescr = '     .';
+$strShowStatusHandler_writeDescr = '     .';
+$strShowStatusInnodb_buffer_pool_pages_dataDescr = ' ,    (  ).';
+$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = '  .';
+$strShowStatusInnodb_buffer_pool_pages_flushedDescr = '   ,       .';
+$strShowStatusInnodb_buffer_pool_pages_freeDescr = '  .';
+$strShowStatusInnodb_buffer_pool_pages_latchedDescr = ' ,      InnoDB.  ,                -  .';
+$strShowStatusInnodb_buffer_pool_pages_miscDescr = '   ,        ,       .        Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';
+$strShowStatusInnodb_buffer_pool_pages_totalDescr = '   ,  .';
+$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = '   ,  InnoDB.  ,      ,    .';
+$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = '   ,  InnoDB.  ,  InnoDB     .';
+$strShowStatusInnodb_buffer_pool_read_requestsDescr = '   ,  InnoDB.';
+$strShowStatusInnodb_buffer_pool_readsDescr = '  ,  InnoDB      ,     .';
+$strShowStatusInnodb_buffer_pool_wait_freeDescr = ',     InnoDB,   . ,           ,  ,      .      .      ,     .';
+$strShowStatusInnodb_buffer_pool_write_requestsDescr = ' ,     InnoDB.';
+$strShowStatusInnodb_data_fsyncsDescr = '  fsync()   .';
+$strShowStatusInnodb_data_pending_fsyncsDescr = '   fsync(),   .';
+$strShowStatusInnodb_data_pending_readsDescr = '  ,   .';
+$strShowStatusInnodb_data_pending_writesDescr = '  ,   .';
+$strShowStatusInnodb_data_readDescr = '     ,  .';
+$strShowStatusInnodb_data_readsDescr = '   .';
+$strShowStatusInnodb_data_writesDescr = '   .';
+$strShowStatusInnodb_data_writtenDescr = '     ,  .';
+$strShowStatusInnodb_dblwr_pages_writtenDescr = '  ,   ,   ,      .';
+$strShowStatusInnodb_dblwr_writesDescr = '  ,   ,   ,      .';
+$strShowStatusInnodb_log_waitsDescr = '   - ,      ,    ,    .';
+$strShowStatusInnodb_log_write_requestsDescr = '   .';
+$strShowStatusInnodb_log_writesDescr = '     -.';
+$strShowStatusInnodb_os_log_fsyncsDescr = '  ,   -.';
+$strShowStatusInnodb_os_log_pending_fsyncsDescr = '  -,   .';
+$strShowStatusInnodb_os_log_pending_writesDescr = '   -,   .';
+$strShowStatusInnodb_os_log_writtenDescr = ' ,   -.';
+$strShowStatusInnodb_pages_createdDescr = '  .';
+$strShowStatusInnodb_page_sizeDescr = '   InnoDB (  16).     ;        .';
+$strShowStatusInnodb_pages_readDescr = '  .';
+$strShowStatusInnodb_pages_writtenDescr = '  .';
+$strShowStatusInnodb_row_lock_current_waitsDescr = '  ,      .';
+$strShowStatusInnodb_row_lock_time_avgDescr = '     ,  .';
+$strShowStatusInnodb_row_lock_timeDescr = '      ,  .';
+$strShowStatusInnodb_row_lock_time_maxDescr = '     ,  .';
+$strShowStatusInnodb_row_lock_waitsDescr = ' ,     .';
+$strShowStatusInnodb_rows_deletedDescr = ' ,    InnoDB.';
+$strShowStatusInnodb_rows_insertedDescr = ' ,    InnoDB.';
+$strShowStatusInnodb_rows_readDescr = ' ,    InnoDB.';
+$strShowStatusInnodb_rows_updatedDescr = ' ,    InnoDB.';
+$strShowStatusKey_blocks_not_flushedDescr = '    ,   ,       .    Not_flushed_key_blocks.';
+$strShowStatusKey_blocks_unusedDescr = '     .          .';
+$strShowStatusKey_blocks_usedDescr = '     .              ,   .';
+$strShowStatusKey_read_requestsDescr = '       .';
+$strShowStatusKey_readsDescr = '      .   Key_reads ,  key_buffer_size, ,  .        Key_reads/Key_read_requests.';
+$strShowStatusKey_write_requestsDescr = '       .';
+$strShowStatusKey_writesDescr = '      .';
+$strShowStatusLast_query_costDescr = '    ,   .        .    0 ,       .';
+$strShowStatusNot_flushed_delayed_rowsDescr = '   ,   INSERT DELAY.';
+$strShowStatusOpened_tablesDescr = ' ,   .    ,      .';
+$strShowStatusOpen_filesDescr = '  .';
+$strShowStatusOpen_streamsDescr = '   (   ).';
+$strShowStatusOpen_tablesDescr = '  .';
+$strShowStatusQcache_free_blocksDescr = '      .';
+$strShowStatusQcache_free_memoryDescr = '     .';
+$strShowStatusQcache_hitsDescr = '   .';
+$strShowStatusQcache_insertsDescr = ' ,     .';
+$strShowStatusQcache_lowmem_prunesDescr = ' ,     ,       .        .     ,    (LRU)  ,      .';
+$strShowStatusQcache_not_cachedDescr = '   (   -   query_cache_type).';
+$strShowStatusQcache_queries_in_cacheDescr = ' ,    .';
+$strShowStatusQcache_total_blocksDescr = '     .';
+$strShowStatusReset = ' ';
+$strShowStatusRpl_statusDescr = '     (  ).';
+$strShowStatusSelect_full_joinDescr = ' \',    .      0,     .';
+$strShowStatusSelect_full_range_joinDescr = ' \',        .';
+$strShowStatusSelect_range_checkDescr = ' \'   ,       . (     0,     .)';
+$strShowStatusSelect_rangeDescr = ' \',    븢   . (  ,     .)';
+$strShowStatusSelect_scanDescr = ' \',      .';
+$strShowStatusSlave_open_temp_tablesDescr = '  ,       SQL-.';
+$strShowStatusSlave_retried_transactionsDescr = ' ( )  ,   SQL-   .';
+$strShowStatusSlave_runningDescr = '   "ON",        ,   .';
+$strShowStatusSlow_launch_threadsDescr = ' ,     slow_launch_time   .';
+$strShowStatusSlow_queriesDescr = ' ,     ,  long_query_time .';
+$strShowStatusSort_merge_passesDescr = ' ,     .    ,       sort_buffer_size.';
+$strShowStatusSort_rangeDescr = ' ,       .';
+$strShowStatusSort_rowsDescr = '  .';
+$strShowStatusSort_scanDescr = ' ,      .';
+$strShowStatusTable_locks_immediateDescr = ' ,      .';
+$strShowStatusTable_locks_waitedDescr = ' ,             .    ,     ,    ,       ,   .';
+$strShowStatusThreads_cachedDescr = '    .         Threads_created/Connections.       ,    thread_cache_size.';
+$strShowStatusThreads_connectedDescr = '     .';
+$strShowStatusThreads_createdDescr = ' ,    .   Threads_created , ,    thread_cache_size. (,    -   ,     .)';
+$strShowStatusThreads_runningDescr = ' ,    .';
 $strShowTableDimension = '  ';
 $strShowTables = ' ';
 $strShowThisQuery = '     ';
-$strShowingRecords = ' ';
 $strSimplifiedChinese = 'ʳ ';
 $strSingly = '()';
 $strSize = '';
+$strSkipQueries = ' (),     ';
 $strSlovak = '';
 $strSlovenian = '';
 $strSocketProblem = '(    MySQL   )';
-$strSort = '';
 $strSortByKey = '  ';
+$strSort = '';
+$strSorting = '';
 $strSpaceUsage = ' ';
 $strSpanish = 'ó';
 $strSplitWordsWithSpace = '   (" ").';
+$strSQLExportCompatibility = '  SQL';
+$strSQLExportType = ' ';
+$strSQLImportOptions = ' SQL';
+$strSQLOptions = ' SQL';
+$strSQLParserBugMessage = ',     SQL-.  ,         .       ,        -  ,  .           MySQL.     MySQL  ,       .           ,      ,  ,    SQL-   ,   ,        ,    CUT :';
+$strSQLParserUserError = ',  SQL-  .     MySQL  , ,      ';
+$strSQLQuery = 'SQL-';
+$strSQLResult = 'SQL-';
+$strSQL = 'SQL';
+$strSQPBugInvalidIdentifer = ' ';
+$strSQPBugUnclosedQuote = ' ';
+$strSQPBugUnknownPunctuation = '  ';
 $strStatCheckTime = ' ';
 $strStatCreateTime = '';
-$strStatUpdateTime = ' ';
 $strStatement = '';
+$strStatisticsOverrun = '       ,  ,   MySQL-,   .';
+$strStatUpdateTime = ' ';
 $strStatus = '';
 $strStorageEngine = '  ';
 $strStorageEngines = '  ';
@@ -709,37 +863,47 @@ $strSwedish = '';
 $strSwitchToDatabase = '    ';
 $strSwitchToTable = '   ';
 
-$strTable = '';
+$strTableAlreadyExists = ' %s  !';
 $strTableComments = '  ';
 $strTableEmpty = '  !';
 $strTableHasBeenDropped = ' %s  ';
 $strTableHasBeenEmptied = ' %s  ';
 $strTableHasBeenFlushed = '  %s  ';
 $strTableMaintenance = ' ';
+$strTable = '';
 $strTableOfContents = '';
 $strTableOptions = ' ';
+$strTables = '%s ()';
 $strTableStructure = ' ';
 $strTableType = ' ';
-$strTables = '%s ()';
 $strTakeIt = '';
 $strTblPrivileges = ',   ';
+$strTempData = ' ';
 $strTextAreaLength = ' -  ,<br />       ';
 $strThai = '';
-$strTheContent = '   .';
-$strTheContents = '             .';
-$strTheTerminator = '  븢.';
+$strThemeDefaultNotFound = '   %s  !';
+$strThemeNoPreviewAvailable = '  .';
+$strThemeNotFound = ' %s  !';
+$strThemeNoValidImgPath = '     %s  !';
 $strTheme = ' / ';
+$strThemePathNotFound = '     %s!';
 $strThisHost = ' ';
 $strThisNotDirectory = '  ';
+$strThreads = '';
 $strThreadSuccessfullyKilled = ' %s   .';
 $strTime = '';
+$strTimeoutInfo = '   -  .         %d.';
+$strTimeoutNothingParsed = ',       .   ,  phpMyAdmin     ,       php-.';
+$strTimeoutPassed = '    .     ,  ,      .';
 $strToggleScratchboard = '  ';
 $strTotal = '';
 $strTotalUC = '';
 $strTraditionalChinese = ' ';
 $strTraditionalSpanish = ' ';
 $strTraffic = '';
+$strTransactionCoordinator = ' ';
 $strTransformation_application_octetstream__download = '      .                ,    .     ,      ';
+$strTransformation_application_octetstream__hex = '    .';
 $strTransformation_image_jpeg__inline = '  ;        .   .';
 $strTransformation_image_jpeg__link = '     .';
 $strTransformation_image_png__inline = '  image/jpeg: ';
@@ -748,6 +912,7 @@ $strTransformation_text_plain__external = 'ʲ  LINUX:           .    .     Tidy,
 $strTransformation_text_plain__formatted = '   -,     htmlspecialchars().  ,     HTML-.';
 $strTransformation_text_plain__imagelink = '   ,    .       "http://www.example.com/".          .';
 $strTransformation_text_plain__link = ' ;    .       "http://www.example.com/".     .';
+$strTransformation_text_plain__sql = '   SQL-   .';
 $strTransformation_text_plain__substr = '   .        ,    (  0).     ,    ( :   ).    ,      /   ,    ( : "...") .';
 $strTruncateQueries = '  ';
 $strTurkish = '';
@@ -759,26 +924,29 @@ $strUnicode = '';
 $strUnique = '';
 $strUnknown = '';
 $strUnselectAll = '  ';
-$strUpdComTab = '     column_comments ,  ,  ';
+$strUnsupportedCompressionDetected = '      ,   (%s).     ,     .';
 $strUpdatePrivMessage = '     %s.';
 $strUpdateProfileMessage = '  .';
 $strUpdateQuery = ' ';
+$strUpdComTab = '     column_comments ,  ,  ';
 $strUpgrade = '   %s   %s  .';
+$strUploadLimit = ', ,     .  ,   %s%s      .';
 $strUsage = '';
 $strUseBackquotes = '      븢';
+$strUsedPhpExtensions = '  PHP';
 $strUseHostTable = '  ';
-$strUseTabKey = '  TAB        CTRL+      ';
-$strUseTables = ' ';
-$strUseTextField = '  ';
-$strUseThisValue = '  ';
-$strUser = '';
 $strUserAlreadyExists = ' %s  !';
+$strUser = '';
 $strUserEmpty = '  !';
 $strUserName = ' ';
 $strUserNotFound = '      .';
 $strUserOverview = '';
 $strUsersDeleted = '    .';
 $strUsersHavingAccessToDb = '     &quot;%s&quot;';
+$strUseTabKey = '  TAB        CTRL+      ';
+$strUseTables = ' ';
+$strUseTextField = '  ';
+$strUseThisValue = '  ';
 
 $strValidateSQL = ' SQL';
 $strValidatorError = '   SQL.  , ,       PHP,     %s%s.';
@@ -786,13 +954,14 @@ $strValue = '';
 $strVar = '';
 $strVersionInformation = '  ';
 $strView = '';
-$strViewDump = '  () ';
-$strViewDumpDB = '  ()  ';
 $strViewDumpDatabases = '  ()  ';
+$strViewDumpDB = '  ()  ';
+$strViewDump = '  () ';
 $strViewHasBeenDropped = ' %s  ';
+$strViewMaxExactCount = '     %d .  ,   %s%s.';
 
-$strWebServerUploadDirectory = ' -   ';
 $strWebServerUploadDirectoryError = '       ';
+$strWebServerUploadDirectory = ' -   ';
 $strWelcome = '  %s';
 $strWestEuropean = '';
 $strWildcard = '';
@@ -810,7 +979,4 @@ $strYes = '';
 $strZeroRemovesTheLimit = ':     0 ()  .';
 $strZip = '  zip';
 
-$strGeneratePassword = 'Generate Password';  //to translate
-$strGenerate = 'Generate';  //to translate
-$strCopy = 'Copy';  //to translate
 ?>
