@@ -1,5 +1,5 @@
 <?php
-/* $Id: bulgarian-windows-1251.inc.php,v 2.101 2005/11/12 00:35:07 lem9 Exp $ */
+/* $Id: bulgarian-windows-1251.inc.php,v 2.123.2.3 2006/03/23 17:42:11 lem9 Exp $ */
 
 /**
  * Translated by Stanislav Yordanov <stanprog at stanprog.com>
@@ -217,7 +217,6 @@ $strDocu = '';
 $strDoYouReally = '     ';
 $strDropDatabaseStrongWarning = '      !';
 $strDrop = '';
-$strDropSelectedDatabases = '     ';
 $strDropUsersDb = '           .';
 $strDumpingData = ' ()    ';
 $strDumpSaved = '()     %s.';
@@ -263,7 +262,6 @@ $strFields = '';
 $strField = '';
 $strFileAlreadyExists = ' %s    ,         .';
 $strFileCouldNotBeRead = '     ';
-$strFileNameTemplateHelp = ' __DB__      , __TABLE__        %sstrftime%s      ,      .      .';
 $strFileNameTemplateRemember = '  ';
 $strFileNameTemplate = '   ';
 $strFileToImport = '  ';
@@ -311,7 +309,6 @@ $strIgnoreInserts = '  INSERT IGNORE';
 $strIgnoringFile = '   %s';
 $strImportDocSQL = ' docSQL ';
 $strImportFiles = '  ';
-$strImportFinished = '  .';
 $strImportFormat = '   ';
 $strImport = '';
 $strIndexes = '';
@@ -335,7 +332,6 @@ $strInternalRelations = ' ';
 $strInUse = '';
 $strInvalidColumn = '  (%s)!';
 $strInvalidColumnCount = '      -  .';
-$strInvalidCSVInput = ' CSV ,     !';
 $strInvalidFieldAddCount = '     .';
 $strInvalidFieldCount = '      .';
 $strInvalidRowNumber = '%d      .';
@@ -407,9 +403,7 @@ $strMyISAMRepairThreads = '  ';
 $strMyISAMSortBufferSize = '    ';
 $strMySQLCharset = '    MySQL';
 $strMySQLConnectionCollation = '  MySQL';
-$strMySQLReloaded = 'MySQL  .';
 $strMySQLSaid = 'MySQL : ';
-$strMySQLServerProcess = 'MySQL %pma_s1%    %pma_s2%  %pma_s3%';
 $strMySQLShowProcess = 'MySQL ';
 $strMySQLShowStatus = '    MySQL ';
 $strMySQLShowVars = '   MySQL';
@@ -550,7 +544,6 @@ $strRelationNotWorking = '      (linked)   .      %s%s.';
 $strRelations = '';
 $strRelationsForTable = '  ';
 $strRelationView = '  ';
-$strReloadFailed = '     MySQL.';
 $strReloadingThePrivileges = '  ';
 $strReloadMySQL = '  MySQL';
 $strRemoveSelectedUsers = '   ';
@@ -796,7 +789,6 @@ $strDataPages = 'Pages containing data';  //to translate
 $strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate
 $strDirtyPages = 'Dirty pages';  //to translate
 
-$strEnclosingOptional = 'Enclosing of fields is optional';  //to translate
 $strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
 
 $strFlushQueryCache = 'Flush query cache';  //to translate
@@ -978,4 +970,34 @@ $strView = 'View';  //to translate
 
 $strWriteRequests = 'Write requests';  //to translate
 
+$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate
+$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
+$strFileNameTemplateDescriptionTable = 'table name';  //to translate
+$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
+$strFileNameTemplateDescriptionServer = 'server name';  //to translate
+$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
+$strProtocolVersion = 'Protocol version';  //to translate
+$strMysqlClientVersion = 'MySQL client version';  //to translate
+$strUsedPhpExtensions = 'Used PHP extensions';  //to translate
+$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
+$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
+$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
+$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
+$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
+$strPDF = 'PDF';  //to translate
+$strPDFOptions = 'PDF options';  //to translate
+$strPDFReportTitle = 'Report title';  //to translate
+$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
+$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
+$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
+$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
+$strThemeNotFound = 'Theme %s not found!';  //to translate
+$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
+$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
+$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
+$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
+$strSQLImportOptions = 'SQL options';  //to translate
+$strBrowseDistinctValues = 'Browse distinct values';  //to translate
+$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
+$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
 ?>
