@@ -1,5 +1,5 @@
 <?php
-/* $Id: catalan-utf-8.inc.php,v 2.107.2.1 2005/12/04 18:11:49 lem9 Exp $ */
+/* $Id: catalan-utf-8.inc.php,v 2.130.2.3 2006/03/23 17:42:11 lem9 Exp $ */
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
@@ -21,6 +21,7 @@ $datefmt = '%d-%m-%Y a les %H:%M:%S';
 $strAbortedClients = 'Avortat';
 $strAbsolutePathToDocSqlDir = 'S\'ha d\'entrar el camí absolut en el servidor web per el directori de docSQL';
 $strAccessDenied = 'Accés denegat';
+$strAccessDeniedCreateConfig = 'La raó més probable d\'aixó és que no heu creat l\'arxiu de configuració. Podriau voler utilitzar %1$ssetup script%2$s per crear-ne un.';
 $strAccessDeniedExplanation = 'phpMyAdmin ha intentat connectar amb el servidor de MySQL, pero el servidor ha rebutjat la connexió. Comprova el host, el num d\' usuari i la contrasenya al fitxer config.inc.php i mira que es correspongui amb la informació facilitada per l\' administrador del servidor de MySQL.';
 $strAction = 'Acció';
 $strAddAutoIncrement = 'Afegir valor AUTO_INCREMENT';
@@ -91,6 +92,7 @@ $strBookmarkQuery = 'Consulta SQL desada';
 $strBookmarkReplace = 'Reemplaçar una consulta desada ja existent amb el mateix nom';
 $strBookmarkThis = 'Desa aquesta consulta SQL';
 $strBookmarkView = 'Només mirar';
+$strBrowseDistinctValues = 'Navega per valors diferents';
 $strBrowseForeignValues = 'Navega valors externs';
 $strBrowse = 'Navega';
 $strBufferPool = 'Grup de memòries intermitges';
@@ -141,6 +143,7 @@ $strCompatibleHashing = 'Compatible amb MySQL&nbsp;4.0';
 $strCompleteInserts = 'Completar insercions';
 $strCompression = 'Compressió';
 $strCompressionWillBeDetected = 'La compresió de l\'arxiu importat es detectarà automàticament des de: %s';
+$strConfigDefaultFileError = 'No es pot carregar la configuració per defecte des de: "%1$s"';
 $strConfigFileError = 'phpMyAdmin és incapaç de llegir el fitxer de configuració!<br />Això pot succeir si php troba un error sintàctic en ell o bé php no pot trobar el fitxer.<br />Intenta obrir el fitxer de configuració directament fent servir l\'enllaç següent i comprova el(s) missatge(s) d\'error que reps. En moltes ocasions una coma o punt i coma falta en algun lloc.<br />Si reps una plana en blanc, tot està bé.';
 $strConfigureTableCoord = 'Configura les coordinades per la taula %s';
 $strConnectionError = 'No puc connectar: paràmetres incorrectes.';
@@ -229,7 +232,6 @@ $strDocu = 'Documentació';
 $strDoYouReally = 'Realment vols fer?';
 $strDropDatabaseStrongWarning = 'Ets a punt d\' ELIMINAR completament una base de dades!';
 $strDrop = 'Eliminar';
-$strDropSelectedDatabases = 'Esborra les Bases de dades sel.lecionades';
 $strDropUsersDb = 'Esborra les bases de dades que tenen els mateixos noms que els usuaris.';
 $strDumpingData = 'Volcant dades de la taula';
 $strDumpSaved = 'El volcat s\'ha guardat amb el nom d\'arxiu %s.';
@@ -244,7 +246,6 @@ $strEmpty = 'Buidar';
 $strEmptyResultSet = 'MySQL ha retornat un conjunt buit (p.e. cap fila).';
 $strEnabled = 'Activat';
 $strEncloseInTransaction = 'Incloure exportació en la transacció';
-$strEnclosingOptional = 'L\'inclusió de camps és opcional';
 $strEndCut = 'FI DEL TALL';
 $strEnd = 'Final';
 $strEndRaw = 'FI DEL VOLCAT';
@@ -277,7 +278,10 @@ $strFieldsEscapedBy = 'Camps amb marca d\'escapada';
 $strFieldsTerminatedBy = 'Camps acabats per';
 $strFileAlreadyExists = 'L\'arxiu %s ja existeix al servidor, canvia el nom o marca l\'opció de sobreescriure.';
 $strFileCouldNotBeRead = 'No es pot llegir el fitxer';
-$strFileNameTemplateHelp = 'Utilitza __DB__ per a nom de base de dades, __TABLE__ per a nom de taula i opcions %sany strftime%s per especificacions horaries, la extensió s\'afegirà automàgicament. Qualsevol altre text es mantindrà.';
+$strFileNameTemplateDescription = 'Aquest valor es interpretat usant %1$sstrftime%2$s, pel que podeu usar les cadenes de formateig de temps. Ademès, es faràn aquestes transformacions: %3$s. Altre text es deixarà sense variació.';
+$strFileNameTemplateDescriptionDatabase = 'nom de base de dades';
+$strFileNameTemplateDescriptionServer = 'nom de servidor';
+$strFileNameTemplateDescriptionTable = 'nom de taula';
 $strFileNameTemplate = 'Nom de fitxer de plantilla';
 $strFileNameTemplateRemember = 'Recordar plantilla';
 $strFileToImport = 'Arxiu a importar';
@@ -328,9 +332,9 @@ $strIgnoreInserts = 'Utilitzar "ignore inserts"';
 $strIgnoringFile = 'Ignorant fitxer %s';
 $strImportDocSQL = 'Importa Arxius docSQL';
 $strImportFiles = 'Importar fitxers';
-$strImportFinished = 'Importació finalitzada correctament.';
 $strImportFormat = 'Format de l\'arxiu importat';
 $strImport = 'Importar';
+$strImportSuccessfullyFinished = 'Importació finalitzada correctament, %d consultes executades.';
 $strIndexes = 'Indexos';
 $strIndexHasBeenDropped = 'S\'ha esborrat l\'índex %s';
 $strIndex = 'Índex';
@@ -358,11 +362,15 @@ $strInUse = 'en ús';
 $strInvalidAuthMethod = 'Mètode d\'identificació incorrecte establert a la configuració:';
 $strInvalidColumnCount = 'El comptador de columnes ha de ser més gran que zero.';
 $strInvalidColumn = 'S\'ha especificat una columna incorrecta (%s)!';
-$strInvalidCSVInput = 'Entrada de CSV incorrecta, no es pot processar!';
+$strInvalidCSVFieldCount = 'Comptador de camps incorrecte en l\'entrada CSV a la línia %d.';
+$strInvalidCSVFormat = 'Format incorrecte a l\'entrada CSV a la línia %d.';
+$strInvalidCSVParameter = 'Paràmetre incorrecte per importació CSV: %s';
 $strInvalidFieldAddCount = 'Heu d\'afegir al menys un camp.';
 $strInvalidFieldCount = 'La taula ha de tenir al menys un camp.';
 $strInvalidLDIImport = 'Aquesta extensió no suporta importacions comprimides!';
 $strInvalidRowNumber = '%d no és un num. vàlid de fila.';
+$strInvalidServerHostname = 'Nom de host invàlid pel servidor %1$s. Si us plau, reviseu la configuració.';
+$strInvalidServerIndex = 'Index de servidor invàlid: "%s"';
 
 $strJapanese = 'Japonès';
 $strJoins = 'Unions';
@@ -377,6 +385,8 @@ $strKill = 'Finalitzar';
 $strKorean = 'Coreà';
 
 $strLandscape = 'Horitzontal';
+$strLanguageFileNotFound = 'Arxiu d\'idioma "%1$s" no trobat.';
+$strLanguageUnknown = 'Idioma desconegut: %1$s.';
 $strLatchedPages = 'Planes inalterables';
 $strLatexCaption = 'Titol de Taula';
 $strLatexContent = 'Contingut de la taula __TABLE__';
@@ -443,10 +453,9 @@ $strMyISAMRepairThreads = 'Reparar fils';
 $strMyISAMSortBufferSizeDesc = 'Ârea assignada per classificar índexos MyISAM mentre es fa un REPAIR TABLE o mentre es creen índexos amb CREATE INDEX o ALTER TABLE.';
 $strMyISAMSortBufferSize = 'Tamany de l\'àrea de classificació';
 $strMySQLCharset = 'Joc de caràcters de MySQL';
+$strMysqlClientVersion = 'Versió del client MySQL';
 $strMySQLConnectionCollation = 'Ordenació de la connexió MySQL'; 
-$strMySQLReloaded = 'MySQL reiniciat.';
 $strMySQLSaid = 'MySQL diu: ';
-$strMySQLServerProcess = 'MySQL %pma_s1% executant-se a %pma_s2% com a %pma_s3%';
 $strMySQLShowProcess = 'Mostrar processos';
 $strMySQLShowStatus = 'Mostra la informació de funcionament del MySQL';
 $strMySQLShowVars = 'Mostra les variables de sistema del MySQL';
@@ -490,6 +499,7 @@ $strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> resultat(s)';
 $strNumTables = 'Taules';
 
 $strOK = 'Correcte';
+$strOpenNewWindow = 'Obrir nova finestra de phpMyAdmin';
 $strOperations = 'Operacions';
 $strOperator = 'Operador';
 $strOptimizeTable = 'Optimitza la taula';
@@ -510,6 +520,9 @@ $strPasswordNotSame = 'Les contrasenyes no coincideixen!';
 $strPdfDbSchema = 'Esquema de la base de dades "%s" - Pàgina %s';
 $strPdfInvalidTblName = 'La taula "%s" no existeix!';
 $strPdfNoTables = 'No hi ha taules';
+$strPDFOptions = 'Opcions PDF';
+$strPDF = 'PDF';
+$strPDFReportTitle = 'Títol de llistat';
 $strPerHour = 'per hora';
 $strPerMinute = 'per minut';
 $strPerSecond = 'per segon';
@@ -570,6 +583,7 @@ $strPrivDescUsage = 'Sense permissos.';
 $strPrivileges = 'Permissos';
 $strPrivilegesReloaded = 'Els permissos s\'han recarregat correctament.';
 $strProcesslist = 'Llista de processos';
+$strProtocolVersion = 'Versió del protocol';
 $strPutColNames = 'Posa els noms de camp a la primera fila';
 
 $strQBE = 'Consulta segons exemple';
@@ -593,7 +607,6 @@ $strRelationNotWorking = 'Les característiques addicionals per treballar amb ta
 $strRelationsForTable = 'RELACIONS DE LA TAULA';
 $strRelations = 'Relacions';
 $strRelationView = 'Vista de Relacions';
-$strReloadFailed = 'El reinici del MySQL ha fallat';
 $strReloadingThePrivileges = 'Recarregant permissos';
 $strReloadMySQL = 'Rellegir el MySQL';
 $strRemoveSelectedUsers = 'Treure els usuaris sel.leccionats';
@@ -799,6 +812,7 @@ $strSpanish = 'Espanyol';
 $strSplitWordsWithSpace = 'Paraules separades per un espai (" ").';
 $strSQLExportCompatibility = 'Compatibilitat d\'exportació SQL';
 $strSQLExportType = 'Tipus d\' Exportació';
+$strSQLImportOptions = 'Opcions SQL';
 $strSQLOptions = 'Opcions SQL';
 $strSQLParserBugMessage = 'És possible que hagueu trobat un error a l\'intèrpret SQL. Si us plau, comproveu la sintaxi de la consulta i verifiqueu que les cometes estiguin al seu lloc i facin parelles. Un altra possible causa de l\'errada és que estigueu pujant un arxiu amb dades binàries per fora de l\'àrea de text delimitada. També podeu provar la consulta a la interfície de comandes de MySQL. La sortida següent generada pel servidor MySQL, si n\'hi ha, pot ajudar-vos a diagnosticar el problema. Si encara teniu problemes o si l\'intèrpret falla i l\'interfície de comandes funciona, reduïu la consulta a la part de l\'SQL que produeix l\'errada, i envieu un informe d\'error amb la cadena de dades de la secció de TALL indicada avall:';
 $strSQLParserUserError = 'Sembla que hi ha un error a la consulta SQL. La sortida següent generada pel servidor MySQL, si n\'hi ha, pot ajudar-vos a diagnosticar el problema';
@@ -811,6 +825,7 @@ $strSQPBugUnknownPunctuation = 'Signe de puntuació desconegut';
 $strStatCheckTime = 'Darrera comprovació';
 $strStatCreateTime = 'Creació';
 $strStatement = 'Sentències';
+$strStatisticsOverrun = 'En un servidor ocupat, els comptadors de bytes poden excedir el seu tamany, llavors les estadístiques donades pel servidor MySQL poden ser incorrectes.';
 $strStatUpdateTime = 'Darrera actualització';
 $strStatus = 'Estat';
 $strStorageEngine = 'Motor d\'emmagatzematge';
@@ -848,6 +863,11 @@ $strTblPrivileges = 'Permissos especifics de taula';
 $strTempData = 'Dades temporals';
 $strTextAreaLength = ' A causa de la seva longitud,<br /> aquest camp pot no ser editable ';
 $strThai = 'Tailandès';
+$strThemeDefaultNotFound = 'Tema per defecte %s no trobat!';
+$strThemeNoPreviewAvailable = 'No hi ha vista prèvia disponible.';
+$strThemeNotFound = 'Tema %s no trobat!';
+$strThemeNoValidImgPath = 'El camí de les imatges del tema %s és incorrecte!';
+$strThemePathNotFound = 'No s\'ha trobat el camí de les imatges del tema %s!';
 $strTheme = 'Tema / Estil';
 $strThisHost = 'Aquest Host';
 $strThisNotDirectory = 'Aixó no és un directori';
@@ -895,6 +915,7 @@ $strUpgrade = 'Es necessari actualitzar a %s %s o posterior.';
 $strUploadLimit = 'Probablement has triat d\'enviar un arxiu massa gran. Consulta la %sdocumentació%s per trobar formes de modificar aquest límit.';
 $strUsage = 'Ús';
 $strUseBackquotes = 'Usa &quot;backquotes&quot; amb taules i noms de camps';
+$strUsedPhpExtensions = 'Extensions de PHP usades';
 $strUseHostTable = 'Utilitza la Taula de Hosts';
 $strUserAlreadyExists = 'L\'usuari %s ja existeix!';
 $strUserEmpty = 'El nom d\'usuari és buit!';
@@ -918,6 +939,7 @@ $strViewDumpDatabases = 'Veure volcat (esquema) de les bases de dades';
 $strViewDumpDB = 'Veure l\'esquema de la base de dades';
 $strViewDump = 'Veure un esquema de la taula';
 $strViewHasBeenDropped = 'Vista %s esborrada';
+$strViewMaxExactCount = 'Aquesta vista té més de %d files. Consulteu a %sdocumentació%s.';
 $strView = 'Vista';
 
 $strWebServerUploadDirectory = 'Directori de pujada d\'arxius del servidor web';
