@@ -1,5 +1,5 @@
 <?php
-/* $Id: czech-utf-8.inc.php,v 2.136 2005/11/13 23:16:15 nijel Exp $ */
+/* $Id: czech-utf-8.inc.php,v 2.166.2.2 2006/03/23 17:42:11 lem9 Exp $ */
 
 /**
  * Czech language file by
@@ -26,6 +26,7 @@ $timespanfmt = '%s dnů, %s hodin, %s minut a %s sekund';
 
 $strAbortedClients = 'Přerušené';
 $strAbsolutePathToDocSqlDir = 'docSQL adresář';
+$strAccessDeniedCreateConfig = 'Pravděpodobná příčina je, že nemáte vytvořený konfigurační soubor. Pro jeho vytvoření by se vám mohl hodit %1$snastavovací skript%2$s.';
 $strAccessDeniedExplanation = 'phpMyAdmin se pokusil připojit k&nbsp;MySQL serveru, a ten odmítl připojení. Zkontrolujte jméno serveru, uživatelské jméno a heslo v&nbsp;souboru config.inc.php a ujistěte se, že jsou totožné s&nbsp;těmi, které máte od administrátora MySQL serveru.';
 $strAccessDenied = 'Přístup odepřen';
 $strAction = 'Akce';
@@ -97,6 +98,7 @@ $strBookmarkQuery = 'Oblíbený SQL dotaz';
 $strBookmarkReplace = 'Přepsat existující oblíbený dotaz stejného jména';
 $strBookmarkThis = 'Přidat tento SQL dotaz do oblíbených';
 $strBookmarkView = 'Zobrazit';
+$strBrowseDistinctValues = 'Procházet odlišné hodnoty';
 $strBrowseForeignValues = 'Projít hodnoty cizích klíčů';
 $strBrowse = 'Projít';
 $strBufferPoolActivity = 'Aktivita vyrovnávací paměti';
@@ -152,6 +154,7 @@ $strCompatibleHashing = 'Kompatibilní s&nbsp;MySQL&nbsp;4.0';
 $strCompleteInserts = 'Úplné inserty';
 $strCompression = 'Komprese';
 $strCompressionWillBeDetected = 'Komprimace importovaného souboru bude automaticky rozpoznána. Podporovány jsou: %s';
+$strConfigDefaultFileError = 'Nepodařilo se nahrát výchozí konfiguraci ze soubouru: "%1$s"';
 $strConfigFileError = 'phpMyAdmin nemohl načíst konfigurační soubor!<br />Tato chyba může nastat, pokud v&nbsp;něm PHP najde chybu nebo nemůže tento soubor najít.<br />Po kliknutí na následující odkaz se PHP pokusí přímo interpretovat tento soubor a zobrazí informace o&nbsp;chybě, ke které došlo. Pak opravte tuto chybu (nejčastěji se jedná o&nbsp;chybějící středník).<br />Pokud získáte prázdnou stránku, všechno je v&nbsp;pořádku.';
 $strConfigureTableCoord = 'Prosím, nastavte souřadnice pro tabulku %s';
 $strConnectionError = 'Nepodařilo se připojit: chybné nastavení.';
@@ -235,12 +238,11 @@ $strDisableForeignChecks = 'Vypnout kontrolu cizích klíčů';
 $strDisplayFeat = 'Zobrazení funkcí';
 $strDisplayOrder = 'Seřadit podle:';
 $strDisplayPDF = 'Zobrazit jako schéma v&nbsp;PDF';
-$strDoAQuery = 'Provést &bdquo;dotaz podle příkladu&ldquo; (zástupný znak: &bdquo;%&ldquo)';
+$strDoAQuery = 'Provést &bdquo;dotaz podle příkladu&ldquo; (zástupný znak: &bdquo;%&ldquo;)';
 $strDocu = 'Dokumentace';
 $strDoYouReally = 'Opravdu si přejete vykonat příkaz';
 $strDropDatabaseStrongWarning = 'Chystáte se ZRUŠIT celou databázi!';
 $strDrop = 'Odstranit';
-$strDropSelectedDatabases = 'Zrušit vybranou databázi';
 $strDropUsersDb = 'Odstranit databáze se stejnými jmény jako uživatelé.';
 $strDumpingData = 'Vypisuji data pro tabulku';
 $strDumpSaved = 'Výpis byl uložen do souboru %s.';
@@ -255,7 +257,6 @@ $strEmptyResultSet = 'MySQL vrátil prázdný výsledek (tj. nulový počet řá
 $strEmpty = 'Vyprázdnit';
 $strEnabled = 'Zapnuto';
 $strEncloseInTransaction = 'Uzavřít příkazy v&nbsp;transakci';
-$strEnclosingOptional = 'Uzavření slouců je volitelné';
 $strEndCut = 'KONEC VÝPISU';
 $strEnd = 'Konec';
 $strEndRaw = 'KONEC VÝPISU';
@@ -281,14 +282,17 @@ $strExtra = 'Extra';
 $strFailedAttempts = 'Nepovedených pokusů';
 $strFieldHasBeenDropped = 'Sloupec %s byl odstraněn';
 $strFieldsEmpty = ' Nebyl zadán počet sloupců! ';
-$strFieldsEnclosedBy = 'Názvy sloupců uzavřené do';
+$strFieldsEnclosedBy = 'Názvy sloupců uzavřené';
 $strFieldsEscapedBy = 'Názvy sloupců escapovány';
 $strField = 'Sloupec';
 $strFields = 'Sloupce';
 $strFieldsTerminatedBy = 'Sloupce oddělené';
 $strFileAlreadyExists = 'Soubor %s již na serveru existuje, změňte jméno souboru, nebo zvolte přepsání souboru.';
 $strFileCouldNotBeRead = 'Soubor nelze přečíst';
-$strFileNameTemplateHelp = 'Použijte __DB__ pro jméno databáze, __TABLE__ pro jméno tabulky a jakékoliv parametry pro %sfunkci strftime%s pro vložení data. Přípona souboru bude automaticky přidána podle typu. Jakýkoliv jiný text bude zachován.';
+$strFileNameTemplateDescriptionDatabase = 'jméno databáze';
+$strFileNameTemplateDescriptionServer = 'jméno serveru';
+$strFileNameTemplateDescriptionTable = 'jméno tabulky';
+$strFileNameTemplateDescription = 'Tato hodnota je interpretována pomocí %1$sstrftime%2$s, takže můžete použít libovolné řetězce pro formátování data a času. Dále budou provedena následující nahrazení: %3$s. Jakýkoliv jiný text zůstane zachován beze změny.';
 $strFileNameTemplateRemember = 'zapamatovat si hodnotu';
 $strFileNameTemplate = 'Vzor pro jméno souboru';
 $strFileToImport = 'Soubor pro importování';
@@ -343,9 +347,9 @@ $strIgnoreInserts = 'Použít IGNORE';
 $strIgnoringFile = 'Ignoruji soubor %s';
 $strImportDocSQL = 'Importovat soubory docSQL';
 $strImportFiles = 'Importovat soubory';
-$strImportFinished = 'Import byl úspěšně dokončen.';
 $strImportFormat = 'Formát importovaného souboru'; 
 $strImport = 'Import';
+$strImportSuccessfullyFinished = 'Import byl úspěšně dokončen, bylo provedeno %d dotazů.';
 $strIndexes = 'Indexy';
 $strIndexHasBeenDropped = 'Index %s byl odstraněn';
 $strIndex = 'Index';
@@ -376,11 +380,15 @@ $strInUse = 'právě se používá';
 $strInvalidAuthMethod = 'V konfiguraci máte špatnou autentizační metodu:';
 $strInvalidColumn = 'Byl zadán chybný sloupec (%s)!';
 $strInvalidColumnCount = 'Počet sloupců musí být větší než nula.';
-$strInvalidCSVInput = 'Chybná CVS data, nepodařilo se je načíst!';
+$strInvalidCSVFieldCount = 'Chybný počet položek v&nbsp;CSV datech na řádku %d.';
+$strInvalidCSVFormat = 'Chybný formát CSV dat na řádku %d.';
+$strInvalidCSVParameter = 'Neznámý parametr pro import CSV: %s';
 $strInvalidFieldAddCount = 'Musíte přidat alespoň jeden sloupec.';
 $strInvalidFieldCount = 'Tabulka musí mít alespoň jeden sloupec.';
 $strInvalidLDIImport = 'Tento plugin nepodporuje komprimované soubory!';
 $strInvalidRowNumber = '%d není platné číslo řádku.';
+$strInvalidServerHostname = 'Chybné jméno serveru pro server %1$s. Prosím zkontrolujte nastavení.';
+$strInvalidServerIndex = 'Chybný index serveru: "%s"';
 
 $strJapanese = 'Japonština';
 $strJoins = 'Použité výběry';
@@ -395,6 +403,8 @@ $strKill = 'Ukončit';
 $strKorean = 'Korejština';
 
 $strLandscape = 'Na šířku';
+$strLanguageFileNotFound = 'Jazykový soubor "%1$s" nebyl nalezen.';
+$strLanguageUnknown = 'Neznámý jazyk: %1$s.';
 $strLatchedPages = 'Zamčených stránek';
 $strLatexCaption = 'Titulek tabulky';
 $strLatexContent = 'Obsah tabulky __TABLE__';
@@ -409,7 +419,7 @@ $strLatvian = 'Lotyština';
 $strLDI = 'CSV pomocí LOAD DATA';
 $strLDIImportOptions = 'Nastavení CSV importu pomocí LOAD DATA';
 $strLDILocal = 'Použít klíčové slovo LOCAL';
-$strLengthSet = 'Délka/Množina*';
+$strLengthSet = 'Délka/Množina';
 $strLimitNumRows = 'záznamů na stránku';
 $strLinesTerminatedBy = 'Řádky ukončené';
 $strLinkNotFound = 'Odkaz nenalezen';
@@ -461,10 +471,9 @@ $strMyISAMRepairThreads = 'Threadů pro opravování';
 $strMyISAMSortBufferSizeDesc = 'Paměť, která je alokována při řazení MyISAM indexů během jejich vytváření nebo opravování.';
 $strMyISAMSortBufferSize = 'Velikost paměti pro řazení';
 $strMySQLCharset = 'Znaková sada v&nbsp;MySQL';
+$strMysqlClientVersion = 'Verze MySQL klienta';
 $strMySQLConnectionCollation = 'Porovnávání pro toto připojení k&nbsp;MySQL';
-$strMySQLReloaded = 'MySQL znovu načteno.';
 $strMySQLSaid = 'MySQL hlásí: ';
-$strMySQLServerProcess = 'MySQL %pma_s1% běžící na serveru %pma_s2%, uživatel přihlášen jako %pma_s3%';
 $strMySQLShowProcess = 'Zobrazit procesy';
 $strMySQLShowStatus = 'Informace o&nbsp;stavu MySQL';
 $strMySQLShowVars = 'Systémové proměnné MySQL';
@@ -480,8 +489,8 @@ $strNoDropDatabases = 'Příkaz &bdquo;DROP DATABASE&ldquo; je vypnutý.';
 $strNoExplain = 'Bez vysvětlení (EXPLAIN) SQL';
 $strNoFilesFoundInZip = 'V&nbsp;ZIP archívu nebyly nalezeny žádné soubory!';
 $strNoFrames = 'phpMyAdmin se lépe používá v&nbsp;prohlížeči podporujícím rámy (&bdquo;FRAME&ldquo;).';
-$strNoIndex = 'Tabulka nemá žádný index!';
 $strNoIndexPartsDefined = 'Nebyla zadána žádná část indexu!';
+$strNoIndex = 'Tabulka nemá žádný index!';
 $strNoModification = 'Žádná změna';
 $strNo = 'Ne';
 $strNone = 'Žádná';
@@ -508,6 +517,7 @@ $strNumSearchResultsTotal = '<b>Celkem:</b> <i>%s</i> odpovídající(ch) zázna
 $strNumTables = 'Tabulek';
 
 $strOK = 'OK';
+$strOpenNewWindow = 'Otevřít nové okno phpMyAdmina';
 $strOperations = 'Úpravy';
 $strOperator = 'Operátor';
 $strOptimizeTable = 'Optimalizovat tabulku';
@@ -528,6 +538,9 @@ $strPasswordNotSame = 'Hesla nejsou stejná!';
 $strPdfDbSchema = 'Schéma databáze &bdquo;%s&ldquo; - Strana %s';
 $strPdfInvalidTblName = 'Tabulka &bdquo;%s&ldquo; neexistuje!';
 $strPdfNoTables = 'žádné tabulky';
+$strPDFOptions = 'Nastavení PDF';
+$strPDF = 'PDF';
+$strPDFReportTitle = 'Název výpisu';
 $strPerHour = 'za hodinu';
 $strPerMinute = 'za minutu';
 $strPerSecond = 'za sekundu';
@@ -588,6 +601,7 @@ $strPrivDescUsage = 'Žádná oprávnění.';
 $strPrivileges = 'Oprávnění';
 $strPrivilegesReloaded = 'Oprávnění byla znovunačtena úspěšně.';
 $strProcesslist = 'Seznam procesů';
+$strProtocolVersion = 'Verze protokolu';
 $strPutColNames = 'Přidat jména sloupců na první řádek';
 
 $strQBEDel = 'smazat';
@@ -612,7 +626,6 @@ $strRelationNotWorking = 'Některé z&nbsp;rozšířených funkcí phpMyAdmina n
 $strRelationsForTable = 'RELACE PRO TABULKU';
 $strRelations = 'Relace';
 $strRelationView = 'Zobrazit relace';
-$strReloadFailed = 'Znovunačtení MySQL selhalo.';
 $strReloadingThePrivileges = 'Znovunačítám oprávnění';
 $strReloadMySQL = 'Znovunačtení MySQL';
 $strRemoveSelectedUsers = 'Odstranit vybrané uživatele';
@@ -818,6 +831,7 @@ $strSpanish = 'Španělština';
 $strSplitWordsWithSpace = 'Slova jsou oddělena mezerou (&bdquo; &ldquo;).';
 $strSQLExportCompatibility = 'Kompatibilita SQL exportu';
 $strSQLExportType = 'Typ vytvořených dotazů';
+$strSQLImportOptions = 'Nastavení SQL importu';
 $strSQLOptions = 'Nastavení SQL exportu';
 $strSQLParserBugMessage = 'Je možné, že jste našli chybu v&nbsp;SQL parseru. Prosím prozkoumejte podrobně SQL dotaz, především jestli jsou správně uvozovky a jestli nejsou proházené. Další možnost selhání je pokud nahráváte soubor s&nbsp;binárními daty nezapsanými v&nbsp;uvozovkách. Můžete také vyzkoušet příkazovou řádku MySQL. Níže uvedený výstup z&nbsp;MySQL serveru (pokud je nějaký) Vám také může pomoci při zkoumání problému. Pokud stále máte problémy nebo pokud SQL parser ohlásí chybu u&nbsp;dotazu, který na příkazové řádce funguje, prosím pokuste se zredukovat dotaz na co nejmenší, ve kterém se problém ještě vyskytne, a ohlaste chybu na stránkách phpMyAdmina spolu se sekcí VÝPIS uvedenou níže:';
 $strSQLParserUserError = 'Pravděpodobně máte v&nbsp;SQL dotazu chybu. Níže uvedený výstup MySQL serveru (pokud je nějaký) Vám také může pomoci při zkoumání problému';
@@ -830,6 +844,7 @@ $strSQPBugUnknownPunctuation = 'Neznámé interpunkční znaménko';
 $strStatCheckTime = 'Poslední kontrola';
 $strStatCreateTime = 'Vytvoření';
 $strStatement = 'Údaj';
+$strStatisticsOverrun = 'Na hodně zatíženém serveru mohou čítače přetéct, takže statistiky MySQL serveru mohou být nepřesné.';
 $strStatUpdateTime = 'Poslední změna';
 $strStatus = 'Stav';
 $strStorageEngines = 'Úložiště';
@@ -867,6 +882,11 @@ $strTblPrivileges = 'Oprávnění pro jednotlivé tabulky';
 $strTempData = 'Dočasná data';
 $strTextAreaLength = 'Tento sloupec možná nepůjde <br />(kvůli délce) upravit ';
 $strThai = 'Thajština';
+$strThemeDefaultNotFound = 'Výchozí vzhled %s nebyl nalezen!';
+$strThemeNoPreviewAvailable = 'Náhled není k&nbsp;dispozici.';
+$strThemeNotFound = 'Vzhled %s nebyl nalezen!';
+$strThemeNoValidImgPath = 'Nebyla nalezena platná cesta k obrázkům pro vzhled %s!';
+$strThemePathNotFound = 'Nebyla nalezena platná cesta k vzhledu %s!';
 $strTheme = 'Vzhled';
 $strThisHost = 'Tento počítač';
 $strThisNotDirectory = 'Nebyl zadán adresář';
@@ -914,6 +934,7 @@ $strUpgrade = 'Měli byste aktualizovat %s na verzi %s nebo vyšší.';
 $strUploadLimit = 'Pravděpodobně jste se pokusili nahrát příliš velký soubor. Přečtěte si prosím %sdokumentaci%s, jak toto omezení obejít.';
 $strUsage = 'Používá';
 $strUseBackquotes = 'Použít zpětné uvozovky u&nbsp;jmen tabulek a sloupců';
+$strUsedPhpExtensions = 'Použitá rozšíření PHP';
 $strUseHostTable = 'Použít tabulku s&nbsp;počítači';
 $strUserAlreadyExists = 'Uživatel %s již existuje!';
 $strUserEmpty = 'Jméno uživatele je prázdné!';
@@ -937,6 +958,7 @@ $strViewDumpDatabases = 'Export databází';
 $strViewDumpDB = 'Export databáze';
 $strViewDump = 'Export tabulky';
 $strViewHasBeenDropped = 'Pohled %s byl odstraněn';
+$strViewMaxExactCount = 'Tento pohled má více než %d záznamů. Viz %sdokumentace%s.';
 $strView = 'Pohled';
 
 $strWebServerUploadDirectoryError = 'Adresář určený pro upload souborů nemohl být otevřen';
