@@ -1,5 +1,5 @@
 <?php
-/* $Id: danish-utf-8.inc.php,v 2.111.2.1 2005/12/21 15:59:06 lem9 Exp $ *//* Dansk v 2.93 (english 2.108) 11/12-2005 00:00:00 - oversætter AlleyKat kan kontaktes på < phpmyadmin (at) phpbb2.dk > */
+/* $Id: danish-utf-8.inc.php,v 2.135.2.3 2006/03/23 17:42:11 lem9 Exp $ */ /* Dansk v 2.136 (english 2.130) 10/02-2006 00:00:00 - oversætter AlleyKat kan kontaktes på < phpmyadmin (at) phpbb2.dk > */
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
@@ -21,6 +21,7 @@ $timespanfmt = '%s dage, %s timer, %s minutter og %s sekunder';
 $strAbortedClients = 'Afbrudt';
 $strAbsolutePathToDocSqlDir = 'Indtast venligst absolut sti på webserveren til docSQL mappen';
 $strAccessDenied = 'Adgang Nægtet';
+$strAccessDeniedCreateConfig = 'Sandsynlig årsag til dette er at du ikke har oprettet en konfigurationsfil. Du kan bruge %1$ssetupscriptet%2$s til at oprette en.';
 $strAccessDeniedExplanation = 'phpMyAdmin forsøgte at forbinde til MySQL-serveren, og serveren afviste forbindelsen. Du bør tjekke host, brugernavn og kodeord i config.inc.php og sikre dig at de svarer til den information du har fået af administratoren af MySQL-serveren.';
 $strAction = 'Handling';
 $strAddAutoIncrement = 'Tilføj AUTO_INCREMENT værdi';
@@ -30,7 +31,7 @@ $strAddDeleteRow = 'Tilføj/Slet kriterie-række';
 $strAddDropDatabase = 'Tilføj DROP DATABASE';
 $strAddedColumnComment = 'Tilføjet kommentar til kolonne';
 $strAddedColumnRelation = 'Tilføjet relation til kolonne';
-$strAddFields  =  'Tilføj %s felt(er)';
+$strAddFields = 'Tilføj %s felt(er)';
 $strAddHeaderComment = 'Tilføj tilpassede kommentarer i headeren (\\n deler linjer)';
 $strAddIfNotExists = 'Tilføj IF NOT EXISTS';
 $strAddIntoComments = 'Tilføj til kommentarer';
@@ -39,19 +40,19 @@ $strAddPrivilegesOnDb = 'Tilføj privilegier på følgende database';
 $strAddPrivilegesOnTbl = 'Tilføj privileges på følgende tabel';
 $strAddSearchConditions = 'Tilføj søgekriterier (kroppen af "WHERE" sætningen):';
 $strAddToIndex = 'Føj til indeks &nbsp;%s&nbsp;kolonne(r)';
-$strAddUserMessage = 'Du har tilføjet en ny bruger.';
 $strAddUser = 'Tilføj en ny bruger';
+$strAddUserMessage = 'Du har tilføjet en ny bruger.';
 $strAdministration = 'Administration';
 $strAffectedRows = 'Berørte rækker:';
 $strAfter = 'Efter %s';
 $strAfterInsertBack = 'Tilbage til foregående side';
 $strAfterInsertNewInsert = 'Indsæt endnu en ny række';
-$strAfterInsertNext = 'Ret næste række';
+$strAfterInsertNext = 'Redigér næste række';
 $strAfterInsertSame = 'Gå tilbage til denne side';
 $strAll = 'Alle';
 $strAllowInterrupt = 'Tillad afbrydelse af import hvis scriptet er tæt på tidsgrænsen. Dette kan være en god metode til at importere større filer, men kan knække transaktioner.';
 $strAllTableSameWidth = 'vis alle tabeller med samme bredde?';
-$strAlterOrderBy = 'Arrangér rækkeorden efter';
+$strAlterOrderBy = 'Arrangér tabelrækkefølge efter';
 $strAnalyzeTable = 'Analysér tabel';
 $strAnd = 'Og';
 $strAndThen = 'og derefter';
@@ -83,7 +84,7 @@ $strBinLogName = 'Lognavn';
 $strBinLogOriginalPosition = 'Original position';
 $strBinLogPosition = 'Position';
 $strBinLogServerId = 'Server ID';
-$strBookmarkAllUsers = 'Lad alle brugere få adgang til bogmærket';
+$strBookmarkAllUsers = 'Lad alle brugere bruge dette bogmærke';
 $strBookmarkCreated = 'Bogmærke %s oprettet';
 $strBookmarkDeleted = 'Bogmærket er fjernet.';
 $strBookmarkLabel = 'Mærke';
@@ -91,8 +92,9 @@ $strBookmarkQuery = 'SQL-forespørgsel med bogmærke';
 $strBookmarkReplace = 'Erstat eksisterende bogmærke af samme navn';
 $strBookmarkThis = 'Lav bogmærke til denne SQL-forespørgsel';
 $strBookmarkView = 'Kun oversigt';
-$strBrowseForeignValues = 'Bladr i fremmede værdier';
 $strBrowse = 'Vis';
+$strBrowseDistinctValues = 'Gennemse bestemte værdier';
+$strBrowseForeignValues = 'Bladr i fremmede værdier';
 $strBufferPoolActivity = 'Buffer Pool Aktivitet';
 $strBufferPool = 'Buffer Pool';
 $strBufferPoolUsage = 'Buffer Pool Forbrug';
@@ -102,13 +104,13 @@ $strBufferWriteWaitsInPercent = 'Write waits i %';
 $strBufferWriteWaits = 'Write waits';
 $strBulgarian = 'Bulgarsk';
 $strBusyPages = 'Travle sider';
-$strBzError  =  'phpMyAdmin kunne ikke komprimere dumpet på grund af en ødelagt Bz2 extension i denne PHP version. Det anbefales kraftigt at sætte <code>$cfg[\'BZipDump\']</code> direktivet i din phpMyAdmin konfigurationsfil til <code>FALSE</code>. Hvis du vil bruge Bz2 komprimeringsfeatures, bør du opdatere til en nyere PHP version. Se PHP bug report %s for detaljer.';
+$strBzError = 'phpMyAdmin kunne ikke komprimere dumpet på grund af en ødelagt Bz2 extension i denne PHP version. Det anbefales kraftigt at sætte <code>$cfg[\'BZipDump\']</code> direktivet i din phpMyAdmin konfigurationsfil til <code>FALSE</code>. Hvis du vil bruge Bz2 komprimeringsfeatures, bør du opdatere til en nyere PHP version. Se PHP bug report %s for detaljer.';
 $strBzip = '"bzipped"';
 
 $strCalendar = 'Kalender';
 $strCanNotLoadImportPlugins = 'Kunne ikke indlæse import plugins, check venligst din installation!';
 $strCannotLogin = 'Kan ikke logge ind på MySQL-serveren';
-$strCantLoad  =  'Kan ikke indlæse [a@http://php.net/%1$s@Dokumentation][em]%1$s[/em][/a] udvidelsen. Tjek venligst din PHP konfiguration.';
+$strCantLoad = 'Kan ikke indlæse [a@http://php.net/%1$s@Dokumentation][em]%1$s[/em][/a] udvidelsen. Tjek venligst din PHP konfiguration.';
 $strCantLoadRecodeIconv = 'Kan ikke indlæse iconv eller omkode nødvendig udvidelse til tegnsæt-konvertering, konfigurer php til at tillade brug af disse udvidelser eller slå tegnsæt-konvertering fra i phpMyAdmin.';
 $strCantRenameIdxToPrimary = 'Kan ikke omdøbe indeks til PRIMARY!';
 $strCantUseRecodeIconv = 'Kan ikke bruge iconv ejheller libiconv eller recode_string funktionen omend udvidelsen ser ud til at være indlæst. Check din php-konfiguration.';
@@ -118,17 +120,17 @@ $strCaseSensitive = 'forskel på store/små bogstaver';
 $strCentralEuropean = 'Centraleuropæisk';
 $strChange = 'Ændre';
 $strChangeCopyModeCopy = '... behold den gamle.';
+$strChangeCopyMode = 'Opret en bruger med samme privilegier og ...';
 $strChangeCopyModeDeleteAndReload = ' ... slet den gamle fra brugertabellerne og genindlæs privilegierne efterfølgende.';
 $strChangeCopyModeJustDelete = ' ... slet den gamle fra brugertabellerne.';
-$strChangeCopyMode = 'Opret en bruger med samme privilegier og ...';
 $strChangeCopyModeRevoke = ' ... tilbagekald alle aktive privilegier fra den gamle og slet den efterfølgende.';
 $strChangeCopyUser = 'Ret Login-information / Kopiér bruger';
 $strChangeDisplay = 'Vælg felt der skal vises';
 $strChangePassword = 'Ændre kodeord';
+$strCharset = 'Tegnsæt';
 $strCharsetOfFile = 'Tegnsæt for filen:';
 $strCharsetsAndCollations = 'Tegnsæt og kollationer (Collations)';
 $strCharsets = 'Tegnsæt';
-$strCharset = 'Tegnsæt';
 $strCheckAll = 'Afmærk alt';
 $strCheckOverhead = 'Check tabeller der har overhead';
 $strCheckPrivs = 'Check Privilegier';
@@ -137,15 +139,16 @@ $strCheckTable = 'Tjek tabel';
 $strChoosePage = 'Vælg en side der skal redigeres';
 $strColComFeat = 'Viser kolonne-kommentarer';
 $strCollation = 'Kollation (Collation)';
-$strColumnNames = 'Kolonne navne';
+$strColumnNames = 'Kolonnenavne';
 $strColumnPrivileges = 'Kolonne-specifikke privilegier';
 $strCommand = 'Kommando';
-$strCommentsForTable = 'COMMENTS FOR TABLE (tabel-kommentarer)';
 $strComments = 'Kommentarer';
+$strCommentsForTable = 'COMMENTS FOR TABLE (tabel-kommentarer)';
 $strCompatibleHashing = 'MySQL&nbsp;4.0 kompatibel';
-$strCompleteInserts = 'Lav komplette inserts';
+$strCompleteInserts = 'Komplette inserts';
 $strCompression = 'Komprimering';
 $strCompressionWillBeDetected = 'Importeret fil-komprimering vil blive automatisk registreret fra: %s';
+$strConfigDefaultFileError = 'Kunne ikke indlæse standardkonfiguration fra: \"%1$s\"';
 $strConfigFileError = 'phpMyAdmin kunne ikke læse din konfigurationsfil!<br />Dette kan ske hvis php finder en parser-fejl i den, eller php kan ikke finde filen.<br />Kald konfigurationsfilen direkte fra nedenstående link og læs de(n) phpfejlmeddelse(r) du får. I de fleste tilfælde mangler der et anførselstegn eller et semikolon et sted.<br />Hvis du får en blank side, er alt i orden.';
 $strConfigureTableCoord = 'Konfigurér venligst koordinaterne for tabel %s';
 $strConnectionError = 'Kan ikke forbinde: ugyldige indstillinger.';
@@ -153,18 +156,18 @@ $strConnections = 'Forbindelser';
 $strConstraintsForDumped = 'Begrænsninger for dumpede tabeller';
 $strConstraintsForTable = 'Begrænsninger for tabel';
 $strCookiesRequired = 'Herefter skal cookies være slået til.';
-$strCopyDatabaseOK = 'Database %s er blevet kopieret til %s';
 $strCopy = 'Kopi';
+$strCopyDatabaseOK = 'Database %s er blevet kopieret til %s';
 $strCopyTable = 'Kopier tabel til (database<b>.</b>tabel):';
 $strCopyTableOK = 'Tabellen %s er nu kopieret til: %s.';
 $strCopyTableSameNames = 'Kan ikke kopiere tabellen til den samme!';
 $strCouldNotKill = 'phpMyAdmin kunne ikke dræbe tråden %s. Den er sandsynligvis allerede lukket.';
+$strCreate = 'Opret';
 $strCreateDatabaseBeforeCopying = 'CREATE DATABASE før kopiering';
 $strCreateIndex = 'Dan et indeks på&nbsp;%s&nbsp;kolonner';
 $strCreateIndexTopic = 'Lav et nyt indeks';
 $strCreateNewDatabase = 'Opret ny database';
 $strCreateNewTable = 'Opret ny tabel i database %s';
-$strCreate = 'Opret';
 $strCreatePage = 'Opret en ny side';
 $strCreatePdfFeat = 'Oprettelse af PDFer';
 $strCreationDates = 'Oprettet/Opdateret/Check datoer';
@@ -174,8 +177,8 @@ $strCSV = 'CSV (kommasepareret)';
 $strCSVImportOptions = 'CSV indstillinger';
 $strCSVOptions = 'CSV-indstillinger';
 $strCyrillic = 'Kyrillisk';
-$strCzechSlovak = 'Tjekkisk-Slovakisk';
 $strCzech = 'Tjekkisk';
+$strCzechSlovak = 'Tjekkisk-Slovakisk';
 
 $strDanish = 'Dansk';
 $strDatabase = 'Database';
@@ -195,8 +198,8 @@ $strDataOnly = 'Kun data';
 $strDataPages = 'Sider der indeholder data';
 $strDBComment = 'Databasekommentar: ';
 $strDBCopy = 'Kopiér database til';
-$strDBGContextID = 'Sammenhæng-ID';
 $strDBGContext = 'Sammenhæng';
+$strDBGContextID = 'Sammenhæng-ID';
 $strDBGHits = 'Hits';
 $strDBGLine = 'Linje';
 $strDBGMaxTimeMs = 'Max tid, ms';
@@ -207,17 +210,17 @@ $strDBGTotalTimeMs = 'Total tid, ms';
 $strDbPrivileges = 'Database-specifikke privilegier';
 $strDBRename = 'Omdøb database til';
 $strDbSpecific = 'database-specifik';
-$strDefaultEngine = '%s er standard datalageret på denne MySQL-server.';
 $strDefault = 'Standardværdi';
+$strDefaultEngine = '%s er standard datalageret på denne MySQL-server.';
 $strDefaultValueHelp = 'For standardværdier, indtast venligst kun en enkelt værdi, uden backslash escaping eller quotes, ud fra følgende format: a';
 $strDefragment = 'Defragmentér tabel';
 $strDelayedInserts = 'Brug forsinkede indsættelser';
-$strDeleteAndFlushDescr = 'Dette er den sikreste metode, men genindlæsning af privilegierne kan tage noget tid.';
 $strDeleteAndFlush = 'Slet brugerne og genindlæs privilegier bagefter.';
-$strDeleted = 'Rækken er slettet!';
-$strDeletedRows = 'Slettede rækker:';
-$strDeleteNoUsersSelected = 'Ingen brugere valgt til sletning!';
+$strDeleteAndFlushDescr = 'Dette er den sikreste metode, men genindlæsning af privilegierne kan tage noget tid.';
 $strDelete = 'Slet';
+$strDeletedRows = 'Slettede rækker:';
+$strDeleted = 'Rækken er slettet!';
+$strDeleteNoUsersSelected = 'Ingen brugere valgt til sletning!';
 $strDeleting = 'Sletter %s';
 $strDelOld = 'Nuværende side har referencer til tabeller der ikke længere eksisterer. Vil du slette disse referencer?';
 $strDescending = 'Faldende';
@@ -233,7 +236,6 @@ $strDoAQuery = 'Kør en forespørgsel på felter (jokertegn: "%")';
 $strDocu = 'Dokumentation';
 $strDoYouReally = 'Er du sikker på at du vil ';
 $strDropDatabaseStrongWarning = 'Du er ved at DESTRUERE en komplet database!';
-$strDropSelectedDatabases = 'Drop (slet) valgte Databaser';
 $strDrop = 'Slet';
 $strDropUsersDb = 'Drop databaser der har samme navne som brugernes.';
 $strDumpingData = 'Data dump for tabellen';
@@ -241,18 +243,17 @@ $strDumpSaved = 'Dump er blevet gemt i filen %s.';
 $strDumpXRows = 'Dump %s rækker startende med række %s.';
 $strDynamic = 'dynamisk';
 
+$strEdit = 'Ret';
 $strEditPDFPages = 'Redigér PDF-sider';
 $strEditPrivileges = 'Ret privilegier';
-$strEdit = 'Ret';
 $strEffective = 'Effektiv';
-$strEmptyResultSet = 'MySQL returnerede ingen data (fx ingen rækker).';
 $strEmpty = 'Tøm';
+$strEmptyResultSet = 'MySQL returnerede ingen data (fx ingen rækker).';
 $strEnabled = 'Slået til';
 $strEncloseInTransaction = 'Inkludér eksport i en transaktion';
-$strEnclosingOptional = 'Indeslutning af felter er frivilligt';
 $strEndCut = 'SLUT KLIP';
-$strEndRaw = 'SLUT RÅ';
 $strEnd = 'Slut';
+$strEndRaw = 'SLUT RÅ';
 $strEngineAvailable = '%s er tilgængelig på denne MySQL-server.';
 $strEngineDisabled = '%s er slået fra på denne MySQL-server.';
 $strEngines = 'Lagre';
@@ -282,9 +283,12 @@ $strFields = 'Felter';
 $strFieldsTerminatedBy = 'Felter afsluttet med';
 $strFileAlreadyExists = 'Filen %s findes allerede på serveren, ændr filnavn eller tillad at der overskrives.';
 $strFileCouldNotBeRead = 'Filen kunne ikke læses';
-$strFileNameTemplateHelp = 'Brug __DB__ for databasenavn, __TABLE__ for tabelnavn og %senhver strftime%s sammensætning for tidsspecifikation, extension (filefternavn) tilføjes automagisk. Al anden tekst bevares.';
-$strFileNameTemplateRemember = 'husk skabelonen';
+$strFileNameTemplateDescriptionDatabase = 'databasenavn';
+$strFileNameTemplateDescriptionServer = 'servernavn';
+$strFileNameTemplateDescriptionTable = 'tabelnavn';
+$strFileNameTemplateDescription = 'Denne værdi fortolkes via %1$sstrftime%2$s, så du kan bruge tidsformatterede strenge. Ydermere vil følgende transformationer foregå: %3$s. Anden tekst vil blive bevaret som det er.';
 $strFileNameTemplate = 'Skabelon for filnavn';
+$strFileNameTemplateRemember = 'husk skabelonen';
 $strFileToImport = 'Fil til import';
 $strFixed = 'ordnet';
 $strFlushPrivilegesNote = 'Bemærk: phpMyAdmin henter brugernes privilegier direkte fra MySQLs privilegietabeller. Indholdet af disse tabeller kan være forskelligt fra privilegierne serveren bruger hvis der er lavet manuelle ændringer i den. Hvis det er tilfældet, bør du %sgenindlæse privilegierne%s før du fortsætter.';
@@ -337,9 +341,9 @@ $strIgnoreInserts = 'Brug ignorér inserts';
 $strIgnoringFile = 'Ignorerer fil %s';
 $strImportDocSQL = 'Importer docSQL Filer';
 $strImportFiles = 'Importér filer';
-$strImportFinished = 'Import færdig';
 $strImportFormat = 'Format på importeret fil';
 $strImport = 'Importer';
+$strImportSuccessfullyFinished = 'Import er korrekt gennemført, %d forespørgsler udført.';
 $strIndexes = 'Indeks';
 $strIndexHasBeenDropped = 'Indeks %s er blevet slettet';
 $strIndex = 'Indeks';
@@ -370,17 +374,21 @@ $strInUse = 'i brug';
 $strInvalidAuthMethod = 'Ugyldig autorisationsmetode sat i konfiguration:';
 $strInvalidColumnCount = 'Kolonnetælling skal være større end nul.';
 $strInvalidColumn = 'Ugyldig kolonne (%s) specificeret!';
-$strInvalidCSVInput = 'Ugyldigt CSV input, kunne ikke behandle!';
+$strInvalidCSVFieldCount = 'Ugyldigt feltantal i CSV-input på linie %d.';
+$strInvalidCSVFormat = 'Ugyldigt format for CSV-input på linie %d.';
+$strInvalidCSVParameter = 'Ugyldigt parameter for CSV-import: %s';
 $strInvalidFieldAddCount = 'Du skal tilføje mindst ét felt.';
 $strInvalidFieldCount = 'Tabellen skal indeholde mindst ét felt.';
 $strInvalidLDIImport = 'Denne plugin understøtter ikke komprimerede importer!';
 $strInvalidRowNumber = '%d er ikke gyldigt rækkenummer.';
+$strInvalidServerHostname = 'Ugyldigt hostnavn for server %1$s. Gennemgå venligst din konfiguration.';
+$strInvalidServerIndex = 'Ugyldigt server indeks: \"%s\"';
 
 $strJapanese = 'Japansk';
 $strJoins = 'Joins';
 $strJumpToDB = 'Hop til database &quot;%s&quot;.';
-$strJustDelete = 'Bare slet brugerne fra privilegietabellerne.';
 $strJustDeleteDescr = 'De &quot;slettede&quot; brugere kan stadig tilgå serveren som de plejer indtil privilegierne genindlæses.';
+$strJustDelete = 'Bare slet brugerne fra privilegietabellerne.';
 
 $strKeepPass = 'Kodeord må ikke ændres';
 $strKeyCache = 'Nøglemellemlager (key cache)';
@@ -389,6 +397,8 @@ $strKill = 'Dræb (Kill)';
 $strKorean = 'Koreansk';
 
 $strLandscape = 'Liggende';
+$strLanguageFileNotFound = 'Sprogfil \"%1$s\" ikke fundet.';
+$strLanguageUnknown = 'Ukendt sprog: %1$s.';
 $strLatchedPages = 'Eksklusivt låste (latched) sider';
 $strLatexCaption = 'Tabeloverskrift';
 $strLatexContent = 'Indhold af tabel __TABLE__';
@@ -431,7 +441,7 @@ $strMIME_MIMEtype = 'MIME-type';
 $strMIME_nodescription = 'Der er ingen beskrivelse af denne transformation.<br />Spørg venligst forfatteren, hvad %s gør.';
 $strMIME_transformation = 'Browser transformation';
 $strMIME_transformation_note = 'For en liste over mulige transformationsindstillinger og deres MIME-type transformationer, klik på %stransformationsbeskrivelser%s';
-$strMIME_transformation_options_note  =  'Indtast værdier for transformationsindstillinger ud fra følgende format: \'a\',\'b\',\'c\'...<br />Skulle du få brug for at indsætte en backslash ("\") eller en apostrof ("\'") i værdierne, backslash det (for eksempel \'\\\\xyz\' eller \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Indtast værdier for transformationsindstillinger ud fra følgende format: \'a\',\'b\',\'c\'...<br />Skulle du få brug for at indsætte en backslash ("\") eller en apostrof ("\'") i værdierne, backslash det (for eksempel \'\\\\xyz\' eller \'a\\\'b\').';
 $strMIME_transformation_options = 'Transformationsindstillinger';
 $strMIMETypesForTable = 'MIME TYPES FOR TABLE (MIME-typer for tabellen)';
 $strMIME_without = 'MIME-typer skrevet med kursiv har ikke en separat transformationsfunktion';
@@ -455,10 +465,9 @@ $strMyISAMRepairThreads = 'Reparér tråde';
 $strMyISAMSortBufferSizeDesc = 'Bufferen der allokeres ved sortering af MyISAM indeks under en REPAIR TABLE eller når indeks oprettes med CREATE INDEX eller ALTER TABLE.';
 $strMyISAMSortBufferSize = 'Sorterings-bufferstørrelse';
 $strMySQLCharset = 'MySQL Tegnsæt';
+$strMysqlClientVersion = 'MySQL klientversion';
 $strMySQLConnectionCollation = 'MySQL forbindelses-sammenkøring';
-$strMySQLReloaded = 'MySQL genstartet.';
 $strMySQLSaid = 'MySQL returnerede: ';
-$strMySQLServerProcess = 'MySQL %pma_s1% kører på %pma_s2% som %pma_s3%';
 $strMySQLShowProcess = 'Vis tråde';
 $strMySQLShowStatus = 'Vis MySQL runtime-information';
 $strMySQLShowVars = 'Vis MySQL systemvariabler';
@@ -502,6 +511,7 @@ $strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> hit(s)';
 $strNumTables = 'Tabeller';
 
 $strOK = 'OK';
+$strOpenNewWindow = 'Åbn nyt phpMyAdmin vindue';
 $strOperations = 'Operationer';
 $strOperator = 'Operatør';
 $strOptimizeTable = 'Optimer tabel';
@@ -517,11 +527,14 @@ $strPartialText = 'Delvise tekster';
 $strPasswordChanged = 'Kodeordet for %s blev korrekt udskiftet.';
 $strPasswordEmpty = 'Der er ikke angivet noget kodeord!';
 $strPasswordHashing = 'Kodeord Hashing';
-$strPassword = 'Kodeord';
 $strPasswordNotSame = 'De to kodeord er ikke ens!';
+$strPassword = 'Kodeord';
 $strPdfDbSchema = 'Skematik for databasen "%s" - Side %s';
 $strPdfInvalidTblName = 'Tabellen "%s" findes ikke!';
 $strPdfNoTables = 'Ingen tabeller';
+$strPDFOptions = 'PDF-indstillinger';
+$strPDF = 'PDF';
+$strPDFReportTitle = 'Rapporttitel';
 $strPerHour = 'pr. time';
 $strPerMinute = 'pr. minut';
 $strPerSecond = 'pr. sekund';
@@ -531,7 +544,7 @@ $strPHP40203 = 'Du bruger PHP 4.2.3, som har en alvorlig fejl med multi-byte str
 $strPhp = 'Fremstil PHP-kode';
 $strPHPVersion = 'PHP version';
 $strPmaDocumentation = 'phpMyAdmin dokumentation';
-$strPmaUriError  =  '<tt>$cfg[\'PmaAbsoluteUri\']</tt> direktivet SKAL være sat i din konfigurationsfil!';
+$strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> direktivet SKAL være sat i din konfigurationsfil!';
 $strPolish = 'Polsk';
 $strPortrait = 'Stående';
 $strPos1 = 'Start';
@@ -544,8 +557,8 @@ $strPrint = 'Print';
 $strPrintViewFull = 'Udskrift-visning (med fulde tekster)';
 $strPrintView = 'Vis (udskriftvenlig)';
 $strPrivDescAllPrivileges = 'Inkluderer alle privilegier pånær GRANT.';
-$strPrivDescAlterRoutine = 'Tillader ændring og sletning af gemte rutiner.';
 $strPrivDescAlter = 'Tillader ændring af strukturen på eksisterende tabeller.';
+$strPrivDescAlterRoutine = 'Tillader ændring og sletning af gemte rutiner.';
 $strPrivDescCreateDb = 'Tillader oprettelse af nye databaser og tabeller.';
 $strPrivDescCreateRoutine = 'Tillader oprettelse af gemte rutiner.';
 $strPrivDescCreateTbl = 'Tillader oprettelse af nye tabeller.';
@@ -582,11 +595,12 @@ $strPrivDescUsage = 'Ingen privilegier.';
 $strPrivileges = 'Privilegier';
 $strPrivilegesReloaded = 'Privilegierne blev korrekt genindlæst.';
 $strProcesslist = 'Procesliste';
+$strProtocolVersion = 'Protokolversion';
 $strPutColNames = 'Indsæt feltnavne i første række';
 
 $strQBEDel = 'Del (Slet)';
-$strQBE = 'Foresp. via eks.';
 $strQBEIns = 'Ins(Indsæt)';
+$strQBE = 'Foresp. via eks.';
 $strQueryCache = 'Forespørgsel-mellemlager';
 $strQueryFrame = 'Foresp. vindue';
 $strQueryOnDb = 'SQL-forespørgsel til database <b>%s</b>:';
@@ -606,7 +620,6 @@ $strRelationNotWorking = 'De ekstra features for at arbejde med linkede tabeller
 $strRelationsForTable = 'RELATIONS FOR TABLE (Relationer for tabellen)';
 $strRelations = 'Relationer';
 $strRelationView = 'Se Relationer';
-$strReloadFailed = 'Genstart af MySQL fejlede.';
 $strReloadingThePrivileges = 'Genindlæs privilegierne';
 $strReloadMySQL = 'Genstart MySQL';
 $strRemoveSelectedUsers = 'Fjern valgte brugere';
@@ -636,12 +649,12 @@ $strRows = 'Rækker';
 $strRowsStatistic = 'Række-statistik';
 $strRunning = 'kører på %s';
 $strRunQuery = 'Send forespørgsel';
-$strRunSQLQuery = 'Kør SQL-forspørgsel(er) på database %s';
 $strRunSQLQueryOnServer = 'Kør SQL-forespørgsel/forespørgsler på server %s';
+$strRunSQLQuery = 'Kør SQL-forspørgsel(er) på database %s';
 $strRussian = 'Russisk';
 
-$strSave = 'Gem';
 $strSaveOnServer = 'Gem på serveren i mappen %s ';
+$strSave = 'Gem';
 $strScaleFactorSmall = 'Skaleringsfaktoren er for lille til at tilpasse skematikken til en side';
 $strSearchFormTitle = 'Søg i databasen';
 $strSearchInTables = 'Indeni tabel(ler):';
@@ -684,6 +697,7 @@ $strShowingBookmark = 'Viser bogmærke';
 $strShowingRecords = 'Viser poster ';
 $strShowOpenTables = 'Vis åbne tabeller';
 $strShowPHPInfo = 'Vis PHP information';
+$strShow = 'Vis';
 $strShowSlaveHosts = 'Vis slave værter';
 $strShowSlaveStatus = 'Vis slave status';
 $strShowStatusBinlog_cache_disk_useDescr = 'Antal transaktioner der brugte det midlertidige binære log mellemlager men overskred værdien for binlog_cache_size og brugte en midlertidig fil til at gemme statements fra transaktionen.';
@@ -796,7 +810,6 @@ $strShowStatusThreads_runningDescr = 'Antallet af tråde der ikke sover.';
 $strShowTableDimension = 'Vis tabellernes dimensioner';
 $strShowTables = 'Vis tabeller';
 $strShowThisQuery = ' Vis forespørgslen her igen ';
-$strShow = 'Vis';
 $strSimplifiedChinese = 'Simplificeret Kinesisk';
 $strSingly = '(enkeltvis)';
 $strSize = 'Størrelse';
@@ -810,8 +823,9 @@ $strSort = 'Sorter';
 $strSpaceUsage = 'Pladsforbrug';
 $strSpanish = 'Spansk';
 $strSplitWordsWithSpace = 'Ord adskilles af mellemrums-karakter (" ").';
-$strSQLExportCompatibility = 'SQL eksport kompatibilitet';
+$strSQLExportCompatibility = 'SQL eksport-kompatibilitet';
 $strSQLExportType = 'Eksporttype';
+$strSQLImportOptions = 'SQL-indstillinger';
 $strSQLOptions = 'SQL-indstillinger';
 $strSQLParserBugMessage = 'Det er muligt at du har fundet en fejl i SQL-parseren. Undersøg venligst din forespørgsel nøje, og check at anførselstegn er rigtige og ikke giver konflikter. Andre fejlårsager kan være at du uploader en fil med binær udenfor et lukket tekstområde. Du kan også prøve din forespørgsel i MySQL kommandolinje-interfacet. MySQL-serverens fejlmelding der følger herunder, hvis der er nogen, kan også hjælpe dig med at finde problemet. Hvis du stadig har probemer eller hvis parseren fejler hvor kommandolinjeinterfacet lykkes, reducer din SQL-forespørgselsinput til den ene forespørgsel der forårsager problemet, og indsend en fejlrapport med datablokken i KLIP-sektionen herunder:';
 $strSQLParserUserError = 'Der ser ud til at være en fejl i din SQL-forespørgsel. MySQL-serverens fejlmelding der følger herunder, hvis der er nogen, kan også hjælpe dig med at finde problemet.';
@@ -824,10 +838,11 @@ $strSQPBugUnknownPunctuation = 'Ukendt tegnsætnings-streng';
 $strStatCheckTime = 'Sidste check';
 $strStatCreateTime = 'Oprettelse';
 $strStatement = 'Erklæringer';
+$strStatisticsOverrun = 'På en travl server er der risiko for at bytetællerne løber over, så disse statistikker som rapporteret af MySQL-serveren kan være forkerte.';
 $strStatUpdateTime = 'Sidste opdatering';
 $strStatus = 'Status';
-$strStorageEngine = 'Datalager';
 $strStorageEngines = 'Datalagre';
+$strStorageEngine = 'Datalager';
 $strStrucCSV = 'CSV-data';
 $strStrucData = 'Struktur og data';
 $strStrucDrop = 'Tilføj DROP TABLE';
@@ -861,6 +876,11 @@ $strTblPrivileges = 'Tabel-specifikke privilegier';
 $strTempData = 'Midlertidige data';
 $strTextAreaLength = ' På grund af feltets længde,<br /> kan det muligvis ikke ændres ';
 $strThai = 'Thai';
+$strThemeDefaultNotFound = 'Standardtema %s ikke fundet!';
+$strThemeNoPreviewAvailable = 'Intet billede til rådighed.';
+$strThemeNotFound = 'Tema %s ikke fundet!';
+$strThemeNoValidImgPath = 'Ingen gyldig billedsti for tema %s fundet!';
+$strThemePathNotFound = 'Sti til tema ikke fundet for tema %s!';
 $strTheme = 'Tema / Layout';
 $strThisHost = 'Denne Host';
 $strThisNotDirectory = 'Dette var ikke en mappe';
@@ -908,15 +928,16 @@ $strUpgrade = 'Du burde opdatere til %s %s eller senere.';
 $strUploadLimit = 'Du har sandsynligvis forsøgt at uploade en for stor fil. Se venligst %sdokumentationen%s for måder hvorpå du kan arbejde dig uden om denne begrænsning.';
 $strUsage = 'Benyttelse';
 $strUseBackquotes = 'Brug "backquotes" omkring tabeller og felters navne';
+$strUsedPhpExtensions = 'Brugte PHP-udvidelser';
 $strUseHostTable = 'Brug Host Tabel';
 $strUserAlreadyExists = 'Brugeren %s findes i forvejen!';
-$strUser = 'Bruger';
 $strUserEmpty = 'Intet brugernavn!';
 $strUserName = 'Brugernavn';
 $strUserNotFound = 'Den valgte bruger blev ikke fundet i privilegietabellen.';
 $strUserOverview = 'Brugeroversigt';
 $strUsersDeleted = 'De valgte brugere er blevet korrekt slettet.';
 $strUsersHavingAccessToDb = 'Brugere med adgang til &quot;%s&quot;';
+$strUser = 'Bruger';
 $strUseTabKey = 'Brug TAB tasten for at flytte dig fra værdi til værdi, eller CTRL+piletasterne til at flytte frit omkring';
 $strUseTables = 'Benyt tabeller';
 $strUseTextField = 'Brug tekstfelt';
@@ -931,6 +952,7 @@ $strViewDumpDatabases = 'Vis dump (skema) for databaser';
 $strViewDumpDB = 'Vis dump (skema) af database';
 $strViewDump = 'Vis dump (skema) over tabel';
 $strViewHasBeenDropped = 'Visning %s er blevet droppet';
+$strViewMaxExactCount = 'Denne visning har mere end %d rækker. Se venligst %sdokumentationen%s.';
 $strView = 'Visning';
 
 $strWebServerUploadDirectoryError = 'Mappen du har sat til upload-arbejde kan ikke findes';
@@ -951,5 +973,4 @@ $strYes = 'Ja';
 
 $strZeroRemovesTheLimit = 'Bemærk: Indstilling af disse værdier til 0 (nul) fjerner begrænsningen.';
 $strZip = '"zippet"';
-
 ?>
