@@ -1,5 +1,5 @@
 <?php
-/* $Id: dutch-utf-8.inc.php,v 2.101 2005/10/30 10:03:49 nijel Exp $ */
+/* $Id: dutch-utf-8.inc.php,v 2.123.2.3 2006/03/23 17:42:12 lem9 Exp $ */
 
 /*
  * Updated by "CaliMonk" <calimonk at gmx.net> on 2005/01/04.
@@ -216,7 +216,6 @@ $strDoYouReally = 'Weet u zeker dat u dit wilt ';
 $strDocu = 'Documentatie';
 $strDrop = 'Verwijderen';
 $strDropDatabaseStrongWarning = 'U staat op het punt een complete database te DESTROY-en!';
-$strDropSelectedDatabases = 'Geselecteerde databases verwijderen';
 $strDropUsersDb = 'Verwijder de databases die dezelfde naam hebben als de gebruikers.';
 $strDumpSaved = 'Dump is bewaard als %s.';
 $strDumpXRows = '%s rijen aan het dumpen, start bij rij %s.';
@@ -258,7 +257,6 @@ $strFieldsTerminatedBy = 'Velden beëindigd door';
 $strFileAlreadyExists = 'Bestaand %s bestaat al op de server, verander de bestandsnaam of controleer overschrijf opties.';
 $strFileCouldNotBeRead = 'Bestand kon niet worden gelezen';
 $strFileNameTemplate = 'File naam template';
-$strFileNameTemplateHelp = 'Gebruik __DB__ voor de database naam, __TABLE__ voor tabel naam en %salle strftime%s opties voor tijd specificaties, extensies zullen automatisch worden bijgevoegd. Elke andere tekst zal worden bewaard.';
 $strFileNameTemplateRemember = 'Onthoud template';
 $strFixed = 'vast';
 $strFlushPrivilegesNote = 'Opmerking: phpMyAdmin krijgt de rechten voor de gebruikers uit de MySQL privileges tabel. De content van deze tabel kan verschillen met de rechten van de server als er handmatig aanpassingen zijn aangebracht. Mocht dit het geval zijn dan moet men %sde privilege tabel vernieuwen%s voordat men verder gaat.';
@@ -300,7 +298,6 @@ $strIgnoreInserts = 'Gebruik ignore inserts';
 $strIgnoringFile = 'Negeer bestand %s';
 $strImportDocSQL = 'Importeer docSQL Bestanden';
 $strImportFiles = 'Importeren bestanden';
-$strImportFinished = 'Importeren voltooid';
 $strInUse = 'in gebruik';
 $strIndex = 'Index';
 $strIndexHasBeenDropped = 'Index %s is vervallen';
@@ -380,9 +377,7 @@ $strMoveTableSameNames = 'Kan de tabel niet naar dezelfde verplaatsen!';
 $strMultilingual = 'meertalig';
 $strMySQLCharset = 'MySQL Karakterset';
 $strMySQLConnectionCollation = 'MySQL verbindingscollatie';
-$strMySQLReloaded = 'MySQL opnieuw geladen.';
 $strMySQLSaid = 'MySQL retourneerde: ';
-$strMySQLServerProcess = 'MySQL %pma_s1% draait op %pma_s2% als %pma_s3%';
 $strMySQLShowProcess = 'Laat processen zien';
 $strMySQLShowStatus = 'MySQL runtime informatie';
 $strMySQLShowVars = 'MySQL systeemvariabelen';
@@ -516,7 +511,6 @@ $strRelationView = 'Relatie overzicht';
 $strRelationalSchema = 'Relationeel schema';
 $strRelations = 'Relaties';
 $strRelationsForTable = 'RELATIES VOOR TABEL';
-$strReloadFailed = 'Opnieuw laden van MySQL mislukt.';
 $strReloadMySQL = 'MySQL opnieuw laden.';
 $strReloadingThePrivileges = 'Bezig de privileges te vernieuwen';
 $strRemoveSelectedUsers = 'Verwijder de geselecteerde gebruikers';
@@ -803,7 +797,6 @@ $strImportFormat = 'Format of imported file';  //to translate
 $strFileToImport = 'File to import';  //to translate
 $strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
 $strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
-$strEnclosingOptional = 'Enclosing of fields is optional';  //to translate
 $strCSVImportOptions = 'CSV options';  //to translate
 $strPartialImport = 'Partial import';  //to translate
 $strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
@@ -815,7 +808,6 @@ $strNothingToImport = 'You didn\'t enter any data to import!';  //to translate
 $strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
 $strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
 $strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
-$strInvalidCSVInput = 'Invalid CSV input, could not parse!';  //to translate
 $strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
 $strErrorInZipFile = 'Error in ZIP archive:';  //to translate
 $strFlushQueryCache = 'Flush query cache';  //to translate
@@ -956,4 +948,34 @@ $strBookmarkCreated = 'Bookmark %s created';  //to translate
 $strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
 $strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
 $strEsperanto = 'Esperanto';  //to translate
+$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate
+$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
+$strFileNameTemplateDescriptionTable = 'table name';  //to translate
+$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
+$strFileNameTemplateDescriptionServer = 'server name';  //to translate
+$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
+$strProtocolVersion = 'Protocol version';  //to translate
+$strMysqlClientVersion = 'MySQL client version';  //to translate
+$strUsedPhpExtensions = 'Used PHP extensions';  //to translate
+$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
+$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
+$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
+$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
+$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
+$strPDF = 'PDF';  //to translate
+$strPDFOptions = 'PDF options';  //to translate
+$strPDFReportTitle = 'Report title';  //to translate
+$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
+$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
+$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
+$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
+$strThemeNotFound = 'Theme %s not found!';  //to translate
+$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
+$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
+$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
+$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
+$strSQLImportOptions = 'SQL options';  //to translate
+$strBrowseDistinctValues = 'Browse distinct values';  //to translate
+$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
+$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
 ?>
