@@ -1,5 +1,5 @@
 <?php
-/* $Id: french-utf-8.inc.php,v 2.128.2.2 2005/12/02 17:58:40 lem9 Exp $ */
+/* $Id: french-utf-8.inc.php,v 2.152.2.2 2006/03/23 17:42:12 lem9 Exp $ */
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
@@ -22,6 +22,7 @@ $timespanfmt = '%s jours, %s heures, %s minutes et %s secondes';
 $strAbortedClients = 'Arrêts prématurés';
 $strAbsolutePathToDocSqlDir = 'Veuillez entrer le chemin absolu du répertoire docSQL sur le serveur web';
 $strAccessDenied = 'Accès refusé';
+$strAccessDeniedCreateConfig = 'La raison probable est que vous n\'avez pas créé de fichier de configuration. Vous pouvez utiliser le %1$sscript de configuration%2$s dans ce but.';
 $strAccessDeniedExplanation = 'phpMyAdmin a tenté de se connecter au serveur MySQL, et le serveur a rejeté la connexion. Veuillez vérifier les valeurs de "host", "username" et "password" dans config.inc.php et vous assurer qu\'elles correspondent aux informations fournies par l\'administrateur du serveur MySQL.';
 $strAction = 'Action';
 $strAddAutoIncrement = 'Inclure la valeur courante de l\'AUTO_INCREMENT';
@@ -93,6 +94,7 @@ $strBookmarkReplace = 'Remplacer un signet existant du même nom';
 $strBookmarkThis = 'Conserver cette requête dans les signets';
 $strBookmarkView = 'Voir uniquement';
 $strBrowse = 'Afficher';
+$strBrowseDistinctValues = 'Affiche les valeurs distinctes';
 $strBrowseForeignValues = 'Afficher les valeurs de la table liée';
 $strBufferPoolActivity = 'Activité de la mémoire-tampon';
 $strBufferPool = 'Mémoire-tampon';
@@ -147,6 +149,7 @@ $strCompatibleHashing = 'compatible MySQL&nbsp;4.0';
 $strCompleteInserts = 'Insertions complètes';
 $strCompression = 'Compression';
 $strCompressionWillBeDetected = 'Ces modes de compression seront détectés automatiquement : %s';
+$strConfigDefaultFileError = 'Chargement de la configuration par défaut impossible depuis "%1$s"';
 $strConfigFileError = 'phpMyAdmin n\'a pu lire votre fichier de configuration!<br />Il est possible qu\'il contienne une erreur de syntaxe, ou que PHP soit incapable de le trouver<br />À l\'aide du lien suivant, vous pouvez vérifier le message d\'erreur généré par PHP;<br />la plupart du temps, un apostrophe ou un point-virgule sont manquants.<br />Si vous recevez une page blanche, aucune erreur n\'a été détectée.';
 $strConfigureTableCoord = 'Les coordonnées de la table %s n\'ont pas été configurées';
 $strConnectionError = 'Connexion impossible: réglages incorrects.';
@@ -234,7 +237,6 @@ $strDoAQuery = 'Recherche par valeur (passepartout: "%")';
 $strDocu = 'Documentation';
 $strDoYouReally = 'Voulez-vous vraiment effectuer ';
 $strDropDatabaseStrongWarning = 'Vous êtes sur le point de DÉTRUIRE une base de données!';
-$strDropSelectedDatabases = 'Supprimer les bases de données sélectionnées';
 $strDrop = 'Supprimer';
 $strDropUsersDb = 'Supprimer les bases de données portant le même nom que les utilisateurs';
 $strDumpingData = 'Contenu de la table';
@@ -250,7 +252,6 @@ $strEmptyResultSet = 'MySQL n\'a retourné aucun enregistrement.';
 $strEmpty = 'Vider';
 $strEnabled = 'activé';
 $strEncloseInTransaction = 'Utiliser le mode transactionnel';
-$strEnclosingOptional = 'Il est optionnel d\'entourer les champs';
 $strEndCut = 'Fin de la section à couper';
 $strEnd = 'Fin';
 $strEndRaw = 'Fin des informations sur l\'anomalie';
@@ -283,7 +284,10 @@ $strFieldsEscapedBy = 'Caractère spécial';
 $strFieldsTerminatedBy = 'Champs terminés par';
 $strFileAlreadyExists = 'Le fichier %s existe déjà sur le serveur, veuillez changer le nom, ou cocher l\'option Écraser';
 $strFileCouldNotBeRead = 'Le fichier n\'a pu être lu';
-$strFileNameTemplateHelp = 'Utilisez __DB__ comme nom de base, __TABLE__ comme nom de table et %stoute option valide de strftime%s comme indicateur de date/heure, le suffixe sera ajouté automatiquement. Tout autre texte sera préservé.';
+$strFileNameTemplateDescription = 'Cette valeur est interprétée avec %1$sstrftime%2$s, vous pouvez donc utiliser des chaînes de format d\'heure. Ces transformations additionnelles vont se produire: %3$s. Tout autre texte sera conservé tel quel.';
+$strFileNameTemplateDescriptionDatabase = 'nom de base de données';
+$strFileNameTemplateDescriptionServer = 'nom de serveur';
+$strFileNameTemplateDescriptionTable = 'nom de table';
 $strFileNameTemplate = 'Modèle de nom de fichier';
 $strFileNameTemplateRemember = 'se souvenir du modèle';
 $strFileToImport = 'Fichier à importer';
@@ -338,9 +342,9 @@ $strIgnoreInserts = 'Ignorer les erreurs de doublons (INSERT IGNORE)';
 $strIgnoringFile = 'Fichier %s ignoré';
 $strImportDocSQL = 'Importer des fichiers docSQL';
 $strImportFiles = 'Importe les fichiers';
-$strImportFinished = 'Importation terminée avec succès.';
 $strImportFormat = 'Format du fichier d\'importation';
 $strImport = 'Importer';
+$strImportSuccessfullyFinished = 'L\'importation s\'est terminée avec succès, %d requêtes exécutées.';
 $strIndexes = 'Index';
 $strIndexHasBeenDropped = 'L\'index %s a été effacé';
 $strIndex = 'Index';
@@ -371,11 +375,15 @@ $strInUse = 'utilisé';
 $strInvalidAuthMethod = 'Le fichier de configuration contient un type d\'authentification invalide :';
 $strInvalidColumnCount = 'Le nombre de champs doit être plus grand que zéro.';
 $strInvalidColumn = 'La colonne %s est invalide!';
-$strInvalidCSVInput = 'Impossible d\'analyser ces données CSV!';
+$strInvalidCSVFieldCount = 'Nombre de champs invalide dans les données CSV à la ligne %d';
+$strInvalidCSVFormat = 'Format invalide pour les données CSV à la ligne %d.';
+$strInvalidCSVParameter = 'Paramètres invalides pour l\'importation CSV: %s';
 $strInvalidFieldAddCount = 'Vous devez ajouter au moins un champ';
 $strInvalidFieldCount = 'La table doit comporter au moins un champ';
 $strInvalidLDIImport = 'Ce greffon ne supporte pas les importations en format comprimé!';
 $strInvalidRowNumber = '%d n\'est pas un numéro d\'enregistrement valable.';
+$strInvalidServerHostname = 'Nom d\'hôte (hostname) invalide pour le serveur %1$s. Veuillez vérifier votre configuration.';
+$strInvalidServerIndex = 'Indice de serveur invalide: "%s"';
 
 $strJapanese = 'japonais';
 $strJoins = 'Jointures';
@@ -390,6 +398,8 @@ $strKill = 'Supprimer';
 $strKorean = 'coréen';
 
 $strLandscape = 'Paysage';
+$strLanguageFileNotFound = 'Fichier de langue "%1$s" inexistant.';
+$strLanguageUnknown = 'Langue inconnue: %1$s.';
 $strLatchedPages = 'Pages verrouillées';
 $strLatexCaption = 'Sous-titre de la table';
 $strLatexContent = 'Contenu de la table __TABLE__';
@@ -456,10 +466,9 @@ $strMyISAMRepairThreads = 'Nombre de fils d\'exécution pour la réparation';
 $strMyISAMSortBufferSizeDesc = 'La mémoire tampon qui est allouée pour trier les index MyISAM durant une opération REPAIR TABLE ou pour créer les index lors d\'un CREATE INDEX ou ALTER TABLE';
 $strMyISAMSortBufferSize = 'Taille de la mémoire tampon';
 $strMySQLCharset = 'Jeu de caractères pour MySQL';
+$strMysqlClientVersion = 'Version du client MySQL';
 $strMySQLConnectionCollation = 'Interclassement pour la connexion MySQL';
-$strMySQLReloaded = 'MySQL rechargé.';
 $strMySQLSaid = 'MySQL a répondu:';
-$strMySQLServerProcess = 'MySQL %pma_s1% sur le serveur %pma_s2% - utilisateur&nbsp;: %pma_s3%';
 $strMySQLShowProcess = 'Afficher les processus';
 $strMySQLShowStatus = 'Afficher l\'état du serveur';
 $strMySQLShowVars = 'Afficher les variables du serveur';
@@ -503,6 +512,7 @@ $strNumSearchResultsTotal = '<b>Total :</b> <i>%s</i> occurence(s)';
 $strNumTables = 'Tables';
 
 $strOK = 'OK';
+$strOpenNewWindow = 'Ouvrir une nouvelle fenêtre phpMyAdmin';
 $strOperations = 'Opérations';
 $strOperator = 'Opérateur';
 $strOptimizeTable = 'Optimiser la table';
@@ -523,6 +533,9 @@ $strPasswordNotSame = 'Les mots de passe doivent être identiques';
 $strPdfDbSchema = 'Schema de la base "%s" - Page %s';
 $strPdfInvalidTblName = 'La table "%s" n\'existe pas !';
 $strPdfNoTables = 'Pas de table !';
+$strPDFOptions = 'Options PDF';
+$strPDF = 'PDF';
+$strPDFReportTitle = 'Titre du rapport';
 $strPerHour = 'par heure';
 $strPerMinute = 'par minute';
 $strPerSecond = 'par seconde';
@@ -583,6 +596,7 @@ $strPrivDescUsage = 'Pas de privilèges';
 $strPrivileges = 'Privilèges';
 $strPrivilegesReloaded = 'Les privilèges ont été rechargés.';
 $strProcesslist = 'Liste des processus';
+$strProtocolVersion = 'Version du protocole';
 $strPutColNames = 'Afficher les noms de champ en première ligne';
 
 $strQBEDel = 'Effacer';
@@ -607,7 +621,6 @@ $strRelationNotWorking = 'Certaines fonctionnalités ayant trait aux tables reli
 $strRelationsForTable = 'RELATIONS POUR LA TABLE';
 $strRelations = 'Relations';
 $strRelationView = 'Gestion des relations';
-$strReloadFailed = 'MySQL n\'a pu être rechargé.';
 $strReloadingThePrivileges = 'Chargement des privilèges en cours.';
 $strReloadMySQL = 'Recharger MySQL';
 $strRemoveSelectedUsers = 'Effacer les utilisateurs sélectionnés.';
@@ -813,6 +826,7 @@ $strSpanish = 'espagnol';
 $strSplitWordsWithSpace = 'Séparer les mots par un espace (" ").';
 $strSQLExportCompatibility = 'Compatibilité de l\'exportation';
 $strSQLExportType = 'Type d\'exportation';
+$strSQLImportOptions = 'Options SQL';
 $strSQLOptions = 'options SQL';
 $strSQLParserBugMessage = 'Il semble que vous ayiez trouvé une anomalie dans l\'analyseur syntaxique SQL. Veuillez examiner votre requête attentivement, et vérifier que vos apostrophes sont conformes. Il se pourrait aussi que vous ayiez chargé un fichier dont le contenu binaire n\'est pas entre apostrophes.  Si vous avez accès à MySQL via son interface de commande en mode ligne, vous pouvez y essayer votre requête. Le message d\'erreur présenté plus bas pourrait vous indiquer la source du problème. En dernier recours, veuillez trouver la plus courte requête possible qui cause le problème, et soumettre un rapport d\'anomalie en incluant la section à couper:';
 $strSQLParserUserError = 'Il semble qu\'il y ait une erreur dans votre requête SQL. Le message ci-bas peut vous aider à en trouver la cause.';
@@ -825,6 +839,7 @@ $strSQPBugUnknownPunctuation = 'Ponctuation invalide';
 $strStatCheckTime = 'Dernière vérification';
 $strStatCreateTime = 'Création';
 $strStatement = 'Information';
+$strStatisticsOverrun = 'Sur un serveur surchargé, la capacité des compteurs d\'octets peut être dépassée, auquel cas les statistiques rapportées par MySQL peuvent être inexactes.';
 $strStatUpdateTime = 'Dernière modification';
 $strStatus = 'État';
 $strStorageEngine = 'Moteur de stockage';
@@ -862,6 +877,11 @@ $strTblPrivileges = 'Privilèges spécifiques à une table';
 $strTempData = 'Données temporaires';
 $strTextAreaLength = 'Il est possible que ce champ<br />ne soit pas éditable<br />en raison de sa longueur';
 $strThai = 'thaï';
+$strThemeDefaultNotFound = 'Thème par défaut %s inexistant!';
+$strThemeNoPreviewAvailable = 'Prévisualisation non disponible.';
+$strThemeNotFound = 'Thème %s inexistant!';
+$strThemeNoValidImgPath = 'Chemin des images inexistant pour le thème %s!';
+$strThemePathNotFound = 'Chemin non trouvé pour le thème %s!';
 $strTheme = 'Thème / Style';
 $strThisHost = 'Ce serveur';
 $strThisNotDirectory = 'Ceci n\'est pas un répertoire';
@@ -909,6 +929,7 @@ $strUpgrade = 'Vous devriez utiliser %s en version %s ou plus récente.';
 $strUploadLimit = 'Vous avez probablement tenté de télécharger un fichier trop volumineux. Veuillez vous référer à la %sdocumentation%s pour des façons de contourner cette limite.';
 $strUsage = 'Espace';
 $strUseBackquotes = 'Protéger les noms des tables et des champs par des&nbsp;"`"';
+$strUsedPhpExtensions = 'Extensions PHP utilisées';
 $strUseHostTable = 'Utiliser la table Host';
 $strUserAlreadyExists = 'L\'utilisateur %s existe déjà!';
 $strUserEmpty = 'Le nom d\'utilisateur est vide';
@@ -932,6 +953,7 @@ $strViewDump = '<b>Afficher le schéma</b> de la table';
 $strViewDumpDatabases = 'Schéma et/ou contenu des bases de données';
 $strViewDumpDB = 'Schéma et données de la base ';
 $strViewHasBeenDropped = 'La vue %s a été supprimée';
+$strViewMaxExactCount = 'Cette vue comporte plus de %d enregistrements. Veuillez vous référer à la %sdocumentation%s.';
 $strView = 'Vue';
 
 $strWebServerUploadDirectoryError = 'Le répertoire de transfert est inaccessible';
