@@ -1,5 +1,5 @@
 <?php
-/* $Id: greek-iso-8859-7.inc.php,v 2.94 2005/10/30 10:03:49 nijel Exp $ */
+/* $Id: greek-iso-8859-7.inc.php,v 2.116.2.3 2006/03/23 17:42:13 lem9 Exp $ */
 
 /* Translated by Kyriakos Xagoraris <theremon at users.sourceforge.net> */
 
@@ -179,7 +179,6 @@ $strDoAQuery = '     (  "%")';
 $strDoYouReally = '    ';
 $strDocu = '';
 $strDrop = '';
-$strDropSelectedDatabases = '   ';  
 $strDropUsersDb = '        .'; 
 $strDumpSaved = '     %s.';  
 $strDumpXRows = ' %s      %s.'; 
@@ -218,7 +217,6 @@ $strFieldsTerminatedBy = '   ';
 $strFileAlreadyExists = '  %s    .         .';  
 $strFileCouldNotBeRead = '      ';  
 $strFileNameTemplate = '  ';
-$strFileNameTemplateHelp = ' __DB__   , __TABLE__     %s  strftime%s   .     .     .';
 $strFileNameTemplateRemember = ' ';
 $strFixed = ' ';
 $strFlushPrivilegesNote = ':  phpMyAdmin      \'       MySQL.                    .    ,    %s  %s  .'; 
@@ -256,7 +254,6 @@ $strIgnore = '';
 $strIgnoringFile = '   %s';  
 $strImportDocSQL = '  docSQL';  
 $strImportFiles = ' ';  
-$strImportFinished = '  ';  
 $strInUse = ' ';
 $strIndex = '';
 $strIndexHasBeenDropped = '  %s ';
@@ -316,9 +313,7 @@ $strMoveTableOK = '  %s   %s.';
 $strMoveTableSameNames = '         !';  
 $strMultilingual = '';  
 $strMySQLCharset = '   MySQL';  
-$strMySQLReloaded = ' MySQL .';
 $strMySQLSaid = ' MySQL   : ';
-$strMySQLServerProcess = ' MySQL %pma_s1%   %pma_s2%  %pma_s3%';
 $strMySQLShowProcess = ' ';
 $strMySQLShowStatus = '    MySQL';
 $strMySQLShowVars = '   MySQL';
@@ -442,7 +437,6 @@ $strRelationNotWorking = '         .    ,  %s%s.';
 $strRelationView = ' ';  
 $strRelationalSchema = ' ';  
 $strRelations = '';  
-$strReloadFailed = '   MySQL .';
 $strReloadMySQL = '  MySQL';
 $strReloadingThePrivileges = ' '; 
 $strRemoveSelectedUsers = '   '; 
@@ -807,7 +801,6 @@ $strImportFormat = 'Format of imported file';  //to translate
 $strFileToImport = 'File to import';  //to translate
 $strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
 $strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
-$strEnclosingOptional = 'Enclosing of fields is optional';  //to translate
 $strCSVImportOptions = 'CSV options';  //to translate
 $strPartialImport = 'Partial import';  //to translate
 $strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
@@ -819,7 +812,6 @@ $strNothingToImport = 'You didn\'t enter any data to import!';  //to translate
 $strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
 $strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
 $strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
-$strInvalidCSVInput = 'Invalid CSV input, could not parse!';  //to translate
 $strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
 $strErrorInZipFile = 'Error in ZIP archive:';  //to translate
 $strFlushQueryCache = 'Flush query cache';  //to translate
@@ -960,4 +952,34 @@ $strBookmarkCreated = 'Bookmark %s created';  //to translate
 $strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
 $strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
 $strEsperanto = 'Esperanto';  //to translate
+$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate
+$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
+$strFileNameTemplateDescriptionTable = 'table name';  //to translate
+$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
+$strFileNameTemplateDescriptionServer = 'server name';  //to translate
+$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
+$strProtocolVersion = 'Protocol version';  //to translate
+$strMysqlClientVersion = 'MySQL client version';  //to translate
+$strUsedPhpExtensions = 'Used PHP extensions';  //to translate
+$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
+$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
+$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
+$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
+$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
+$strPDF = 'PDF';  //to translate
+$strPDFOptions = 'PDF options';  //to translate
+$strPDFReportTitle = 'Report title';  //to translate
+$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
+$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
+$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
+$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
+$strThemeNotFound = 'Theme %s not found!';  //to translate
+$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
+$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
+$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
+$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
+$strSQLImportOptions = 'SQL options';  //to translate
+$strBrowseDistinctValues = 'Browse distinct values';  //to translate
+$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
+$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
 ?>
