@@ -1,5 +1,5 @@
 <?php
-/* $Id: italian-utf-8.inc.php,v 2.101.2.2 2005/11/29 14:15:02 lem9 Exp $ */
+/* $Id: italian-utf-8.inc.php,v 2.124.2.3 2006/03/23 17:42:14 lem9 Exp $ */
 
 /**
  * translated by: Pietro Danesi <danone at users.sourceforge.net>  2002-03-29
@@ -27,6 +27,7 @@ $timespanfmt = '%s giorni, %s ore, %s minuti e %s secondi';
 $strAbortedClients = 'Fallito';
 $strAbsolutePathToDocSqlDir = 'Prego, immettere il path assoluto sul webserver alla directory di docSQL';
 $strAccessDenied = 'Accesso negato';
+$strAccessDeniedCreateConfig = 'La ragione di questo è che probabilmente non hai creato alcun file di configurazione. Potresti voler usare %1$ssetup script%2$s per crearne uno.';
 $strAccessDeniedExplanation = 'phpMyAdmin ha provato a connettersi al server MySQL, e il server ha rifiutato la connessione. Si dovrebbe controllare il nome dell\'host, l\'username e la password nel file config.inc.php ed assicurarsi che corrispondano alle informazioni fornite dall\'amministratore del server MySQL.';
 $strAction = 'Azione';
 $strAddAutoIncrement = 'Aggiungi valore AUTO_INCREMENT';
@@ -97,6 +98,7 @@ $strBookmarkQuery = 'Query SQL aggiunte ai preferiti';
 $strBookmarkReplace = 'Sostituzione dei segnalibri esistenti con lo stesso nome';
 $strBookmarkThis = 'Aggiungi ai preferiti questa query SQL';
 $strBookmarkView = 'Visualizza solo';
+$strBrowseDistinctValues = 'Nviga tra i valori DISTINCT';
 $strBrowseForeignValues = 'Sfoglia le opzioni straniere';
 $strBrowse = 'Mostra';
 $strBufferPoolActivity = 'Attività del Buffer Pool';
@@ -152,6 +154,7 @@ $strCompatibleHashing = 'Compatibile con MySQL&nbsp;4.0';
 $strCompleteInserts = 'Inserimenti completi';
 $strCompression = 'Compressione';
 $strCompressionWillBeDetected = 'Il tipo di compressione del file importato sarà automaticamente rilevato da: %s';
+$strConfigDefaultFileError = 'Non posso leggere la configurazione da: "%1$s"';
 $strConfigFileError = 'phpMyAdmin non riesce a leggere il file di configurazione!<br />Questo può accadere se il php trova un parse error in esso oppure il php non trova il file.<br />Richiamate il file di configurazione direttamente utilizzando il link sotto e leggete il/i messaggio/i di errore del php che ricevete. Nella maggior parte dei casi ci sono un apostrofo o una virgoletta mancanti.<br />Se ricevete una pagina bianca, allora è tutto a posto.';
 $strConfigureTableCoord = 'Prego, configurare le coordinate per la tabella %s';
 $strConnectionError = 'Impossibile connettersi: impostazioni non valide.';
@@ -240,7 +243,6 @@ $strDocu = 'Documentazione';
 $strDoYouReally = 'Confermi: ';
 $strDropDatabaseStrongWarning = 'Si sta per DISTRUGGERE COMPLETAMENTE un intero DataBase!';
 $strDrop = 'Elimina';
-$strDropSelectedDatabases = 'Cancella i database selezionati';
 $strDropUsersDb = 'Elimina i databases gli stessi nomi degli utenti.';
 $strDumpingData = 'Dump dei dati per la tabella';
 $strDumpSaved = 'Il dump è stato salvato sul file %s.';
@@ -255,7 +257,6 @@ $strEmptyResultSet = 'MySQL ha restituito un insieme vuoto (i.e. zero righe).';
 $strEmpty = 'Svuota';
 $strEnabled = 'Abilitata';
 $strEncloseInTransaction = 'Includi export in una transazione';
-$strEnclosingOptional = 'L\'inclusione dei campi è opzionale';
 $strEndCut = 'FINE CUT';
 $strEnd = 'Fine';
 $strEndRaw = 'FINE RAW';
@@ -287,8 +288,11 @@ $strFieldsEnclosedBy = 'Campo composto da';
 $strFieldsEscapedBy = 'Campo impedito da';
 $strFieldsTerminatedBy = 'Campo terminato da';
 $strFileAlreadyExists = 'Il file %s esiste già sul server: prego, cambiare nome del file o selezionare l\'opzione "sovrascrivi".';
-$strFileCouldNotBeRead = 'Il filenon può essere letto';
-$strFileNameTemplateHelp = 'Usare __DB__ per i nomi dei database, __TABLE__ per i nomi delle tabelle e %sany strftime%s opzione per le specifiche temporali, le estensioni saranno automaticamente aggiunte . Tutto il resto del testo verrà preservato.';
+$strFileCouldNotBeRead = 'Il file non può essere letto';
+$strFileNameTemplateDescriptionDatabase = 'nome database';
+$strFileNameTemplateDescription = 'Questo valore è interpretato usando %1$sstrftime%2$s, in questo modo puoi usare stringhe di formattazione per le date/tempi. Verranno anche aggiunte le seguenti trasformazioni: %3$s. Il testo rimanente resterà invariato.';
+$strFileNameTemplateDescriptionServer = 'nome server';
+$strFileNameTemplateDescriptionTable = 'nome tabella';
 $strFileNameTemplate = 'Nome file template';
 $strFileNameTemplateRemember = 'ricorda il template';
 $strFileToImport = 'File importato';
@@ -343,9 +347,9 @@ $strIgnoreInserts = 'Utilizza gli IGNORE INSERTS';
 $strIgnoringFile = 'File %s ignorato';
 $strImportDocSQL = 'Importa Files docSQL';
 $strImportFiles = 'Importa files';
-$strImportFinished = 'Importazione terminata';
 $strImportFormat = 'Formato del file importato';
 $strImport = 'Importa';
+$strImportSuccessfullyFinished = 'Importazione eseguita con successo, %d queries eseguite.';
 $strIndexes = 'Indici';
 $strIndexHasBeenDropped = 'L\'indice %s è stato eliminato';
 $strIndex = 'Indice';
@@ -376,11 +380,15 @@ $strInUse = 'in uso';
 $strInvalidAuthMethod = 'Metodo di autenticazione settato nella configurazione non valido:';
 $strInvalidColumn = 'Colonna specificata (%s) invalida!';
 $strInvalidColumnCount = 'Il contatore delle colonne deve essere superiore a 0.';
-$strInvalidCSVInput = 'CSV input non valido, impossibile processarlo!';
-$strInvalidFieldAddCount = 'Devi aggiungere come minimo un campo.';
+$strInvalidCSVFieldCount = 'Contatore di campo non valido nell\'input CSV alla linea %d.';
+$strInvalidCSVFormat = 'Formato non valido per l\'input CSV alla linea %d.';
+$strInvalidCSVParameter = 'Parametro non valido per importazione CSV: %s';
+$strInvalidFieldAddCount = 'Deviaggiungere come minimo un campo.';
 $strInvalidFieldCount = 'la tabella deve avere come minimo un dato.';
 $strInvalidLDIImport = 'Questo plugin non supporta importazioni di dati compressi!';
 $strInvalidRowNumber = '%d non è un numero valido di righe.';
+$strInvalidServerHostname = 'Nome host per il server %1$s non valido. Controlla la tua configurazione.';
+$strInvalidServerIndex = 'Server index non valido: "%s"';
 
 $strJapanese = 'Giapponese';
 $strJoins = 'Joins';
@@ -395,6 +403,8 @@ $strKill = 'Rimuovi';
 $strKorean = 'Coreano';
 
 $strLandscape = 'Orizzontale';
+$strLanguageFileNotFound = 'File di lingua "%1$s" non trovato.';
+$strLanguageUnknown = 'Lingua non conosciuta : %1$s.';
 $strLatchedPages = 'Latched pages';
 $strLatexCaption = 'Sottotitolo della tabella';
 $strLatexContent = 'Contenuto della tabella __TABLE__';
@@ -461,10 +471,9 @@ $strMyISAMRepairThreads = 'Thread di riparazione';
 $strMyISAMSortBufferSizeDesc = 'Il buffer che viene allocato nell\'ordinamento degli indici MyISAM durante un REPAIR TABLE o nella creazione degli indici con CREATE INDEX o ALTER TABLE.';
 $strMyISAMSortBufferSize = 'Ordina la dimensione del buffer';
 $strMySQLCharset = 'Set di caratteri MySQL';
+$strMysqlClientVersion = 'Versione MySQL client';
 $strMySQLConnectionCollation = 'collazione della connessione di MySQL';
-$strMySQLReloaded = 'MySQL riavviato.';
 $strMySQLSaid = 'Messaggio di MySQL: ';
-$strMySQLServerProcess = 'MySQL %pma_s1% in esecuzione su %pma_s2% come %pma_s3%';
 $strMySQLShowProcess = 'Visualizza processi in esecuzione';
 $strMySQLShowStatus = 'Visualizza informazioni di runtime di MySQL';
 $strMySQLShowVars = 'Visualizza variabili di sistema di MySQL';
@@ -495,7 +504,7 @@ $strNoRowsSelected = 'Nessuna riga selezionata';
 $strNoSpace = 'Spazio insufficiente per salvare il file %s.';
 $strNoTablesFound = 'Non ci sono tabelle nel database.';
 $strNoThemeSupport = 'Nessun supporto per i temi, si prega di controllare la configurazione e/o i temi nella cartella %s.';
-$strNothingToImport = 'Non hai inserito alcun dato da importare!';
+$strNothingToImport = 'Non hai inserito alcun dato da importare';
 $strNotNumber = 'Questo non è un numero!';
 $strNotOK = 'non OK';
 $strNotSet = '<b>%s</b> tabella non trovata o non settata in %s';
@@ -508,6 +517,7 @@ $strNumSearchResultsTotal = '<b>Totale:</b> <i>%s</i> corrispondenza/e';
 $strNumTables = 'Tabelle';
 
 $strOK = 'OK';
+$strOpenNewWindow = 'Apri una nuova finestra di PhpMyAdmin';
 $strOperations = 'Operazioni';
 $strOperator = 'Operatore';
 $strOptimizeTable = 'Ottimizza tabella';
@@ -528,6 +538,9 @@ $strPassword = 'Password';
 $strPdfDbSchema = 'Schema del database "%s" - Pagina %s';
 $strPdfInvalidTblName = 'La tabella "%s" non esiste!';
 $strPdfNoTables = 'Nessuna Tabella';
+$strPDFOptions = 'Opzioni PDF';
+$strPDF = 'PDF';
+$strPDFReportTitle = 'Titolo del Report';
 $strPerHour = 'all\'ora';
 $strPerMinute = 'al minuto';
 $strPerSecond = 'al secondo';
@@ -588,6 +601,7 @@ $strPrivDescUsage = 'Nessun privilegio.';
 $strPrivileges = 'Privilegi';
 $strPrivilegesReloaded = 'I privilegi sono stati ricaricati con successo.';
 $strProcesslist = 'Lista Processi';
+$strProtocolVersion = 'Versione protocollo';
 $strPutColNames = 'Mette i nomi delle colonne alla prima riga';
 
 $strQBEDel = 'Cancella';
@@ -612,7 +626,6 @@ $strRelationNotWorking = 'Le caratteristiche aggiuntive sono state disattivate p
 $strRelationsForTable = 'RELATIONS FOR TABLE';
 $strRelations = 'Relazioni';
 $strRelationView = 'Vedi relazioni';
-$strReloadFailed = 'Riavvio di MySQL fallito.';
 $strReloadingThePrivileges = 'Caricamento dei privilegi in corso';
 $strReloadMySQL = 'Riavvia MySQL';
 $strRemoveSelectedUsers = 'Rimuove gli utenti selezionati';
@@ -698,14 +711,14 @@ $strShowStatusBinlog_cache_useDescr = 'Il numero delle transazioni che usano la
 $strShowStatusCreated_tmp_disk_tablesDescr = 'Il numero delle tabelle temporanee create automaticamente sul disco dal server mentre esegue i comandi. Se il valore Created_tmp_disk_tables è grande, potresti voler aumentare il valore tmp_table_size, per fare im modo che le tabelle temporanee siano memory-based anzichè disk-based.';
 $strShowStatusCreated_tmp_filesDescr = 'Numero di files temporanei che mysqld ha creato.';
 $strShowStatusCreated_tmp_tablesDescr = 'Il numero di tabelle temporanee create automaticamente in memoria dal server durante l\'esecuzione dei comandi.';
-$strShowStatusDelayed_errorsDescr = 'Numero di righe scritte con INSERT DELAYED in cui ci sono stati degli errori (probabilmente chiave duplicata).';
+$strShowStatusDelayed_errorsDescr = 'Numero di righe scritte con INSERT DELAYED in cui ci sono stati degli errori (probabilmete chiave dublicata).';
 $strShowStatusDelayed_insert_threadsDescr = 'Il numero di processi INSERT DELAYED in uso. Ciascuna tabella su cui è usato INSERT DELAYED occupa un thread.';
 $strShowStatusDelayed_writesDescr = 'Il numero di righe INSERT DELAYED scritte.';
 $strShowStatusFlush_commandsDescr  = 'Il numero di comandi FLUSH eseguiti.';
 $strShowStatusHandler_commitDescr = 'Il numero di comandi interni COMMIT eseguiti.';
 $strShowStatusHandler_deleteDescr = 'Il numero di volte in cui una riga è stata cancellata da una tabella.';
-$strShowStatusHandler_discoverDescr = 'Il server MySQL può chiedere al motore di storage NDB Cluster se conosce una tabella sulla base di un nome dato. Questo è chiamato discovery. Handler_discover indica il numero di volte che una tabella è stata trovata.';
-$strShowStatusHandler_read_firstDescr = 'Il numero di volte che il primo valore è stato letto da un indice. Se è troppo alto è probabile che il server stia facendo molte scansioni complete degli indici; per esempio, SELECT col1 FROM foo, assumendo che col1 sia indicizzata.';
+$strShowStatusHandler_discoverDescr = 'Il server MySQL può chiedere al motore di storage NDB Cluster se conosce una tabella sulla base di un nome dato. Questo è chaiamto discovery. Handler_discover indica il numero di volte che una tabella è stata trovata.';
+$strShowStatusHandler_read_firstDescr = 'Il numero di volte che il primo valore è stato letto da un indice. Se è troppo alto è probabile che il server stia facendo molte scansioni complete degli indici; per esempio, SELECT col1 FROM foo, assumento che col1 sia indicizzata.';
 $strShowStatusHandler_read_keyDescr = 'Il numero di richieste per leggere una riga basata su di una chiave. Se è alta, è un buon indice che le tue query e le tue tabelle sono correttamente indicizzate.';
 $strShowStatusHandler_read_nextDescr = 'Il numero di richieste per leggere la riga successiva nell\'ordine delle chiavi. Questo valore è incrementato se stai facendo una query su di una colonna indice con un range costante, oppure se stai facendo una scansione degli indici.';
 $strShowStatusHandler_read_prevDescr = 'Il numero di richieste per leggere la riga precedente nell\'ordine delle chiavi. Questo metodo di lettura è principalmente utilizzato per ottimizzare ORDER BY ... DESC.';
@@ -718,14 +731,14 @@ $strShowStatusInnodb_buffer_pool_pages_dataDescr = 'Il numero di pagine che cont
 $strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'Il numero di pagine attualmente sporche.';
 $strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'Il numero di buffer pool pages che hanno avuto richiesta di essere aggiornate.';
 $strShowStatusInnodb_buffer_pool_pages_freeDescr = 'Il numero di pagine libere.';
-$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'Il numero di pagine bloccate in un InnoDB buffer pool. Queste pagine sono attualmente in lettura o in scrittura e non possono essere aggiornate o rimosse per altre ragioni.';
+$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'Il numero di pagine bloccate in un InnoDB buffer pool. Queste pagine sono attualmente in lettura o in scittura e non possono essere aggiornate o rimosse per altre ragioni.';
 $strShowStatusInnodb_buffer_pool_pages_miscDescr = 'Il numero di pagine occupate perchè sono state allocate per amministrazione, come row locks o per hash index adattivi. Questo valore può essere calcolato come Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';
 $strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Il numero totale di buffer pool, in pagine.';
 $strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'Il numero di read-aheads "random" InnoDB iniziate. Questo accade quando una query legge una porzione di una tabella, ma in ordine casuale.';
 $strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'Il numero di read-aheads InnoDB sequanziali. Questo accade quando InnoDB esegue una scansione completa sequenziale di una tabella.';
 $strShowStatusInnodb_buffer_pool_read_requestsDescr = 'Il numero di richieste logiche che InnoDb ha fatto.';
 $strShowStatusInnodb_buffer_pool_readsDescr = 'Il numero di richieste logiche che InnoDB non può soddisfare dal buffer pool e che devono fare una lettura di una pagina singola.';
-$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normalmente le scritture nel buffer pool InnoDB vengono effettuate in background. Tuttavia se è necessario leggere o creare una pagina, e non sono disponibile pagine pulite è necessario attendere che le pagine siano aggiornate prima. Questo contatore conta le istanze di queste attese. Se la dimensione del buffer pool è stata settata correttamente questo valore dovrebbe essere basso.';
+$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normalmente le sritture nel buffer pool InnoDB vengono effettuate in background. Tuttavia se è necessario leggere o creare una pagina, e non sono disponibile pagine pulite è necessario attendere che le pagine siano aggiornate prima. Questo contatore conta le istanze di queste attese. Se la dimesione del buffer pool è stata settata correttamente questo valore dovrebbe essere basso.';
 $strShowStatusInnodb_buffer_pool_write_requestsDescr = 'Il numero di scritture effettuate nel buffer pool InnoDB.';
 $strShowStatusInnodb_data_fsyncsDescr = 'Il numero delle operazioni fsync() fino ad ora.';
 $strShowStatusInnodb_data_pending_fsyncsDescr = 'Il numero di operazioni fsync() in attesa.';
@@ -745,7 +758,7 @@ $strShowStatusInnodb_os_log_pending_fsyncsDescr = 'Il numero degli fsyncs in sos
 $strShowStatusInnodb_os_log_pending_writesDescr = 'Il numero di scritture in sospeso sul log file.';
 $strShowStatusInnodb_os_log_writtenDescr = 'Il numero di bytes scritti sul log file.';
 $strShowStatusInnodb_pages_createdDescr = 'Il numero di pagine create.';
-$strShowStatusInnodb_page_sizeDescr = 'La dimensione di-compilazione delle pagine InnoDB (default 16KB). Molti valori sono conteggiati nelle pagine; la dimensione delle pagine permette di convertirli facilmente in bytes.';
+$strShowStatusInnodb_page_sizeDescr = 'La dimesione di-compilazione delle pagine InnoDB (default 16KB). Molti valori sono conteggiati nelle pagine; la dimesione delle pagine permette di convertirli facilmente in bytes.';
 $strShowStatusInnodb_pages_readDescr = 'Il numero di pagine lette.';
 $strShowStatusInnodb_pages_writtenDescr = 'Il numero di pagine scritte.';
 $strShowStatusInnodb_row_lock_current_waitsDescr = 'Il numero di row locks attualmente in attesa.';
@@ -757,11 +770,11 @@ $strShowStatusInnodb_rows_deletedDescr = 'Il numero di righe cancellate da una t
 $strShowStatusInnodb_rows_insertedDescr = 'Il numero di righe inserite da una tabella InnoDB.';
 $strShowStatusInnodb_rows_readDescr = 'Il numero di righe lette da una tabella InnoDB.';
 $strShowStatusInnodb_rows_updatedDescr = 'Il numero di righe aggiornate da una tabella InnoDB.';
-$strShowStatusKey_blocks_not_flushedDescr = 'Il numero di blocchi chiave aggiunti nella cache chiave che sono stati cambiati, ma che non sono stai aggiornati su disco. E\' conosciuto con il nome di Not_flushed_key_blocks.';
+$strShowStatusKey_blocks_not_flushedDescr = 'Il numero di blocchi chaive aggiunti nella cache chiave che sono stati cambiati, ma che non sono stai aggiornati su disco. E\' conosciuto con il nome di Not_flushed_key_blocks.';
 $strShowStatusKey_blocks_unusedDescr = 'Il numero di blocchi non usati nella cache chiave. Puoi usare questo valore per determinare quanta cache chiave è in uso.';
-$strShowStatusKey_blocks_usedDescr = 'Il numero di blocchi usati nella cache chiave. Questo valore è un\'importante segnale che indica il numero massimo di blocchi che sono stati in uso contemporaneamente.';
-$strShowStatusKey_read_requestsDescr = 'Il numero di richieste per leggere un blocco chiave dalla cache.';
-$strShowStatusKey_readsDescr = 'Il numero di letture fisiche dal disco di un blocco chiave. Se Key_reads è grande allora il valore key_buffer_size è probabilmente troppo piccolo. Il rapporto di cache miss rate può essere calcolato come Key_reads/Key_read_requests.';
+$strShowStatusKey_blocks_usedDescr = 'Il numero di blocchi usati nella cache chiave. The number of used blocks in the key cache. Questo valore è un\'importante segnale che indica il numero massimo di blocchi che sono stati in uso contemporaneamente.';
+$strShowStatusKey_read_requestsDescr = 'Il numero di richieste per le ggere un blocco chiave dalla cache.';
+$strShowStatusKey_readsDescr = 'Il numero di letture fisiche dal disco di un blocco chiave. Se Key_reads è grande allora il valore key_buffer_size è probabilmente troppo piccolo. IIl rapporto di cache miss rate può essere calcolato come Key_reads/Key_read_requests.';
 $strShowStatusKey_write_requestsDescr = 'Il numero di richieste per scrivere una blocco chiave nella cache.';
 $strShowStatusKey_writesDescr = 'Il numero di scritture fisiche di un blocco chiave sul disco.';
 $strShowStatusLast_query_costDescr = 'Il costo totale dell\'ultima query compilata così come computato dall\'ottimizzatore delle query. Utile per comparare il costo di differenti query per la stessa operazione di query. Il valore di default è 0, che significa che nessuna query è stata ancora compilata.';
@@ -790,7 +803,7 @@ $strShowStatusSlave_retried_transactionsDescr = 'Numero totale di volte (dalla p
 $strShowStatusSlave_runningDescr = 'Questa chiave è ON se questo è un server slave connesso ad un server master.';
 $strShowStatusSlow_launch_threadsDescr = 'Numero di processi che hanno impiegato più di "slow_launch_time" secondi per partire.';
 $strShowStatusSlow_queriesDescr = 'Numero di query che hanno impiegato più di "long_query_time" seconds.';
-$strShowStatusSort_merge_passesDescr = 'Il numero di passaggi di fusione che l\'algoritmo di ordinamento ha dovuto fare. Se questo valore è grande, dovresti incrementare la variabile di sistema sort_buffer_size.';
+$strShowStatusSort_merge_passesDescr = 'Il numero di fusioni passate all\'algoritmo di ordianemento che sono state fatte. Se questo valore è grande, dovresti incrementare la variabile di sistema sort_buffer_size.';
 $strShowStatusSort_rangeDescr = 'Il numero di ordinamenti che sono stati eseguiti in un intervallo.';
 $strShowStatusSort_rowsDescr = 'Il numero di righe ordinate.';
 $strShowStatusSort_scanDescr = 'Il numero di ordinamenti che sono stati fatti leggendo la tabella.';
@@ -798,7 +811,7 @@ $strShowStatusTable_locks_immediateDescr = 'Il numero di volte che un table lock
 $strShowStatusTable_locks_waitedDescr = 'Il numero di volte che un table lock è stato eseguito immediatamente ed era necessaria un\'attesa. Se è alto, potresti avere dei problemi con le performance, dovresti prima ottimizzare le query, oppure sia utilizzare le repliche, sia dividere le tabelle.';
 $strShowStatusThreads_cachedDescr = 'Il numero dei processi nella cache dei processi. L\'hit rate della cache può essere calcolato come processi_creati/connessioni. Se questo valore è rosso devi aumentare la tua thread_cache_size.';
 $strShowStatusThreads_connectedDescr = 'Il numero di connessioni correntemente aperte.';
-$strShowStatusThreads_createdDescr = 'Il numero di processi creati per gestire le connessioni. Se Threads_created è grosso, devi probabilmente aumentare il valore thread_cache_size. (Normalmente questo non fornisce un significativo incremento delle performace se hai una buona implementazione dei processi.)';
+$strShowStatusThreads_createdDescr = 'Il numero di processi creati per gestire le connessioni. Se Threads_created è grosso, devi probabilmente aumentare il valore thread_cache_size. (Normalmente questo non fornisce un significatico incremento delle performace se hai una buona implementazione dei processi.)';
 $strShowStatusThreads_runningDescr = 'Il numero di processi non in attesa.';
 $strShowTableDimension = 'Mostra la dimensione delle tabelle';
 $strShowTables = 'Mostra le tabelle';
@@ -818,6 +831,7 @@ $strSpanish = 'Spagnolo';
 $strSplitWordsWithSpace = 'Le parole sono spezzate sulle spaziature (" ").';
 $strSQLExportCompatibility = 'Compatibilità dell\'esportazione SQL';
 $strSQLExportType = 'Tipo di esportazione';
+$strSQLImportOptions = 'Opzioni SQL';
 $strSQLOptions = 'Opzioni SQL';
 $strSQLParserBugMessage = 'C\'è la possibilità che ci sia un bug nel parser SQL. Per favore, esaminate la query accuratamente, e controllate che le virgolette siano corrette e non sbagliate. Altre possibili cause d\'errori possono essere che si stia cercando di uploadare un file binario al di fuori di un\'area di testo virgolettata. Si può anche provare la query MySQL dalla riga di comando di MySQL. L\'errore qui sotto restituito dal server MySQL, se ce n\'è uno, può anche aiutare nella diagnostica del problema. Se ci sono ancora problemi, o se il parser SQL di phpMyAdmin sbaglia quando invece l\'interfaccia a riga di comando non mostra problemi, si può ridurre la query SQL in ingresso alla singola query che causa problemi, e inviare un bug report con i dati riportati nella sezione CUT qui sotto:';
 $strSQLParserUserError = 'Pare che ci sia un errore nella query SQL immessa. L\'errore del server MySQL mostrato qui sotto, se c\'è, può anche aiutare nella risoluzione del problema';
@@ -830,6 +844,7 @@ $strSQPBugUnknownPunctuation = 'Stringa di Punctuation Sconosciuta';
 $strStatCheckTime = 'Ultimo controllo';
 $strStatCreateTime = 'Creazione';
 $strStatement = 'Istruzioni';
+$strStatisticsOverrun = 'Su di un server sovraccarico, il contatore dei bytes potrebbe incrementarsi, e per questa ragione le statistiche riportate dal server MySQL potrebbero non essere corrette.';
 $strStatUpdateTime = 'Ultimo cambiamento';
 $strStatus = 'Stato';
 $strStorageEngine = 'Motore di Memorizzazione';
@@ -867,6 +882,11 @@ $strTblPrivileges = 'Privilegi relativi alle tabelle';
 $strTempData = 'Dati temporanei';
 $strTextAreaLength = ' A causa della sua lunghezza,<br /> questo campo non può essere modificato ';
 $strThai = 'Thai';
+$strThemeDefaultNotFound = 'Tema di default %s non trovato!';
+$strThemeNoPreviewAvailable = 'Nessuna preview disponibile.';
+$strThemeNotFound = 'Tema %s non trovato!';
+$strThemeNoValidImgPath = 'Nessun percorso per le immagini per il tema %s trovato!';
+$strThemePathNotFound = 'Percorso per il tema non trovato %s!';
 $strTheme = 'Tema / Stile';
 $strThisHost = 'Questo Host';
 $strThisNotDirectory = 'Questa non è una directory';
@@ -894,7 +914,7 @@ $strTransformation_text_plain__formatted = 'Preserva l\'originale formattazione
 $strTransformation_text_plain__imagelink = 'Mostra un collegamento ad una immagine esterna; il campo contiene il nome del file; la prima opzione è un prefisso come "http://tuodominio.com/", la seconda opzione è la larghezza in pixel, la terza è l\'altezza.';
 $strTransformation_text_plain__link = 'Mostra un collegamento, il campo contiene il nome del file; la prima opzione è un prefisso come "http://tuodominio.com/", la seconda opzione è un titolo per il collegamento.';
 $strTransformation_text_plain__sql = 'Formatta il testo come query SQL con evidenziazione della sintassi.';
-$strTransformation_text_plain__substr = 'Mostra soltanto una parte della stringa. La prima opzione è l\'offset che serve a definire dove inizia l\'output del vostro testo (Predefinito: 0). La seconda opzione è un offset che indica quanto testo viene restituito. Se vuoto, restituisce tutto il testo rimanente. La terza opzione definisce quali caratteri saranno aggiunti in fondo all\'output quando una soptto-stringa viene restituita (Predefinito: ...) .';
+$strTransformation_text_plain__substr = 'Mostra soltanto una parte della stringa. La prima opzione è l\'offset che serve a definire dove inizia l\'output del vostro testo (Prefinito: 0). La seconda opzione è un offset che indica quanto testo viene restituito. Se vuoto, restituisce tutto il testo rimanente. La terza opzione definisce quali caratteri saranno aggiunti in fondo all\'output quando una soptto-stringa viene restituita (Predefinito: ...) .';
 $strTruncateQueries = 'Tronca le Query Mostrate';
 $strTurkish = 'Turco';
 $strType = 'Tipo';
@@ -914,6 +934,7 @@ $strUpgrade = 'Si dovrebbe aggiornare %s alla versione %s o successiva.';
 $strUploadLimit = 'Stai probabilmente cercando di uplodare un file troppo grosso. Fai riferimento alla documentazione %sdocumentation%s Per i modi di aggirare questo limite.';
 $strUsage = 'Utilizzo';
 $strUseBackquotes = 'Usa i backquotes con i nomi delle tabelle e dei campi';
+$strUsedPhpExtensions = 'Estensioni PHP usate';
 $strUseHostTable = 'Utilizza la Tabella dell\'Host';
 $strUserAlreadyExists = 'L\'utente %s esiste già!';
 $strUserEmpty = 'Il nome utente è vuoto!';
@@ -937,6 +958,7 @@ $strViewDumpDatabases = 'Visualizza il dump (schema) dei databases';
 $strViewDumpDB = 'Visualizza dump (schema) del database';
 $strViewDump = 'Visualizza dump (schema) della tabella';
 $strViewHasBeenDropped = 'La vista %s è stata eliminata';
+$strViewMaxExactCount = 'Questa vista ha più di %d righe. Per informazioni fare riferimento a %sdocumentation%s.';
 $strView = 'Vista';
 
 $strWebServerUploadDirectory = 'directory di upload del web-server';
@@ -953,7 +975,7 @@ $strWrongUser = 'Nome utente o password errati. Accesso negato.';
 
 $strXML = 'XML';
 
-$strYes = ' Si ';
+$strYes = 'Sì';
 
 $strZeroRemovesTheLimit = 'N.B.: 0 (zero) significa nessun limite.';
 $strZip = '"compresso con zip"';
