@@ -1,9 +1,10 @@
 <?php
-/* $Id: japanese-euc.inc.php,v 2.103.2.2 2005/12/27 13:50:51 lem9 Exp $ */
+/* $Id: japanese-euc.inc.php,v 2.127.2.3 2006/03/23 17:42:14 lem9 Exp $ */
 
 /**
  * Translated by Yukihiro Kawada <kawada at den.fujifilm.co.jp>
  *               Tadashi Jokagi <elf2000 at users.sourceforge.net>
+ *               Kenichi Ishigaki <ishigaki at tcool.org>
  */
 
 $charset = 'euc-jp';
@@ -24,13 +25,14 @@ $timespanfmt = '%s  %s  %s ʬ %s ';
 
 $strAbortedClients = 'Ǥޤ';
 $strAbsolutePathToDocSqlDir = 'docSQL ؤХѥꤷƤ';
-$strAccessDeniedExplanation = 'phpMyAdmin ϡMySQL С³褦ȤޤơС³䤷ޤconfig.inc.php Υۥȡ桼̾ӥѥɤåMySQL СδͤͿ줿ˤ餬뤳ȤΤ٤Ǥ';
 $strAccessDenied = 'ϵݤޤ';
+$strAccessDeniedCreateConfig = '餯ͳϡեƤʤǤ%1$såȥåץץ%2$s ѤƤҤȤĺ뤳ȤǤޤ';
+$strAccessDeniedExplanation = 'phpMyAdmin ϡMySQL С³褦ȤޤơС³䤷ޤconfig.inc.php Υۥȡ桼̾ӥѥɤåMySQL СδԤͿ줿뤳Ȥǧ٤Ǥ';
 $strAction = '';
 $strAddAutoIncrement = 'AUTO_INCREMENTͤɲä';
 $strAddConstraints = '¤ɲä';
-$strAddDeleteColumn = 'եΡɲ/';
-$strAddDeleteRow = 'ԤΡɲ/';
+$strAddDeleteColumn = 'եɲá';
+$strAddDeleteRow = 'Ԥɲá';
 $strAddDropDatabase = 'DROP DATABASEפɲä';
 $strAddedColumnComment = 'Υɲäޤ';
 $strAddedColumnRelation = 'Υ졼ɲäޤ';
@@ -43,8 +45,8 @@ $strAddPrivilegesOnDb = 'ǡ١øɲä';
 $strAddPrivilegesOnTbl = 'ơ֥øɲä';
 $strAddSearchConditions = 'ʸɲäƤ("where"ʸ):';
 $strAddToIndex = ' &nbsp;%s&nbsp; 򥤥ǥåɲäޤ';
-$strAddUserMessage = '桼ɲäޤ';
 $strAddUser = '桼ɲä';
+$strAddUserMessage = '桼ɲäޤ';
 $strAdministration = '';
 $strAffectedRows = 'ƶ줿Կ:';
 $strAfterInsertBack = '';
@@ -52,17 +54,17 @@ $strAfterInsertNewInsert = '쥳ɤɲä';
 $strAfterInsertNext = 'ιԤԽ';
 $strAfterInsertSame = 'Υڡ';
 $strAfter = 'ꥫθ %s';
+$strAll = '';
 $strAllowInterrupt = '»֤ŤƤ뤳Ȥ򥹥ץȤΤ硢ݡȤؤγߤĤޤ礭ʥե򥤥ݡȤΤ褤ʤ⤷ޤ󤬡ϥȥ󥶥Ȥˤʤޤ';
 $strAllTableSameWidth = '٤ƤΥơ֥Ʊɽޤ?';
-$strAll = '';
 $strAlterOrderBy = 'ơ֥֤ξ';
 $strAnalyzeTable = 'ơ֥ʬϤ';
 $strAnd = 'AND';
 $strAndThen = 'Ƥθ';
 $strAnIndex = 'ǥå%sפɲäƤޤ';
+$strAny = '٤';
 $strAnyHost = '٤ƤΥۥ';
 $strAnyUser = '٤ƤΥ桼';
-$strAny = '٤';
 $strApproximateCount = 'ᤤ⤷ޤFAQ 3.11 򻲾ȤƤ';
 $strAPrimaryKey = '祭 %s ɲäޤ';
 $strArabic = 'ӥ';
@@ -78,8 +80,8 @@ $strBack = '';
 $strBaltic = 'ХȽ';
 $strBeginCut = 'ڤ곫';
 $strBeginRaw = 'RAW ';
-$strBinary = ' Хʥ ';
 $strBinaryDoNotEdit = ' Хʥ - Ǥޤ';
+$strBinary = ' Хʥ ';
 $strBinaryLog = 'Хʥ';
 $strBinLogEventType = '٥ȥ';
 $strBinLogInfo = '';
@@ -95,13 +97,14 @@ $strBookmarkQuery = '֥åޡƤ SQL';
 $strBookmarkReplace = '¸ߤƱ̾Υ֥åޡִ';
 $strBookmarkThis = 'SQL ֥åޡ';
 $strBookmarkView = 'ɽΤ';
-$strBrowseForeignValues = 'ɽ';
+$strBrowseDistinctValues = '̤ͤɽ';
 $strBrowse = 'ɽ';
-$strBufferPool = 'Хåեס';
+$strBrowseForeignValues = 'ɽ';
 $strBufferPoolActivity = 'Хåեסγ';
+$strBufferPool = 'Хåեס';
 $strBufferPoolUsage = 'Хåեסλ';
-$strBufferReadMissesInPercent = '% ɤ߹ߥߥ';
 $strBufferReadMisses = 'ɤ߹ߥߥ';
+$strBufferReadMissesInPercent = '% ɤ߹ߥߥ';
 $strBufferWriteWaitsInPercent = '% ν񤭹Ԥ';
 $strBufferWriteWaits = '񤭹Ԥ';
 $strBulgarian = '֥륬ꥢ';
@@ -120,27 +123,27 @@ $strCardinality = 'դͤο';
 $strCaseInsensitive = 'ѻ羮̤ʤ';
 $strCaseSensitive = 'ѻ羮̤';
 $strCentralEuropean = '衼åѸ';
+$strChangeCopyMode = 'ƱøäΥ桼...';
 $strChangeCopyModeCopy = '... ŤΤݻ';
 $strChangeCopyModeDeleteAndReload = ' ... 桼ơ֥뤫ŤΤø˺Ƥӥɤ';
 $strChangeCopyModeJustDelete = ' ... 桼ơ֥뤫ŤΤ';
 $strChangeCopyModeRevoke = ' ... ŤΤͭø򤹤٤̵ˤǺ';
-$strChangeCopyMode = 'ƱøäΥ桼...';
 $strChangeCopyUser = 'ѹ / 桼ԡ';
 $strChangeDisplay = 'ɽեɤǲ';
-$strChangePassword = 'ѥɤѹ򤹤';
 $strChange = 'ѹ';
-$strCharsetOfFile = 'եʸå:';
-$strCharsetsAndCollations = 'ʸåȤȾȲ';
-$strCharsets = 'ʸ';
+$strChangePassword = 'ѥɤѹ';
 $strCharset = 'ʸå';
+$strCharsetOfFile = 'եʸå:';
+$strCharsetsAndCollations = 'ʸåȤȾȹ';
+$strCharsets = 'ʸ';
 $strCheckAll = '٤ƥå';
 $strCheckOverhead = 'Сإåɤθ򤹤';
-$strCheckPrivsLong = 'ǡ١ &quot;%s&quot; øå';
 $strCheckPrivs = 'øΥå򤹤';
+$strCheckPrivsLong = 'ǡ١ &quot;%s&quot; øå';
 $strCheckTable = 'ơ֥å';
 $strChoosePage = 'Խڡ򤷤Ƥ';
 $strColComFeat = '󥳥ɽǽ';
-$strCollation = 'Ȳ';
+$strCollation = 'ȹ';
 $strColumnNames = '()̾';
 $strColumnPrivileges = 'ø';
 $strCommand = 'ޥ';
@@ -148,8 +151,9 @@ $strComments = '';
 $strCommentsForTable = 'COMMENTS FOR TABLE';
 $strCompatibleHashing = 'MySQL&nbsp;4.0 ߴ';
 $strCompleteInserts = ' INSERT ʸ';
-$strCompressionWillBeDetected = 'ݡȤ줿ե밵̤ϡưŪ˸ΤǤ礦: %s';
 $strCompression = '';
+$strCompressionWillBeDetected = 'ݡȤ줿ե밵̤ϡưŪ˸ΤǤ礦: %s';
+$strConfigDefaultFileError = 'ǥեɤ߹ޤǤ: "%1$s"';
 $strConfigFileError = 'phpMyAdmin եɤ߹ळȤǤޤ! <br />ʸˡ顼ȯե뤬Ĥޤ<br />Υ󥯤եľɤ߹ǡPHP Υ顼åǧƤ¿ξ硢ڤʸ䥻ߥ˺Ƥޤ<br />⤷Υڡ줿餹٤ƤޤԤäƤޤ';
 $strConfigureTableCoord = 'ơ֥%sץơ֥ĴƤ';
 $strConnectionError = '³Ǥޤ: ̵Ǥ';
@@ -167,10 +171,10 @@ $strCreateDatabaseBeforeCopying = 'ԡˡCREATE DATABASEפ';
 $strCreateIndex = '&nbsp;%s&nbsp; Υǥå';
 $strCreateIndexTopic = 'ǥå';
 $strCreateNewDatabase = 'ǡ١';
-$strCreateNewTable = 'ǡ١%sפǿơ֥';
+$strCreateNewTable = 'ǡ١%sפ˥ơ֥򿷵';
+$strCreate = '';
 $strCreatePage = 'ڡ';
 $strCreatePdfFeat = 'PDF ǽ';
-$strCreate = '';
 $strCreationDates = '//դɲä';
 $strCriteria = 'ʹߴ';
 $strCroatian = '';
@@ -178,11 +182,10 @@ $strCSV = 'CSV';
 $strCSVImportOptions = 'CSV ץ';
 $strCSVOptions = 'CSV ץ';
 $strCyrillic = 'ʸ';
-$strCzechSlovak = 'ΥХ';
 $strCzech = '';
+$strCzechSlovak = 'ΥХ';
 
 $strDanish = 'ǥޡ';
-$strData = 'ǡ';
 $strDatabase = 'ǡ١';
 $strDatabaseEmpty = 'ǡ١̾Ǥ!';
 $strDatabaseExportOptions = 'ǡ١ݡȥץ';
@@ -190,10 +193,11 @@ $strDatabaseHasBeenDropped = 'ǡ١%sפ˺ޤ';
 $strDatabaseNoTable = 'Υǡ١ϥơ֥ޤǤޤ!';
 $strDatabases = 'ǡ١';
 $strDatabasesDropped = 'ǡ١%sפϺޤ';
+$strDatabasesStats = 'ǡ١';
 $strDatabasesStatsDisable = 'פ̵ˤ';
 $strDatabasesStatsEnable = 'פĤ';
 $strDatabasesStatsHeavyTraffic = ': ǡ١פĤ MySQL  WEBСδ֤ǽŤȥեåȯ뤫⤷ޤ';
-$strDatabasesStats = 'ǡ١';
+$strData = 'ǡ';
 $strDataDict = 'ǡ';
 $strDataOnly = 'ǡΤ';
 $strDataPages = 'ǡޤڡ';
@@ -216,10 +220,10 @@ $strDefaultValueHelp = 'ǥեͤΤˡХåå奨פʤ 1 ĤͤƲ, ΥեޥåȤ: a';
 $strDefault = '';
 $strDefragment = 'ơ֥Υǥե饰';
 $strDelayedInserts = 'ٱ䥤󥵡ȤѤ';
-$strDeleteAndFlushDescr = 'ϥꥢǤøɤΤǾ֤ޤ';
 $strDeleteAndFlush = '桼øɤ';
-$strDeletedRows = '줿Կ:';
+$strDeleteAndFlushDescr = 'ϥꥢǤøɤΤǾ֤ޤ';
 $strDeleted = '򤷤ޤ';
+$strDeletedRows = '줿Կ:';
 $strDeleteNoUsersSelected = '桼򤷤Ƥޤ!';
 $strDelete = '';
 $strDeleting = '%s Ǥ';
@@ -237,34 +241,33 @@ $strDoAQuery = '"QUERY"¹ (磻ɥ: "%")';
 $strDocu = 'ɥ';
 $strDoYouReally = '˼¹ԤƤɤǤ?:';
 $strDropDatabaseStrongWarning = '˥ǡ١˲Ǥ礦!';
-$strDropSelectedDatabases = '򤵤줿ǡ١';
-$strDropUsersDb = '桼Ʊ̾ĥǡ١';
 $strDrop = '';
+$strDropUsersDb = '桼Ʊ̾ĥǡ١';
 $strDumpingData = 'ơ֥Υץǡ';
 $strDumpSaved = 'פե %s ¸ޤ';
 $strDumpXRows = '%s פޤ %s Ǥ';
 $strDynamic = 'ʥߥå';
 
+$strEdit = '';
 $strEditPDFPages = 'PDF ڡԽ';
 $strEditPrivileges = 'ø';
-$strEdit = '';
 $strEffective = '¸';
-$strEmptyResultSet = 'MySQL ֤ͤޤ (㤨йԤä)';
 $strEmpty = 'ˤ';
+$strEmptyResultSet = 'MySQL ֤ͤޤ (㤨йԤä)';
 $strEnabled = 'ͭ';
 $strEncloseInTransaction = 'ȥ󥶥ǥݡȤϤ';
 $strEncto = '󥳡ǥ󥰤Ѵ'; // encoding convert
 $strEndCut = 'ڤ꽪λ';
-$strEndRaw = 'RAW λ';
 $strEnd = 'Ǹ';
+$strEndRaw = 'RAW λ';
 $strEngineAvailable = '%s ϡ MySQL СѲǽǤ';
 $strEngineDisabled = '%s ϡ MySQL СǤ̵ˤƤޤ';
 $strEngines = '󥸥';
 $strEngineUnsupported = ' MySQL С %s ȥ졼󥸥򥵥ݡȤƤޤ';
-$strEnglishPrivileges = ' : MySQLø̾ϱѸɽƤޤ';
 $strEnglish = 'Ѹ';
-$strError = '顼';
+$strEnglishPrivileges = ' : MySQLø̾ϱѸɽƤޤ';
 $strErrorInZipFile = 'ZIP ˥顼Ǥ:';
+$strError = '顼';
 $strEscapeWildcards = '磻ɥɡ_פӡ%פϤʸ̤˻Ѥ뤿ˡ\פǥ()٤Ǥ';
 $strEsperanto = 'ݸ';
 $strEstonian = 'ȥ˥';
@@ -277,24 +280,27 @@ $strExtendedInserts = 'ĥ INSERT ʸ';
 $strExtra = '¾';
 
 $strFailedAttempts = 'ߤϼԤޤ';
-$strField = 'ե';
 $strFieldHasBeenDropped = 'ե %s ˺ޤ';
-$strFields = 'ե';
+$strField = 'ե';
 $strFieldsEmpty = ' եɿǤ ';
 $strFieldsEnclosedBy = 'եɰϤߵ';
 $strFieldsEscapedBy = 'եɤΥ׵';
+$strFields = 'ե';
 $strFieldsTerminatedBy = 'եɶڤ국';
 $strFileAlreadyExists = 'ե%sפϴ˥С¸ߤޤե̾ѹ뤫񤭥ץǧƤ';
 $strFileCouldNotBeRead = 'եɤޤ';
-$strFileNameTemplateHelp = '__DB__ ǡ١̾ˡ__TABLE__ ơ֥̾ˡ%sǤդ strftime ؿ%s ץֻͤˡĥȤƼưŪɲäǤ礦¾ΥƥȤ¸Ǥ礦';
-$strFileNameTemplateRemember = 'ƥץ졼ȤФ';
+$strFileNameTemplateDescription = 'ͤ %1$sstrftime%2$s ѤơȽǤޤäơֽ񼰤ʸѤ뤳ȤǤޤ˼ʸִǤ礦: %3$sΤޤޤ¾ΥƥȤϰݻǤ礦';
+$strFileNameTemplateDescriptionDatabase = 'ǡ١̾';
+$strFileNameTemplateDescriptionServer = 'С̾';
+$strFileNameTemplateDescriptionTable = 'ơ֥̾';
 $strFileNameTemplate = 'ե̾Υƥץ졼';
+$strFileNameTemplateRemember = 'ƥץ졼ȤФ';
 $strFileToImport = 'ե򥤥ݡȤ';
 $strFixed = '';
 $strFlushPrivilegesNote = ': phpMyAdmin  MySQL øơ֥뤫ľܤ˥桼øޤ⤷ޥ˥奢øѹƤȡΥơ֥ƤȤϰۤʤ뤫⤷ޤ󡣤ξ硢³ޤ %s ø %s 򤹤ɬפޤ';
 $strFlushQueryCache = 'Ȳ񥭥åեå夹';
-$strFlushTables = '٤ƤΥơ֥եå夹(Ĥ)';
 $strFlushTable = 'ơ֥Υåˤ("FLUSH")';
+$strFlushTables = '٤ƤΥơ֥եå夹(Ĥ)';
 $strFormat = 'եޥå';
 $strFormEmpty = 'եǤͤޤǤ';
 $strFreePages = 'ե꡼ʥڡ';
@@ -303,8 +309,8 @@ $strFunction = 'ؿ';
 
 $strGenBy = 'Ķ';
 $strGeneralRelationFeat = '졼ǽ';
-$strGeneratePassword = 'ѥɤ';
 $strGenerate = '';
+$strGeneratePassword = 'ѥɤ';
 $strGenTime = 'λ';
 $strGeorgian = '른';
 $strGerman = 'ɥĸ';
@@ -324,8 +330,8 @@ $strHebrew = 'إ֥饤';
 $strHexForBinary = 'Хʥեɤ 16 ʿѤ';
 $strHome = 'ᥤڡ';
 $strHomepageOfficial = 'phpMyAdmin ۡ';
-$strHost = 'ۥ';
 $strHostEmpty = 'ۥ̾϶Ǥ!';
+$strHost = 'ۥ';
 $strHTMLExcel = 'Microsoft Excel 2000';
 $strHTMLExcelOptions = 'Microsoft Excel 2000 ݡȥץ';
 $strHTMLWord = 'Microsoft Word 2000';
@@ -336,18 +342,18 @@ $strIcelandic = 'ɸ';
 $strId = 'ID';
 $strIdxFulltext = 'ʸ';
 $strIgnoreDuplicates = 'Ԥʣ̵뤹';
-$strIgnoreInserts = 'INSERT IGNOREפѤ';
 $strIgnore = '̵';
+$strIgnoreInserts = 'INSERT IGNOREפѤ';
 $strIgnoringFile = 'ե̵ %s';
-$strImport = 'ݡ';
 $strImportDocSQL = 'docSQL ե륤ݡ';
 $strImportFiles = 'ݡȥե';
-$strImportFinished = 'ݡȤλޤ';
 $strImportFormat = 'ݡȺѥեν';
-$strIndex = 'ǥå';
+$strImport = 'ݡ';
+$strImportSuccessfullyFinished = 'ݡȤޤ%d ĤξȲ¹Ԥޤ';
 $strIndexes = 'ǥå';
 $strIndexHasBeenDropped = 'ǥå %s ޤ';
 $strIndexName = 'ǥå̾&nbsp;:';
+$strIndex = 'ǥå';
 $strIndexType = 'ǥåμ&nbsp;:';
 $strIndexWarningMultiple = '1 Ĥۤ INDEX  `%s` Ѥ˺ޤ';
 $strIndexWarningPrimary = 'PRIMARY  INDEX ΥξȤ⡢ `%s` ꤵ٤ǤϤޤ';
@@ -355,36 +361,40 @@ $strIndexWarningTable = 'ơ֥ `%s` Υǥå˴ؤǤ';
 $strIndexWarningUnique = 'UNIQUE  INDEX ΥξȤ⡢ `%s` ꤵ٤ǤϤޤ';
 $strInnoDBAutoextendIncrementDesc = ' 줬äѤˤʤˡưĥơ֥륹ڡΥĥ뤿ʬ̤Ǥ';
 $strInnoDBAutoextendIncrement = 'ưĥɲ';
-$strInnoDBBufferPoolSizeDesc = 'InnoDB åǡȤΥơ֥Υǥå˻ȤХåեΥǤ';
 $strInnoDBBufferPoolSize = 'Хåեѥ';
+$strInnoDBBufferPoolSizeDesc = 'InnoDB åǡȤΥơ֥Υǥå˻ȤХåեΥǤ';
 $strInnoDBDataFilePath = 'ǡե';
 $strInnoDBDataHomeDir = 'ǡۡǥ쥯ȥ';
 $strInnoDBDataHomeDirDesc = '٤Ƥ InnoDB ǡեѤΥǥ쥯ȥѥζʬǤ';
 $strInnoDBPages = 'ڡ';
 $strInnodbStat = 'InnoDB ơ';
 $strInsecureMySQL = 'ʤΥե졼ե꤬ MySQL ǥեȤøȤˤʤäƤޤ (root 桼ǥѥɤʤ)  MySQL С⤳ΥǥեưƤΤǡԤФ̵ǤΥƥۡɬĤƤ';
+$strInsert = 'ɲ';
 $strInsertAsNewRow = 'ԤȤɲä';
 $strInsertedRowId = '󥵡Ȥ ID:';
 $strInsertedRows = 'ɲä줿Կ:';
 $strInsertNewRow = 'Ԥɲä';
-$strInsert = 'ɲ';
 $strInternalNotNecessary = '* InnoDB ¸ߤ硢졼ɬפǤϤޤ';
 $strInternalRelations = '졼';
 $strInUse = '';
 $strInvalidAuthMethod = 'ʤǧˡꤷƤޤ:';
-$strInvalidColumnCount = ' 0 礭ʤФޤ';
 $strInvalidColumn = 'ʤ (%s) ꤵޤ!';
-$strInvalidCSVInput = 'ʤ CSV ϤΤᡢϤǤޤ!';
+$strInvalidColumnCount = ' 0 礭ʤФޤ';
+$strInvalidCSVFieldCount = 'CSV  ̵ʹܿޤ(:%d)';
+$strInvalidCSVFormat = 'CSV  ̵ʽ񼰤ޤ(:%d)';
+$strInvalidCSVParameter = 'CSV ݡȤΥѥ᡼̵Ǥ: %s';
 $strInvalidFieldAddCount = 'ʤȤҤȤĤΥեɤɲäʤФʤޤ';
 $strInvalidFieldCount = 'ơ֥ϾʤȤҤȤĤΥեɤɬפǤ';
 $strInvalidLDIImport = 'Υץ饰ϰ̺ѥݡȤ򥵥ݡȤƤޤ!';
 $strInvalidRowNumber = '%d ʤֹǤ';
+$strInvalidServerHostname = 'С%1$sפΥۥ̵̾ǤĴƤ';
+$strInvalidServerIndex = '̵ʥСǥåǤ: "%s"';
 
 $strJapanese = 'ܸ';
 $strJoins = '';
 $strJumpToDB = '&quot;%s&quot; ǡ١إ.';
-$strJustDeleteDescr = '&quot;&quot; 桼øɤޤǥС˥ǽǤ';
 $strJustDelete = 'øơ֥뤫桼¨';
+$strJustDeleteDescr = '&quot;&quot; 桼øɤޤǥС˥ǽǤ';
 
 $strKanjiEncodConvert = 'Ѵ'; // kanji code convert
 $strKeepPass = 'ѥɤѹʤ';
@@ -394,10 +404,13 @@ $strKill = '';
 $strKorean = 'ڹ';
 
 $strLandscape = 'ɥ';
+$strLanguageFileNotFound = 'ե%1$sפĤޤ';
+$strLanguageUnknown = 'θ: %1$s.';
+$strLatchedPages = 'åƤڡ';
 $strLatexCaption = 'ơ֥륭ץ';
 $strLatexContent = 'ơ֥ __TABLE__ ';
-$strLatexContinuedCaption = '³Υơ֥륭ץ';
 $strLatexContinued = '(³)';
+$strLatexContinuedCaption = '³Υơ֥륭ץ';
 $strLatexIncludeCaption = 'ơ֥륭ץޤ';
 $strLatexLabel = '٥륭';
 $strLaTeX = 'LaTeX';
@@ -415,8 +428,8 @@ $strLinksTo = '';
 $strLithuanian = 'ȥ˥';
 $strLocalhost = '';
 $strLocationTextfile = 'ƥȥեξ';
-$strLogin = '';
 $strLoginInformation = '';
+$strLogin = '';
 $strLogout = '';
 $strLogPassword = 'ѥ:';
 $strLogServer = 'С';
@@ -432,11 +445,13 @@ $strMIME_available_mime = 'ͭ MIME ';
 $strMIME_available_transform = 'Ѵͭ';
 $strMIME_description = '';
 $strMIME_MIMEtype = 'MIME ';
+$strMIME_nodescription = 'Ѵˤͭޤ<br />Ԥ%sΰ̣򤴳ǧ';
 $strMIME_transformation_note = 'ѲǽѴץΰӤ MIME Ѵ˴ؤƤϡ%sѴ%s 򥯥åƤ';
-$strMIME_transformation_options = 'Ѵץ';
 $strMIME_transformation = '֥饦Ѵ';
+$strMIME_transformation_options = 'Ѵץ';
+$strMIME_transformation_options_note = 'ν񼰤ѤơѴץͤϤƤ: \'a\',\'b\',\'c\'...<br />Хåå("\")䥷󥰥륯("\'")ͤ˴ޤɬפ(\\\\xyzפa\\\'bפΤ褦)ХååǥפƤ';
 $strMIMETypesForTable = 'MIME TYPES FOR TABLE';
-$strMIME_without = 'åΤǰ줿MIME פϸ̤ѴؿäƤޤ';
+$strMIME_without = 'åΤǰ줿 MIME פϸ̤ѴؿäƤޤ';
 $strModifications = 'ޤ';
 $strModifyIndexTopic = 'ǥåѹ';
 $strModify = '';
@@ -445,39 +460,38 @@ $strMoveTableOK = 'ơ֥%sפ%sפ˰ưޤ';
 $strMoveTableSameNames = 'Ʊơ֥˰ưǤޤ!';
 $strMultilingual = '¿';
 $strMyISAMDataPointerSize = 'ǡΥݥ󥿡';
-$strMyISAMDataPointerSizeDesc = 'CREATE TABLE  MyISAMơ֥˻Ѥ MAX_ROWS ץ󤬻ꤵʤΥХȻΥǥեȥݥ󥿡Ǥ';
+$strMyISAMDataPointerSizeDesc = 'CREATE TABLE  MyISAM ơ֥˻Ѥ MAX_ROWS ץ󤬻ꤵʤΥХȻΥǥեȥݥ󥿡Ǥ';
+$strMyISAMMaxExtraSortFileSizeDesc = 'MyISAMΥǥå®ȤѤƥݥե礭åѤȤꤳ˻ꤷͰʾ礭ʤϡåˡȤޤ';
 $strMyISAMMaxExtraSortFileSize = 'ǥåѰեκ祵';
 $strMyISAMMaxSortFileSizeDesc = 'MyISAM ǥåκƺǻѤ뤳Ȥ줿 MySQL եκ祵Ǥ (REPAIR TABLE 桢ALTER TABLE  LOAD DATA INFILE)';
 $strMyISAMMaxSortFileSize = 'ȥեκ祵';
 $strMyISAMRecoverOptionsDesc = 'å夷 MyISAM ơ֥μưѥ⡼ɤǡСưץ --myisam-recover ꤷޤ';
 $strMyISAMRecoverOptions = 'ư⡼';
-$strMyISAMRepairThreadsDesc = '⤷ͤ 1 ʾʤ顢MyISAM ơ֥ΥǥåϥȽνʿԤ(켫Ȥγƥǥå)ޤ';
 $strMyISAMRepairThreads = 'åɤν';
-$strMyISAMSortBufferSize = 'ȥХåե';
+$strMyISAMRepairThreadsDesc = '⤷ͤ 1 ʾʤ顢MyISAM ơ֥ΥǥåϥȽνʿԤ(켫Ȥγƥǥå)ޤ';
 $strMyISAMSortBufferSizeDesc = 'ΥХåեϡREPAIR TABLE δ֤ MyISAM ǥå򥽡Ȥ硢ޤ CREATE INDEX  ALTER TABLE ȥǥåˡդޤ';
+$strMyISAMSortBufferSize = 'ȥХåե';
 $strMySQLCharset = 'MySQL ʸå';
-$strMySQLConnectionCollation = 'MySQL ³Ȳ';
-$strMySQLReloaded = 'MySQL 򿷤ɤ߹ߤޤ';
+$strMysqlClientVersion = 'MySQL 饤ȥС';
+$strMySQLConnectionCollation = 'MySQL ³ȹ';
 $strMySQLSaid = 'MySQLΥå: ';
-$strMySQLServerProcess = 'MySQL %pma_s1%  %pma_s2%  %pma_s3% ȤƼ¹ԤƤޤ';
 $strMySQLShowProcess = 'MySQL ץɽ';
 $strMySQLShowStatus = 'MySQL Υ󥿥';
 $strMySQLShowVars = 'MySQL Υƥѿ';
 
 $strName = '̾';
 $strNext = '';
-$strNo = '';
 $strNoActivity = '%s ðʾ򤷤ޤǤ٥򤷤Ƥ';
-$strNoDatabasesSelected = 'ǡ١򤵤Ƥޤ';
 $strNoDatabases = 'ǡ١';
+$strNoDatabasesSelected = 'ǡ١򤵤Ƥޤ';
 $strNoDescription = 'Ҥޤ';
 $strNoDetailsForEngine = 'Υȥ졼󥸥ˤͭʥơξܺپϤޤ';
 $strNoDropDatabases = 'DROP DATABASEץơȥȤ϶ػߤ';
 $strNoExplain = 'SQL ʬϤФ';
 $strNoFilesFoundInZip = 'ZIP ˥ե뤬Ĥޤ!';
 $strNoFrames = 'phpMyAdmin <b>ե졼</b>򥵥ݡȤ֥饦ǤѤ򤪴ᤷޤ';
-$strNoIndexPartsDefined = 'ǥåʬꤵƤޤ';
 $strNoIndex = 'ǥåꤵƤޤ';
+$strNoIndexPartsDefined = 'ǥåʬꤵƤޤ';
 $strNoModification = 'ѹ̵';
 $strNone = '̵';
 $strNoOptions = 'ν񼰤ϥץ󤬤ޤ';
@@ -487,6 +501,7 @@ $strNoPhp = 'PHP ̵';
 $strNoPrivileges = 'ø̵';
 $strNoRights = 'øäƤʤΤǤޤ';
 $strNoRowsSelected = 'Ԥ򤵤ޤǤ';
+$strNo = '';
 $strNoSpace = 'ե%sפ¸ˤ϶̤ԽʬǤ';
 $strNoTablesFound = 'ߤΥǡ١˥ơ֥Ϥޤ';
 $strNoThemeSupport = 'ơޤ򥵥ݡȤƤޤȥơޥǥ쥯ȥ%sפǧƤ';
@@ -503,6 +518,7 @@ $strNumSearchResultsTotal = '<b>:</b> <i>%s</i> Ĥޤ';
 $strNumTables = 'ơ֥';
 
 $strOK = 'OK';
+$strOpenNewWindow = ' phpMyAdmin Υɥ򳫤';
 $strOperations = '';
 $strOperator = '';
 $strOptimizeTable = 'ơ֥Ŭ';
@@ -515,14 +531,17 @@ $strPagesToBeFlushed = 'եå夵줿ڡ';
 $strPaperSize = '極';
 $strPartialImport = 'ʬŪʥݡ';
 $strPartialText = 'ʬŪʸ';
-$strPassword = 'ѥ';
 $strPasswordChanged = '%s Υѥɤѹޤ';
 $strPasswordEmpty = 'ѥɤǤ';
 $strPasswordHashing = 'ѥɥϥå';
+$strPassword = 'ѥ';
 $strPasswordNotSame = 'ѥɤƱǤϤޤ';
 $strPdfDbSchema = 'ǡ١%sפΥ - ڡ %s';
 $strPdfInvalidTblName = '"%s" ơ֥뤬ޤ!';
 $strPdfNoTables = 'ơ֥뤬ޤ';
+$strPDFOptions = 'PDF ץ';
+$strPDF = 'PDF';
+$strPDFReportTitle = 'ݡȤ̾';
 $strPerHour = '';
 $strPerMinute = '/ʬ';
 $strPerSecond = '/';
@@ -541,12 +560,12 @@ $strPrimaryKeyHasBeenDropped = '祭ޤ';
 $strPrimaryKeyName = '祭̾... PRIMARY ǤϤʤФޤ';
 $strPrimaryKeyWarning = '("PRIMARY"Ϥ礦ɼ祭̾ǤϤʤФޤ';
 $strPrimary = '';
+$strPrint = '';
 $strPrintViewFull = 'ӥ塼 (ƥȤޤ)';
 $strPrintView = 'Ѥɽ';
-$strPrint = '';
 $strPrivDescAllPrivileges = 'GRANT ٤Ƥøޤߤޤ';
-$strPrivDescAlterRoutine = 'ȥɥ롼ѹ˴Ĥޤ';
 $strPrivDescAlter = '¸ߤơ֥빽¤ѹĤޤ';
+$strPrivDescAlterRoutine = 'ȥɥ롼ѹ˴Ĥޤ';
 $strPrivDescCreateDb = 'ǡ١ơ֥κĤޤ';
 $strPrivDescCreateRoutine = 'ȥɥ롼κĤޤ';
 $strPrivDescCreateTbl = 'ơ֥κĤޤ';
@@ -556,8 +575,8 @@ $strPrivDescCreateView = 'ӥ塼κĤޤ';
 $strPrivDescDelete = 'ǡκĤޤ';
 $strPrivDescDropDb = 'ǡ١ȥơ֥κĤޤ';
 $strPrivDescDropTbl = 'ơ֥κĤޤ';
-$strPrivDescExecute5 = 'ȥɥ롼μ¹ԤĤޤ';
 $strPrivDescExecute = 'ȥɥץ㡼¹Ԥ뤳ȤĤޤ MySQL ǤǤϰ̣ޤ';
+$strPrivDescExecute5 = 'ȥɥ롼μ¹ԤĤޤ';
 $strPrivDescFile = 'ǡΥݡȡǡΥեؤΥݡȤĤޤ';
 $strPrivDescGrant = 'øơ֥Υɤʤ˥桼øɲäĤޤ';
 $strPrivDescIndex = 'ǥåκĤޤ';
@@ -580,9 +599,10 @@ $strPrivDescShutdown = 'СΥåȥĤޤ';
 $strPrivDescSuper = '³ãƤ³Ĥޤ¿δϥХѿ¾桼ץνλǤ褦꤬ɬפǤ';
 $strPrivDescUpdate = 'ǡνĤޤ';
 $strPrivDescUsage = 'øޤ';
-$strPrivilegesReloaded = 'øϥɤޤ';
 $strPrivileges = 'ø';
+$strPrivilegesReloaded = 'øϥɤޤ';
 $strProcesslist = 'ץ';
+$strProtocolVersion = 'ץȥС';
 $strPutColNames = 'ǽ 1 ܤ˥ե̾ɲä';
 
 $strQBEDel = '';
@@ -592,7 +612,7 @@ $strQueryCache = 'Ȳ񥭥å';
 $strQueryFrame = 'Ȳ񥦥ɥ';
 $strQueryOnDb = 'ǡ١ SQL <b>%s</b>:';
 $strQuerySQLHistory = 'SQL ';
-$strQueryStatistics = '<b>Ȳ</b>: ư %s Ȳ񤬥СƤޤ';
+$strQueryStatistics = '<b>Ȳ</b>: ư %s ĤξȲ񤬥СƤޤ';
 $strQueryTime = 'Ȳμ¹Ի %01.4f ';
 $strQueryType = 'Ȳ񥿥';
 $strQueryWindowLock = 'ɥγ餳ξȲ񤭴Ǥޤ';
@@ -607,13 +627,12 @@ $strRelationNotWorking = 'phpMyAdmin ȼǽǤ졼ǽ뤿Υ󥯥ơ֥뤬ͭˤʤäƤޤ󡣤
 $strRelations = '졼';
 $strRelationsForTable = 'RELATIONS FOR TABLE';
 $strRelationView = '졼ɽ';
-$strReloadFailed = 'MySQL Υɤ˼Ԥޤ';
-$strReloadingThePrivileges = 'øǤ';
+$strReloadingThePrivileges = 'øɤ߹Ǥ';
 $strReloadMySQL = 'MySQL Υ';
 $strRemoveSelectedUsers = '򤵤줿桼ޤ';
-$strRenameDatabaseOK = 'ǡ١ %s  %s ̾ѹޤ';
-$strRenameTableOK = '%sפ%sפ̾ѹޤ';
+$strRenameDatabaseOK = 'ǡ١%sפϡ%sפ̾ѹޤ';
 $strRenameTable = 'ơ֥̾ѹ';
+$strRenameTableOK = '%sפ%sפ̾ѹޤ';
 $strRepairTable = 'ơ֥줹';
 $strReplaceNULLBy = 'NULL ʸ֤';
 $strReplaceTable = 'եǥơ֥֤';
@@ -621,12 +640,13 @@ $strReplication = 'ץꥱ';
 $strReset = 'ꥻå';
 $strResourceLimits = '꥽';
 $strReType = '';
-$strRevokeAndDeleteDescr = '桼øɤޤ USAGE øΤޤޤǤ';
 $strRevokeAndDelete = '桼ͭø򤹤٤˴ƺ';
-$strRevokeMessage = '%s øäޤ';
+$strRevokeAndDeleteDescr = '桼øɤ߹ߤޤ USAGE øΤޤޤǤ';
 $strRevoke = 'ѻ';
+$strRevokeMessage = '%s øäޤ';
 $strRomanian = '롼ޥ˥';
 $strRowLength = 'ԤĹ';
+$strRows = '';
 $strRowsFrom = 'Ϲ';
 $strRowSize = ' ԤΥ ';
 $strRowsModeFlippedHorizontal = 'ʿ (žإå)';
@@ -634,15 +654,14 @@ $strRowsModeHorizontal = 'ʿ';
 $strRowsModeOptions = ': %s : %s 󤺤ĥإå򷫤֤ɽ';
 $strRowsModeVertical = 'ľ';
 $strRowsStatistic = 'Ԥ';
-$strRows = '';
 $strRunning = '¹Ǥ %s';
 $strRunQuery = 'Ȳμ¹Ԥ';
-$strRunSQLQueryOnServer = 'С %s  SQL ¹Ԥ';
-$strRunSQLQuery = 'ǡ١ %s  SQL ¹Ԥ';
+$strRunSQLQuery = 'ǡ١%sפ SQL ¹Ԥ';
+$strRunSQLQueryOnServer = 'С%sפ SQL ¹Ԥ';
 $strRussian = '';
 
-$strSaveOnServer = 'С %s ǥ쥯ȥ¸';
 $strSave = '¸';
+$strSaveOnServer = 'СΥǥ쥯ȥ%sפ¸';
 $strScaleFactorSmall = '1 ڡ˿ɽ֤뤿ˤ礭᤮ޤ';
 $strSearchFormTitle = 'ǡ١򸡺';
 $strSearchInTables = 'ơ֥λ:';
@@ -663,12 +682,12 @@ $strSelectNumRows = 'Ȳ';
 $strSelectTables = 'ơ֥';
 $strSend = 'ե¸';
 $strSent = '';
-$strServer = 'С';
 $strServerChoice = 'С򤹤';
 $strServerNotResponding = 'Сȿޤ';
+$strServer = 'С';
 $strServerStatusDelayedInserts = 'ٱ䥤󥵡';
-$strServerStatusUptime = 'MySQLС %s ưǡ%s ˵ưƤޤ';
 $strServerStatus = '󥿥';
+$strServerStatusUptime = ' MySQL С %s ưǡ%s ˵ưƤޤ';
 $strServerTabProcesslist = 'ץ';
 $strServerTabVariables = 'ѿ';
 $strServerTrafficNotes = '<b>Сȥեå</b>: Υơ֥ MySQL СưƤΥͥåȥȥեåפɽޤ';
@@ -679,7 +698,8 @@ $strSetEnumVal = 'եɥפenumϡsetפξͤˤν񼰤ȤäϤƤ: \'a\',\'b\',\'c\'...<br
 $strShowAll = '٤ɽ';
 $strShowColor = 'ɽ';
 $strShowDatadictAs = 'ǡ';
-$strShowFullQueries = 'եȲɽ';
+$strShow = 'ɽ';
+$strShowFullQueries = 'ʾȲɽ';
 $strShowGrid = 'åɤɽ';
 $strShowingBookmark = '֥åޡ';
 $strShowingRecords = '쥳ɤɽ';
@@ -687,15 +707,23 @@ $strShowOpenTables = 'Ƥơ֥ɽ';
 $strShowPHPInfo = 'PHP ';
 $strShowSlaveHosts = '졼֥ۥȤɽ';
 $strShowSlaveStatus = '졼֤ξ֤ɽ';
+$strShowStatusBinlog_cache_disk_useDescr = 'ƥݥХʥåѤ褦Ȥơbinlog_cache_sizeͤĶᤷᡢȥ󥶥ΥơȥȤƥݥե¸ȥ󥶥ο';
 $strShowStatusBinlog_cache_useDescr = 'ХʥåѤοǤ';
 $strShowStatusCreated_tmp_disk_tablesDescr = 'ʸ¹˥СˤäƼưŪ˥ǥ˺줿ơ֥οǤCreated_tmp_disk_tables 礭硢ΰơ֥ǥ١Ѥ˥١ˤ褦ˡ tmp_table_size 䤷Ǥ礦';
 $strShowStatusCreated_tmp_filesDescr = 'mysqld ϤɤΰŪեǤ';
+$strShowStatusCreated_tmp_tablesDescr = 'Сǹʸμ¹ԤˤäƼưŪ˺줿ΰơ֥ο';
 $strShowStatusDelayed_errorsDescr = '㴳Υ顼ȯ INSERT DELAYED 񤫤줿ԿǤ (餯νʣ)';
+$strShowStatusDelayed_insert_threadsDescr = ' INSERT DELAYED ϥɥ顼åɤοINSERT DELAYED ŬѤۤʤơ֥οͭΥåɤѰդޤ';
 $strShowStatusDelayed_writesDescr = 'INSERT DELAYED 񤭹ߤ򤷤Ǥ';
 $strShowStatusFlush_commandsDescr  = 'FLUSH ʸ¹ԤǤ';
 $strShowStatusHandler_commitDescr = 'COMMIT ʸǤ';
 $strShowStatusHandler_deleteDescr = 'ơ֥뤫Ǥ';
+$strShowStatusHandler_discoverDescr = 'MySQLФNDB饹ȥ졼󥸥̾ĥơ֥ˤĤƤξäƤ뤫䤤碌뤳ȤǤޤϳȸƤФƤޤHandler_discoverϡ줿ơ֥ο򼨤ޤ';
+$strShowStatusHandler_read_firstDescr = 'ǥåϤΥȥɤ߹Ǥ줬⤤硢ϥС¿δʥǥåԤäƤȼޤ㤨СSELECT col1 FROM fooפ col1 ϥǥåȲꤷޤ';
 $strShowStatusHandler_read_keyDescr = '˴ŤƹԤɤ߹׵οǤ줬⤤硢ϤʤξȲȥơ֥뤬Ŭڤ˥ǥåդƤȤ褤ɽǤ';
+$strShowStatusHandler_read_nextDescr = 'ν̤˹ԤɤǤꥯȤοͤϰϤĤƥǥåȲ񤷤Ƥ뤫ǥåԤäƤȤޤ';
+$strShowStatusHandler_read_prevDescr = 'ν̤˹Ԥ̤äɤǤꥯȤοɤ߹ߤϼORDER BY ... DESCŬȤѤޤ';
+$strShowStatusHandler_read_rndDescr = 'ꤵ줿֤ɤǤꥯȤοͤϷ̤򥽡ȤɬפȲ̤˹Ԥȹ⤯ʤޤ餯ơ֥Τ򥹥󤷤ʤФʤʤȲ̤˹ԤäƤ뤫ŬڤѤƤʤjoinԤäƤΤȻפޤ';
 $strShowStatusHandler_read_rnd_nextDescr = 'ǡեμιԤɤ߹׵οǤʤ¿Υơ֥륹򤷤Ƥ硢Ϲ⤤Ǥ̤ˤϡʤΥơ֥뤬Ŭڤ˥ǥåդʤȲ񤬥ǥåѤ褦˽񤫤ƤʤȤ򼨺ޤ';
 $strShowStatusHandler_rollbackDescr = ' ROLLBACK ʸοǤ';
 $strShowStatusHandler_updateDescr = 'ơ֥ιԤι׵ᤷǤ';
@@ -704,8 +732,14 @@ $strShowStatusInnodb_buffer_pool_pages_dataDescr = 'ǡޤڡοǤ (dirty or clean).
 $strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'ߤαڡοǤ';
 $strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'եå夵뤳Ȥ׵ᤷХåեסڡοǤ';
 $strShowStatusInnodb_buffer_pool_pages_freeDescr = 'ڡǤ';
+$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'InnoDBХåեסǥåƤڡϸɤ߹Ǥ롢뤤Ͻ񤭹Ǥڡ뤤¾β餫ͳǥեå夷ǤʤʤäƤڡοǤ';
+$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'ԥå䥢ץƥ֥ϥå奤ǥåȤäХإåɤΤǥӥˤʤäƤڡͤInnodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_dataȤǤ׻Ǥޤ';
 $strShowStatusInnodb_buffer_pool_pages_totalDescr = 'ڡΥХåեסΥιפǤ';
+$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'InnoDBϤ֥ɤ߹ߤβϾȲ񤬥ơ֥ʬʽ֤ǥ󤹤Ȥȯޤ';
+$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'InnoDBϤ󥷥ɤ߹ߤβInnoDB󥷥ʥեơ֥륹ԤȤȯޤ';
 $strShowStatusInnodb_buffer_pool_read_requestsDescr = 'InnoDB ԤäŪɤ߹׵οǤ';
+$strShowStatusInnodb_buffer_pool_readsDescr = 'InnoDBХåեסƤѤǤ󥰥ڡɤ߹ߤԤʤФʤʤäɤ߹ߤβ';
+$strShowStatusInnodb_buffer_pool_wait_freeDescr = '̾InnoDBХåեסؤν񤭹ߤϥХå饦ɤǹԤޤڡɤ߹ߤʤԤɬפΤ˥꡼ʥڡʤϡޤΥڡեå夵ΤԤɬפޤΥ󥿤ϡΥȤβ򥫥ȤΤǤХåեסͤŬڤꤵƤСͤϾϤǤ';
 $strShowStatusInnodb_buffer_pool_write_requestsDescr = 'InnoDB Хåեסؤν񤭹ߤ򤷤Ǥ';
 $strShowStatusInnodb_data_fsyncsDescr = 'ޤǤ fsync() Ǥ';
 $strShowStatusInnodb_data_pending_fsyncsDescr = 'ߤ fsync() αοǤ';
@@ -715,6 +749,9 @@ $strShowStatusInnodb_data_readDescr = 'ޤǤΥǡɤ߹̤Ǥ(ñ:Х)';
 $strShowStatusInnodb_data_readsDescr = 'ɤ߹ߥǡοǤ';
 $strShowStatusInnodb_data_writesDescr = '񤭹ߥǡοǤ';
 $strShowStatusInnodb_data_writtenDescr = 'ޤǤΥǡν񤭹̤Ǥ(ñ:Х)';
+$strShowStatusInnodb_dblwr_pages_writtenDescr = 'Ž񤭹ߤ¹Ԥ줿ȡŽ񤭹ߤȯڡ';
+$strShowStatusInnodb_dblwr_writesDescr = 'Ž񤭹ߤ¹Ԥ줿ȡŽ񤭹ߤȯڡ';
+$strShowStatusInnodb_log_waitsDescr = 'Хåե뤻ǺȤ³Ԥ˥եå夷ʤФʤʤʤäȯȤβ';
 $strShowStatusInnodb_log_write_requestsDescr = '׵ᤵ줿񤭹ߤοǤ';
 $strShowStatusInnodb_log_writesDescr = 'եؤʪŪʽߤοǤ';
 $strShowStatusInnodb_os_log_fsyncsDescr = 'ե fsync 񤭹ߤ򤷤Ǥ';
@@ -741,6 +778,7 @@ $strShowStatusKey_read_requestsDescr = 'å夫饭֥åɤ߹ꥯȿǤ';
 $strShowStatusKey_readsDescr = 'ǥΥ֥åʪŪɤ߹߿ǤKey_reads 礭硢 key_buffer_size 餯ޤåߥΨ Key_reads/Key_read_requests ȤƷ׻뤳ȤǤޤ';
 $strShowStatusKey_write_requestsDescr = 'åؤΥ֥åν񤭹ꥯȿǤ';
 $strShowStatusKey_writesDescr = 'ǥؤΥ֥åʪŪʽ񤭹߿Ǥ';
+$strShowStatusLast_query_costDescr = 'Ȳ񥪥ץƥޥˤäƷ׻줿Ǹ˥ѥ뤵줿ȲȤǤƱȲΰۤʤȲץΥȤӤΤΩޤǥե 0 ϡȲ񤬤ޤѥ뤵ƤʤȤ̣ޤ';
 $strShowStatusNot_flushed_delayed_rowsDescr = 'Ȳ INSERT DELAY ν񤭹ԤιԿǤ';
 $strShowStatusOpened_tablesDescr = 'Ƥơ֥οǤƤơ֥뤬¿硢餯ơ֥륭åͤޤ';
 $strShowStatusOpen_filesDescr = 'ƤեοǤ';
@@ -750,6 +788,7 @@ $strShowStatusQcache_free_blocksDescr = 'Ȳ񥭥åζ֥åοǤ';
 $strShowStatusQcache_free_memoryDescr = 'Ȳ񥭥åζ̤Ǥ';
 $strShowStatusQcache_hitsDescr = 'åΥҥåȿǤ';
 $strShowStatusQcache_insertsDescr = 'åɲä줿ȲǤ';
+$strShowStatusQcache_lowmem_prunesDescr = 'Ȳ򥭥å夹뤿˥٤å夫줿ȲοξϾȲ񥭥åΥĴȤǤȲ񥭥å夬å夫ȲꤹݤˤϡǸ˻Ȥ줿郎ǤŤΤάȤޤ';
 $strShowStatusQcache_not_cachedDescr = 'å夵ʤȲοǤ (åǤʤ query_cache_type ˤ륭å夷ʤ)';
 $strShowStatusQcache_queries_in_cacheDescr = 'åϿ줿ȲοǤ';
 $strShowStatusQcache_total_blocksDescr = 'Ȳ񥭥å֥åǤ';
@@ -757,6 +796,7 @@ $strShowStatusReset = 'ꥻå';
 $strShowStatusRpl_statusDescr = 'ե륻եץꥱξ֤Ǥ (Ƥޤ)';
 $strShowStatusSelect_full_joinDescr = 'ǥåѤʤοǤͤ 0 Ǥʤ硢տơ֥Υǥåǧ٤Ǥ';
 $strShowStatusSelect_full_range_joinDescr = 'Ϣơ֥ϰϸѤοǤ';
+$strShowStatusSelect_range_checkDescr = 'ʤjoinϳƹԤˤĤƥλ٤åΤǤʤ줬0ʳξϥơ֥Υǥå褯åƤˡ';
 $strShowStatusSelect_rangeDescr = 'ǽΥơ֥ϰϤѤοǤ (줬礭Ƥ̾ϴǤϤޤ)';
 $strShowStatusSelect_scanDescr = 'ǽΥơ֥δʥԤäοǤ';
 $strShowStatusSlave_open_temp_tablesDescr = '졼 SQL åɤˤäƸ߳ƤŪơ֥οǤ';
@@ -764,17 +804,19 @@ $strShowStatusSlave_retried_transactionsDescr = 'ץꥱΥ졼 SQL åɤȥ󥶥ƻԤ(
 $strShowStatusSlave_runningDescr = 'ΥСޥ³륹졼֤Ǥ硢 ON Ǥ';
 $strShowStatusSlow_launch_threadsDescr = 'slow_launch_time ÿ֤äƺ줿åɤοǤ';
 $strShowStatusSlow_queriesDescr = 'long_query_time ÿۤȲοǤ';
+$strShowStatusSort_merge_passesDescr = 'ȥ르ꥺब¹ԤʤФʤʤäޡβͤ⤤ϡsort_buffer_sizeƥѿͤ䤹ȤƤƤ';
+$strShowStatusSort_rangeDescr = 'ϰǥȤԤ줿';
 $strShowStatusSort_rowsDescr = 'ȺѤιԿǤ';
 $strShowStatusSort_scanDescr = 'ơ֥ˤԤ줿ȿǤ';
 $strShowStatusTable_locks_immediateDescr = 'ơ֥å˼줿Ǥ';
-$strShowStatusThreads_cachedDescr = 'åɥåΥåɿǤåҥåΨThreads_created/Connections ȤƷ׻뤳ȤǤޤ֤ͤ硢thread_cache_size 夲٤Ǥ';
+$strShowStatusTable_locks_waitedDescr = 'ơ֥å˼Ǥʤä˥Ȥȯͤ⤯ѥեޥ󥹤꤬ƤϡޤȲŬƤǤʤ顢ơ֥ʬ䤹뤫ץꥱѤƤ';
+$strShowStatusThreads_cachedDescr = 'åɥåΥåɿǤåҥåΨ Threads_created/Connections ȤƷ׻뤳ȤǤޤ֤ͤ硢thread_cache_size 夲٤Ǥ';
 $strShowStatusThreads_connectedDescr = '³οǤ';
 $strShowStatusThreads_createdDescr = '³򰷤˺줿åɤοǤThreads_created 礭硢 thread_cache_size äȻפ⤷ޤ(̾褤åɼ򤷤Ƥ硢ϸʥѥեޥ󥹸Ϳޤ)';
 $strShowStatusThreads_runningDescr = '꡼פƤʤåɤοǤ';
 $strShowTableDimension = 'ơ֥礭ɽ';
 $strShowTables = 'ơ֥ɽ';
 $strShowThisQuery = ' ¹ԤȲ򤳤ɽ';
-$strShow = 'ɽ';
 $strSimplifiedChinese = 'λ';
 $strSingly = '(1 )';
 $strSize = '';
@@ -782,14 +824,15 @@ $strSkipQueries = 'Ϥ饹åפ쥳(Ȳ)ο';
 $strSlovak = 'Х';
 $strSlovenian = '٥˥';
 $strSocketProblem = '(ޤϡ MySQL СΥåȤΤꤵޤ)';
-$strSort = '';
 $strSortByKey = 'ǥ';
 $strSorting = '';
+$strSort = '';
 $strSpaceUsage = 'ǥ';
 $strSpanish = 'ڥ';
 $strSplitWordsWithSpace = 'ñϥڡʸ(" ")ǶڤäƲ';
-$strSQLExportCompatibility = 'SQL ݡȸߴ';
+$strSQLExportCompatibility = 'SQL ߴݡ';
 $strSQLExportType = 'ݡȷ';
+$strSQLImportOptions = 'SQL ץ';
 $strSQLOptions = 'SQL ץ';
 $strSQLParserBugMessage = 'ʤ SQL ѡΥХ򸫤뤫⤷ޤ󡣤ʤ䤤碌ǰ˳Τơ䤬ߥޥåʤåޤ礦¾μԤˤϥƥȥꥢǰѤ¦˥Хʥ꡼ɤդƥե뤬åץɤƤޤä褦ʸͤޤޤʤ䤤碌 MySQL Υޥɥ饤ȤäƻȤǤޤMySQL СϰʲΤ褦˥顼Фޤˤ褹Ǥ礦ޥɥ饤ǤƤ⡢ޤ꤬硢ѡԤˤϡΤ SQL 䤤碌ҤȤĤʸ˸餷ƤߤƲưʲΥǥǡڤäƥХäƲ:';
 $strSQLParserUserError = 'SQL ˥顼ޤMySQL СϰʲΤ褦˥顼Ϥޤˤ褹Ǥ礦';
@@ -802,6 +845,7 @@ $strSQPBugUnknownPunctuation = '̵ʶʸǤ';
 $strStatCheckTime = 'ǽ';
 $strStatCreateTime = '';
 $strStatement = 'ơȥ';
+$strStatisticsOverrun = 'ӥʥСǤϡХȥ󥿡Ķ᤹뤫⤷ޤ󡣽äơMySQL С𤹤뤽פʤ⤷ޤ';
 $strStatUpdateTime = 'ǽ';
 $strStatus = '';
 $strStorageEngine = 'ȥ졼󥸥';
@@ -840,31 +884,38 @@ $strTempData = 'ǡ';
 $strTextAreaLength = ' Ĺν٤ǤΥեɤ<br /> Ǥʤǽޤ';
 $strThai = '';
 $strTheme = 'ơ / ';
+$strThemeDefaultNotFound = 'ǥեȥơޡ%sפĤޤ!';
+$strThemeNoPreviewAvailable = 'ץӥ塼ѤǤޤ';
+$strThemeNotFound = 'ơޡ%sפĤޤ!';
+$strThemeNoValidImgPath = 'ơޡ%sפѥĤޤ!';
+$strThemePathNotFound = 'ơޡ%sפΥơޥѥĤޤ!';
 $strThisHost = 'Υۥ';
 $strThisNotDirectory = 'ϥǥ쥯ȥǤϤޤ';
 $strThreads = 'å';
 $strThreadSuccessfullyKilled = 'å %s Ͻλޤ';
+$strTimeoutInfo = '˥ݡȤǥॢȤƤޤ塢 %d ³Ǥ礦';
+$strTimeoutNothingParsed = 'Ǹμ¹ԤǤΥǡϲϤƤޤ󡣤ϡ̾ php λ¤䤵ʤ phpMyAdmin ΥݡȤλ뤳ȤǤʤȤȤ̣ޤ';
 $strTimeoutPassed = 'ץȤॢȤ᤮ޤݡȤ򽪤餻硢ƱեݡȤƳƤ';
 $strTime = '';
 $strToggleScratchboard = 'ȥ륹åܡ';
-$strTotalUC = '';
 $strTotal = '';
+$strTotalUC = '';
 $strTraditionalChinese = 'Ū';
 $strTraditionalSpanish = 'Ūʥڥ';
 $strTraffic = 'ȥեå';
 $strTransactionCoordinator = 'ȥ󥶥󥳡ǥ͡';
-$strTransformation_application_octetstream__download = 'եɤΥХʥǡɤ󥯤ɽޤҤȤĤΥץϥХʥեΥե̾ǤդĤΥץϥե̾ޤơ֥Ԥե̾ǤդĤΥץ󶡤硢ҤȤĤΥץ϶ʸꤹɬפޤ';
+$strTransformation_application_octetstream__download = 'եɤΥХʥǡɤ󥯤ɽޤ1 ܤΥץϥХʥեΥե̾Ǥ2 ܥץϥե̾ޤơ֥Ԥե̾Ǥ2 ܤΥץ󶡤硢1 ܤΥץ϶ʸꤹɬפޤ';
 $strTransformation_application_octetstream__hex = 'ǡ 16 ʿɽǤ';
 $strTransformation_image_jpeg__inline = 'åǽʥͥɽޤ; ץ: widthheight ԥǻ (Ψݤޤ)';
 $strTransformation_image_jpeg__link = 'βؤΥ󥯤ɽ (㤨 blob ľܥ).';
 $strTransformation_image_png__inline = 'image/jpeg: inlineפ򻲾ȤƤ';
-$strTransformation_text_plain__dateformat = 'TIMETIMESTAMP뤤DATETIMEեɤǡɽѤƽ񼰲ޤ1 ܤΥץϥॹפ˲û륪եåȻ(ñ:)Ǥ(ǥե: 0)2 ܤΥץϡPHP  strftime()Ѳǽʥѥ᡼ǤΤޤޤɽǤ';
+$strTransformation_text_plain__dateformat = 'TIMETIMESTAMP 뤤 DATETIME եɤǡɽѤƽ񼰲ޤ1 ܤΥץϥॹפ˲û륪եåȻ(ñ:)Ǥ(ǥե: 0)2 ܤΥץϡPHP  strftime()Ѳǽʥѥ᡼ǤΤޤޤɽǤ';
 $strTransformation_text_plain__external = 'LINUX Τ: ץꥱưɸϤեɥǡϤޤץꥱɸϤ֤ޤǥեȤ Tidy ǡ HTML ɤϤޤƥͳǡưǥեlibraries/text_plain__external.inc.phpפԽ¹ԤĤġʤФʤޤ󡣺ǽΥץϡѤץοǡ2 ܤΥץϥץΥѥ᡼Ǥ3 ܤΥץ 1 ꤵƤ硢htmlspecialchars() ѤƽϤѴǤ礦(ǥե: 1)4  ץ 1 ꤵƤ硢§ɤϤ٤ 1 Ԥ˸뤳ȤݾڤǤ礦(ǥե: 1).';
 $strTransformation_text_plain__formatted = 'եɤθν񼰤¸ޤפ˽λޤ';
-$strTransformation_text_plain__imagelink = 'ȥ󥯡ե̾ޤեɤɽޤ; ҤȤĤΥץ "http://domain.com/" Τ褦ƬǡդĤΥץϥԥߤäĤϹ⤵Ǥ';
-$strTransformation_text_plain__link = 'ե̾ޤեɡ󥯤ɽ; ҤȤܤΥץ "http://domain.com/" Τ褦Ƭ졢ܤΥץϥ󥯤ΥȥǤ';
+$strTransformation_text_plain__imagelink = 'ȥ󥯡ե̾ޤեɤɽޤ; 1 ܤΥץ "http://domain.com/" Τ褦Ƭǡ2 ܤΥץϥԥ3 ܤϹ⤵Ǥ';
+$strTransformation_text_plain__link = 'ե̾ޤեɡ󥯤ɽ; 1 ܤΥץ "http://domain.com/" Τ褦Ƭ졢2 ܤΥץϥ󥯤ΥȥǤ';
 $strTransformation_text_plain__sql = 'SQL Ҳ ȤƥƥȤηʸˡϥ饤Ȥޤ';
-$strTransformation_text_plain__substr = 'ʸΰΤɽޤ1 ܤΥץϥƥȤνϤɤǳϤ뤫եåȤޤ (ǥեȤϡ0פǤ)ܤΥץϤɤΥƥȤ֤ΥեåȤǤξ硢ĤΥƥȤ򤹤٤֤ޤܤΥץϡʸΰ֤ɤʸϤɲä뤫ޤ (ǥեȤϡ...פǤ)';
+$strTransformation_text_plain__substr = 'ʸΰΤɽޤ1 ܤΥץϥƥȤνϤɤǳϤ뤫եåȤޤ (ǥեȤϡ0פǤ)2 ܤΥץϤɤΥƥȤ֤ΥեåȤǤξ硢ĤΥƥȤ򤹤٤֤ޤ3 ܤΥץϡʸΰ֤ɤʸϤɲä뤫ޤ (ǥեȤϡ...פǤ)';
 $strTruncateQueries = 'Ȳɽڤͤ';
 $strTurkish = 'ȥ륳';
 $strType = 'եɥ';
@@ -875,18 +926,19 @@ $strUnicode = 'UNICODE';
 $strUnique = '';
 $strUnknown = '';
 $strUnselectAll = '';
-$strUnsupportedCompressionDetected = 'ݡȤƤʤ̷(%s)Υեɤ߹ߤߤޤΥݡȤƤʤ̵ˤʤäƤ뤫Τ줫Ǥ';
+$strUnsupportedCompressionDetected = 'ݡȤƤʤ̷(%s)Υեɤ߹ߤߤޤμݡȤƤʤ̵ˤʤäƤ뤫Τ줫Ǥ';
 $strUpdatePrivMessage = '%s ø򹹿ޤ';
 $strUpdateProfileMessage = 'ץե򹹿ޤ';
 $strUpdateQuery = 'Ȳ򹹿';
 $strUpdComTab = 'Column_comments ơ֥Υåץ졼ˡΥɥȤ򻲾ȤƤ';
 $strUpgrade = '%s %s ܹԤ˥åץ졼ɤ٤Ǥ';
-$strUploadLimit = '餯ޤˤ礭ʥե򥢥åץɤ褦Ȥޤ¤βʤȤ %sdocumentation%s 򻲾ȤƤ';
+$strUploadLimit = '餯ޤˤ礭ʥե򥢥åץɤ褦Ȥޤ¤βʤȤ %sɥ%s 򻲾ȤƤ';
 $strUsage = '';
 $strUseBackquotes = 'եȤǥơ֥̾ե̾Ϥ';
+$strUsedPhpExtensions = ' PHP ĥ';
 $strUseHostTable = 'ۥȥơ֥Ȥ';
 $strUser = '桼';
-$strUserAlreadyExists = '桼 %s ϴ¸ߤޤ!';
+$strUserAlreadyExists = '桼%sפϴ¸ߤޤ!';
 $strUserEmpty = '桼̾϶Ǥ';
 $strUserName = '桼̾';
 $strUserNotFound = '򤵤줿桼øơ֥˸ĤޤǤ';
@@ -899,15 +951,16 @@ $strUseTextField = 'ƥȥեɤ';
 $strUseThisValue = 'ͤ';
 
 $strValidateSQL = 'SQL θ';
-$strValidatorError = 'SQL θڵǽǤޤ%sdocumentation%s ˵ҤƤ褦 PHP ĥ饤֥꤬󥹥ȡ뤵Ƥ뤫åƤ';
+$strValidatorError = 'SQL θڵǽǤޤ%sɥ%s ˵ҤƤ褦 PHP ĥ饤֥꤬󥹥ȡ뤵Ƥ뤫åƤ';
 $strValue = '';
 $strVar = 'ѿ';
 $strVersionInformation = 'С';
-$strView = 'ӥ塼';
+$strViewDump = 'ơ֥Υ()ɽ';
 $strViewDumpDatabases = 'ǡ١Υץӥ塼 ()';
 $strViewDumpDB = 'DB Υ()ɽ';
-$strViewDump = 'ơ֥Υ()ɽ';
 $strViewHasBeenDropped = 'ӥ塼 %s ˴ޤ';
+$strViewMaxExactCount = 'Υӥ塼 %s ʾ夢ޤ%sɥ%s 򻲾ȤƤ';
+$strView = 'ӥ塼';
 
 $strWebServerUploadDirectoryError = 'åץɤԤǥ쥯ȥ꤬ޤ';
 $strWebServerUploadDirectory = '֥Сǥåץɤ';
@@ -929,41 +982,4 @@ $strYes = 'Ϥ';
 $strZeroRemovesTheLimit = ': ץ 0 ()ꤹ¤ʤʤޤ';
 $strZip = '"zip "';
 
-// To translate:
-
-$strEnclosingOptional = 'Enclosing of fields is optional';  //to translate
-
-$strLatchedPages = 'Latched pages';  //to translate
-
-$strMIME_nodescription = 'Ѵˤͭޤ<br />Please ask the author, what %s does.';//to translate
-$strMIME_transformation_options_note = 'ν񼰤ѤơѴץͤϤƤ: \'a\',\'b\',\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, backslashes it (㤨С\\\\xyzפa\\\'b)';//to translate
-$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
-
-$strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
-$strShowStatusCreated_tmp_tablesDescr = 'Сǹʸμ¹ԤˤäƼưŪ˺줿ΰơ֥οǤ';  //to translate
-$strShowStatusDelayed_insert_threadsDescr = ' INSERT DELAYED ϥɥ顼åɤοǤEvery different table on which one uses INSERT DELAYED gets its own thread.';  //to translate
-$strShowStatusHandler_discoverDescr = 'The MySQL server can ask the NDB Cluster storage engine if it knows about a table with a given name. This is called discovery. Handler_discover indicates the number of time tables have been discovered.';  //to translate
-$strShowStatusHandler_read_firstDescr = 'ǥåϤΥȥɤ߹Ǥ줬⤤硢ϥС¿δʥǥåԤäƤȼޤ㤨СSELECT col1 FROM fooפ col1 ϥǥåȲꤷޤ';
-$strShowStatusHandler_read_nextDescr = 'The number of requests to read the next row in key order. This is incremented if you are querying an index column with a range constraint or if you are doing an index scan.';  //to translate
-$strShowStatusHandler_read_prevDescr = 'The number of requests to read the previous row in key order. This read method is mainly used to optimize ORDER BY ... DESC.';  //to translate
-$strShowStatusHandler_read_rndDescr = 'The number of requests to read a row based on a fixed position. This is high if you are doing a lot of queries that require sorting of the result. You probably have a lot of queries that require MySQL to scan whole tables or you have joins that don\'t use keys properly.';  //to translate
-$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'The number of latched pages in InnoDB buffer pool. These are pages currently being read or written or that can\'t be flushed or removed for some other reason.';  //to translate
-$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'The number of pages busy because they have been allocated for administrative overhead such as row locks or the adaptive hash index. This value can also be calculated as Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';  //to translate
-$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'The number of "random" read-aheads InnoDB initiated. This happens when a query is to scan a large portion of a table but in random order.';  //to translate
-$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'The number of sequential read-aheads InnoDB initiated. This happens when InnoDB does a sequential full table scan.';  //to translate
-$strShowStatusInnodb_buffer_pool_readsDescr = 'The number of logical reads that InnoDB could not satisfy from buffer pool and had to do a single-page read.';  //to translate
-$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normally, writes to the InnoDB buffer pool happen in the background. However, if it\'s necessary to read or create a page and no clean pages are available, it\'s necessary to wait for pages to be flushed first. This counter counts instances of these waits. If the buffer pool size was set properly, this value should be small.';  //to translate
-$strShowStatusInnodb_dblwr_pages_writtenDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
-$strShowStatusInnodb_dblwr_writesDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
-$strShowStatusInnodb_log_waitsDescr = 'The number of waits we had because log buffer was too small and we had to wait for it to be flushed before continuing.';  //to translate
-$strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusQcache_lowmem_prunesDescr = 'The number of queries that have been removed from the cache to free up memory for caching new queries. This information can help you tune the query cache size. The query cache uses a least recently used (LRU) strategy to decide which queries to remove from the cache.';  //to translate
-$strShowStatusSelect_range_checkDescr = 'The number of joins without keys that check for key usage after each row. (If this is not 0, you should carefully check the indexes of your tables.)';  //to translate
-$strShowStatusSort_merge_passesDescr = 'The number of merge passes the sort algorithm has had to do. If this value is large, you should consider increasing the value of the sort_buffer_size system variable.';  //to translate
-$strShowStatusSort_rangeDescr = 'The number of sorts that were done with ranges.';  //to translate
-$strShowStatusTable_locks_waitedDescr = 'The number of times that a table lock could not be acquired immediately and a wait was needed. If this is high, and you have performance problems, you should first optimize your queries, and then either split your table or tables or use replication.';  //to translate
-
-$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
-$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
-
 ?>
