@@ -1,6 +1,6 @@
 <?php
 
-/* $Id: persian-windows-1256.inc.php,v 2.96 2005/10/30 10:03:50 nijel Exp $ */
+/* $Id: persian-windows-1256.inc.php,v 2.118.2.3 2006/03/23 17:42:14 lem9 Exp $ */
 /*
 Persian(Farsi) translation by : Bornis Group
 www.BornisGroup.com
@@ -187,9 +187,7 @@ $strModify = '';
 $strMoveTableOK = ' %s  %s  .';
 $strMoveTable = '   ( <b>.</b>):';
 $strMySQLCharset = '  MySQL';
-$strMySQLReloaded = 'MySQL  ѐ .';
 $strMySQLSaid = ' MySQL :';
-$strMySQLServerProcess = 'MySQL %pma_s1%    %pma_s2%  %pma_s3%';
 $strMySQLShowProcess = ' ';
 $strMySQLShowStatus = '  MySQL';
 $strMySQLShowVars = '   MySQL';
@@ -457,7 +455,6 @@ $strDescription = 'Description'; //to translate
 $strDictionary = 'dictionary'; //to translate
 $strDisableForeignChecks = 'Disable foreign key checks';  //to translate
 $strDropDatabaseStrongWarning = 'You are about to DESTROY a complete database!';  //to translate
-$strDropSelectedDatabases = 'Drop Selected Databases'; //to translate
 $strDropUsersDb = 'Drop the databases that have the same names as the users.'; //to translate
 $strDumpSaved = 'Dump has been saved to file %s.'; //to translate
 
@@ -472,7 +469,6 @@ $strFailedAttempts = 'Failed attempts'; //to translate
 $strFileAlreadyExists = 'File %s already exists on server, change filename or check overwrite option.'; //to translate
 $strFileCouldNotBeRead = 'File could not be read'; //to translate
 $strFileNameTemplate = 'File name template'; //to translate
-$strFileNameTemplateHelp = 'Use __DB__ for database name, __TABLE__ for table name and %sany strftime%s options for time specification, extension will be automagically added. Any other text will be preserved.'; //to translate
 $strFileNameTemplateRemember = 'remember template'; //to translate
 $strFlushPrivilegesNote = 'Note: phpMyAdmin gets the users\' privileges directly from MySQL\'s privilege tables. The content of these tables may differ from the privileges the server uses if manual changes have made to it. In this case, you should %sreload the privileges%s before you continue.'; //to translate
 
@@ -494,7 +490,6 @@ $strId = 'ID'; //to translate
 $strIgnoreInserts = 'Use ignore inserts';  //to translate
 $strIgnoringFile = 'Ignoring file %s'; //to translate
 $strImportFiles = 'Import files'; //to translate
-$strImportFinished = 'Import finished'; //to translate
 $strInnodbStat = 'InnoDB Status'; //to translate
 $strInsertedRowId = 'Inserted row id:'; //to translate
 $strInternalNotNecessary = '* An internal relation is not necessary when it exists also in InnoDB.'; //to translate
@@ -617,7 +612,6 @@ $strRelationalSchema = 'Relational schema'; //to translate
 $strRelationsForTable = 'RELATIONS FOR TABLE';  //to translate
 $strRelations = 'Relations'; //to translate
 $strRelationView = 'Relation view'; //to translate
-$strReloadFailed = 'MySQL reload failed.'; //to translate
 $strReloadingThePrivileges = 'Reloading the privileges'; //to translate
 $strRemoveSelectedUsers = 'Remove selected users'; //to translate
 $strRenameDatabaseOK = 'Database %s has been renamed to %s';  //to translate
@@ -827,7 +821,6 @@ $strImportFormat = 'Format of imported file';  //to translate
 $strFileToImport = 'File to import';  //to translate
 $strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
 $strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
-$strEnclosingOptional = 'Enclosing of fields is optional';  //to translate
 $strCSVImportOptions = 'CSV options';  //to translate
 $strPartialImport = 'Partial import';  //to translate
 $strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
@@ -839,7 +832,6 @@ $strNothingToImport = 'You didn\'t enter any data to import!';  //to translate
 $strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
 $strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
 $strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
-$strInvalidCSVInput = 'Invalid CSV input, could not parse!';  //to translate
 $strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
 $strErrorInZipFile = 'Error in ZIP archive:';  //to translate
 $strFlushQueryCache = 'Flush query cache';  //to translate
@@ -980,4 +972,34 @@ $strBookmarkCreated = 'Bookmark %s created';  //to translate
 $strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
 $strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
 $strEsperanto = 'Esperanto';  //to translate
+$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate
+$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
+$strFileNameTemplateDescriptionTable = 'table name';  //to translate
+$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
+$strFileNameTemplateDescriptionServer = 'server name';  //to translate
+$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
+$strProtocolVersion = 'Protocol version';  //to translate
+$strMysqlClientVersion = 'MySQL client version';  //to translate
+$strUsedPhpExtensions = 'Used PHP extensions';  //to translate
+$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
+$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
+$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
+$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
+$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
+$strPDF = 'PDF';  //to translate
+$strPDFOptions = 'PDF options';  //to translate
+$strPDFReportTitle = 'Report title';  //to translate
+$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
+$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
+$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
+$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
+$strThemeNotFound = 'Theme %s not found!';  //to translate
+$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
+$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
+$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
+$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
+$strSQLImportOptions = 'SQL options';  //to translate
+$strBrowseDistinctValues = 'Browse distinct values';  //to translate
+$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
+$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
 ?>
