@@ -1,5 +1,5 @@
 <?php
-/* $Id: slovak-windows-1250.inc.php,v 2.101 2005/10/30 15:57:28 nijel Exp $ */
+/* $Id: slovak-windows-1250.inc.php,v 2.123.2.3 2006/03/23 17:42:15 lem9 Exp $ */
 
 /* By: lubos klokner <erkac@vault-tec.sk> */
 /* and Ivan Kuriscak <shylauda69@yahoo.com> */
@@ -236,7 +236,6 @@ $strDocu = 'Dokumentcia';
 $strDoYouReally = 'Skutone chcete vykona prkaz ';
 $strDropDatabaseStrongWarning = 'Chystte sa ZRUI cel databzu!';
 $strDrop = 'Odstrni';
-$strDropSelectedDatabases = 'Zrui vybran databzy';
 $strDropUsersDb = 'Odstrni databzy s rovnakm menom ako maj pouvatelia.';
 $strDumpingData = 'Sahujem dta pre tabuku';
 $strDumpSaved = 'Dump (schma) bol uloen do sboru %s.';
@@ -251,7 +250,6 @@ $strEmptyResultSet = 'MySQL vrtil przdny vsledok (tj. nulov poet riadkov).';
 $strEmpty = 'Vyprzdni';
 $strEnabled = 'Zapnut';
 $strEncloseInTransaction = 'Uzatvori prkazy v transakcii';
-$strEnclosingOptional = 'Uzatvorenie stpcov je voliten';
 $strEndCut = 'KONIEC VSEKU';
 $strEnd = 'Koniec';
 $strEndRaw = 'KONIEC TOKU';
@@ -284,7 +282,6 @@ $strFields = 'Polia';
 $strFieldsTerminatedBy = 'Polia ukonen';
 $strFileAlreadyExists = 'Sbor %s u existuje na servery, zmente nzov sboru alebo zvolte prepsanie sboru.';
 $strFileCouldNotBeRead = 'Sbor sa ned preta';
-$strFileNameTemplateHelp = 'Pouite __DB__ ako nzov databzy, __TABLE__ ako nzov tabuky a akkovek parametre pre %sfunkciu strftime%s pre vloenie dt. Prpona sboru bude pridan automaticky poda typu. Akkovek in text zostane zachovan.';
 $strFileNameTemplateRemember = 'zapamta si vzor';
 $strFileNameTemplate = 'Vzor pre nzov sboru';
 $strFileToImport = 'Sbor na importovanie';
@@ -339,7 +336,6 @@ $strIgnoreInserts = 'Poui IGNORE';
 $strIgnoringFile = 'Ignorujem sbor %s';
 $strImportDocSQL = 'Importova sbory docSQL';
 $strImportFiles = 'Importova sbory';
-$strImportFinished = 'Import bol spene ukonen.';
 $strImportFormat = 'Formt importovanho sboru';
 $strImport = 'Import';
 $strIndexes = 'Indexy';
@@ -372,7 +368,6 @@ $strInUse = 'prve sa pouva';
 $strInvalidAuthMethod = 'V konfigurcii je nastaven nesprvna autentifikan metda:';
 $strInvalidColumn = 'Bol zadan chybn stpec (%s)!';
 $strInvalidColumnCount = 'Poet stpcov mus by v ako nula.';
-$strInvalidCSVInput = 'Neplatn CSV dta, nebolo mon nata!';
 $strInvalidFieldAddCount = 'Muste prida aspo jeden stpec.';
 $strInvalidFieldCount = 'Tabuka mus obsahova aspo jeden stpec.';
 $strInvalidLDIImport = 'Tento plug-in nepodporuje import komprimovanch sborov!';
@@ -458,9 +453,7 @@ $strMyISAMSortBufferSizeDesc = 'Pam, ktor je alokovan pri zoraovan MyISAM indexo
 $strMyISAMSortBufferSize = 'Vekos zoraovacej pamte';
 $strMySQLCharset = 'Znakov sada v MySQL';
 $strMySQLConnectionCollation = 'Overenie MySQL spojenia';
-$strMySQLReloaded = 'MySQL znovu-natan.';
 $strMySQLSaid = 'MySQL hlsi: ';
-$strMySQLServerProcess = 'MySQL %pma_s1% be na %pma_s2% ako %pma_s3%';
 $strMySQLShowProcess = 'Zobrazi procesy';
 $strMySQLShowStatus = 'Zobrazi MySQL informcie o behu';
 $strMySQLShowVars = 'Zobrazi MySQL systmov premenn';
@@ -608,7 +601,6 @@ $strRelationNotWorking = 'Prdavn vlastnosti pre prcu s prepojenmi tabukami boli
 $strRelationsForTable = 'VZAHY PRE TABUKU';
 $strRelations = 'Prepojenia';
 $strRelationView = 'Zobrazi spojitosti';
-$strReloadFailed = 'Znovu-natanie MySQL bolo nespen.';
 $strReloadingThePrivileges = 'Znovunatanie prv';
 $strReloadMySQL = 'Znovu-nata MySQL';
 $strRemoveSelectedUsers = 'Odstrni vybranch pouvateov';
@@ -954,4 +946,34 @@ $strYes = 'no';
 $strZeroRemovesTheLimit = 'Poznmka: Nastavenie tchto parametrov na 0 (nulu) odstrni obmedzenia.';
 $strZip = '"zo zipovan"';
 
+$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate
+$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
+$strFileNameTemplateDescriptionTable = 'table name';  //to translate
+$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
+$strFileNameTemplateDescriptionServer = 'server name';  //to translate
+$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
+$strProtocolVersion = 'Protocol version';  //to translate
+$strMysqlClientVersion = 'MySQL client version';  //to translate
+$strUsedPhpExtensions = 'Used PHP extensions';  //to translate
+$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
+$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
+$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
+$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
+$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
+$strPDF = 'PDF';  //to translate
+$strPDFOptions = 'PDF options';  //to translate
+$strPDFReportTitle = 'Report title';  //to translate
+$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
+$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
+$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
+$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
+$strThemeNotFound = 'Theme %s not found!';  //to translate
+$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
+$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
+$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
+$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
+$strSQLImportOptions = 'SQL options';  //to translate
+$strBrowseDistinctValues = 'Browse distinct values';  //to translate
+$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
+$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
 ?>
