@@ -1,5 +1,5 @@
 <?php
-/* $Id: slovenian-iso-8859-2.inc.php,v 2.95 2005/10/30 10:03:50 nijel Exp $ */
+/* $Id: slovenian-iso-8859-2.inc.php,v 2.117.2.3 2006/03/23 17:42:15 lem9 Exp $ */
 
 /* By: urska.colner, agenda d.o.o. <urska.colner@agenda.si>, uros kositer, agenda d.o.o. <urosh@agenda.si> */
 
@@ -198,7 +198,6 @@ $strDoYouReally = 'Ali res elite ';
 $strDocu = 'Dokumentacija';
 $strDrop = 'Zavri';
 $strDropDatabaseStrongWarning = 'S tem dejanjem boste UNIILI celotno bazo podatkov!';
-$strDropSelectedDatabases = 'Zavri izbrane podatkovne baze';
 $strDropUsersDb = 'Izbrii podatkovne baze, ki imajo enako ime kot uporabniki.';
 $strDumpSaved = 'Dump je shranjen v datoteko %s.';
 $strDumpXRows = 'Odloi %s vrstic, zani z zapisom # %s.';
@@ -239,7 +238,6 @@ $strFieldsTerminatedBy = 'Polja zakljuena z';
 $strFileAlreadyExists = 'Datoteka %s e obstaja na streniku, spremenite ime novi ali prepiite obstojeo datoteko.';
 $strFileCouldNotBeRead = 'Ne morem prebrati datoteke';
 $strFileNameTemplate = 'Predloga datoteke';
-$strFileNameTemplateHelp = 'Uporabi __DB__ za ime zbirke podatkov, __TABLE__ za ime tabele in monosti %sany strftime%s za navedbo asa, pripone pa bodo dodane samodejno. Ostalo besedilo ostane nespremenjeno.';
 $strFileNameTemplateRemember = 'Shrani predlogo';
 $strFixed = 'fiksno';
 $strFlushPrivilegesNote = 'Obvestilo: phpMyAdmin dobi podatke o uporabnikovih privilegijih iz MySQL tabel privilegijev. Vsebina teh tabel se lahko razlikuje od privilegijev, ki jih uporablja strenik, e so bile tabele rono spremenjene. V tem primeru morate, preden nadaljujete, osveiti privilegije.';
@@ -279,7 +277,6 @@ $strIgnoreInserts = 'Uporabi monost prezri vstavke';
 $strIgnoringFile = 'Prezrl sem datoteko %s';
 $strImportDocSQL = 'Uvozi docSQL datoteke';
 $strImportFiles = 'Uvozi datoteke';
-$strImportFinished = 'Uvoz konan';
 $strInUse = 'v uporabi';
 $strIndex = 'Indeks';
 $strIndexHasBeenDropped = 'Indeks %s je zavren';
@@ -351,9 +348,7 @@ $strMoveTableOK = 'Tabela %s je bila premaknjena v %s.';
 $strMoveTableSameNames = 'Tabele ni mogoe premakniti same vase!';
 $strMultilingual = 'vejezino';
 $strMySQLCharset = 'MySQL kodna tabela';
-$strMySQLReloaded = 'MySQL ponovno naloen.';
 $strMySQLSaid = 'MySQL je vrnil: ';
-$strMySQLServerProcess = 'MySQL %pma_s1% tee na %pma_s2% kot %pma_s3%';
 $strMySQLShowProcess = 'Pokai procese';
 $strMySQLShowStatus = 'Pokai tekoe informacije o MySQL';
 $strMySQLShowVars = 'Pokai sistemske spremenljivke MySQL';
@@ -480,7 +475,6 @@ $strRelationView = 'Pogled relacij';
 $strRelationalSchema = 'Relacijska shema';
 $strRelations = 'Relacije';
 $strRelationsForTable = 'RELACIJE ZA TABELO';
-$strReloadFailed = 'Ponovno nalaganje MySQL ni uspelo.';
 $strReloadMySQL = 'Ponovno naloi MySQL';
 $strReloadingThePrivileges = 'Osveujem privilegije';
 $strRemoveSelectedUsers = 'Izbrii izbrane uporabnike';
@@ -800,7 +794,6 @@ $strImportFormat = 'Format of imported file';  //to translate
 $strFileToImport = 'File to import';  //to translate
 $strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
 $strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
-$strEnclosingOptional = 'Enclosing of fields is optional';  //to translate
 $strCSVImportOptions = 'CSV options';  //to translate
 $strPartialImport = 'Partial import';  //to translate
 $strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
@@ -812,7 +805,6 @@ $strNothingToImport = 'You didn\'t enter any data to import!';  //to translate
 $strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
 $strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
 $strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
-$strInvalidCSVInput = 'Invalid CSV input, could not parse!';  //to translate
 $strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
 $strErrorInZipFile = 'Error in ZIP archive:';  //to translate
 $strFlushQueryCache = 'Flush query cache';  //to translate
@@ -953,4 +945,34 @@ $strBookmarkCreated = 'Bookmark %s created';  //to translate
 $strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
 $strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
 $strEsperanto = 'Esperanto';  //to translate
+$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate
+$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
+$strFileNameTemplateDescriptionTable = 'table name';  //to translate
+$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
+$strFileNameTemplateDescriptionServer = 'server name';  //to translate
+$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
+$strProtocolVersion = 'Protocol version';  //to translate
+$strMysqlClientVersion = 'MySQL client version';  //to translate
+$strUsedPhpExtensions = 'Used PHP extensions';  //to translate
+$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
+$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
+$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
+$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
+$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
+$strPDF = 'PDF';  //to translate
+$strPDFOptions = 'PDF options';  //to translate
+$strPDFReportTitle = 'Report title';  //to translate
+$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
+$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
+$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
+$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
+$strThemeNotFound = 'Theme %s not found!';  //to translate
+$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
+$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
+$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
+$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
+$strSQLImportOptions = 'SQL options';  //to translate
+$strBrowseDistinctValues = 'Browse distinct values';  //to translate
+$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
+$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
 ?>
