@@ -1,5 +1,5 @@
 <?php
-/* $Id: ukrainian-utf-8.inc.php,v 2.95 2005/10/30 10:03:50 nijel Exp $ */
+/* $Id: ukrainian-utf-8.inc.php,v 2.117.2.3 2006/03/23 17:42:16 lem9 Exp $ */
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
@@ -180,7 +180,6 @@ $strDoAQuery = 'Виконати "запит згідно прикладу" (с
 $strDoYouReally = 'Ви насправді хочете ';
 $strDocu = 'Документація';
 $strDrop = 'Знищити';
-$strDropSelectedDatabases = 'Знищити вибрані бази даних';
 $strDropUsersDb = 'Усунути бази даних, які мають такі ж назви як імена користувачів.';
 $strDumpSaved = 'Dump збережено у файл %s.';
 $strDumpXRows = 'Зґенерувати дамп %s рядків починаючи з %s -го.';
@@ -219,7 +218,6 @@ $strFieldsTerminatedBy = 'Поля розділені';
 $strFileAlreadyExists = 'Файл %s існує на сервері, прошу змінити назву файлу, або відмітити опцію заміни існуючих файлів.';
 $strFileCouldNotBeRead = 'Неможливо прочитати файл';
 $strFileNameTemplate = 'Шаблон назви файлу';
-$strFileNameTemplateHelp = 'Використати __DB__ як назву бази даних, __TABLE__ як назву таблиці і %sдовільні strftime%s опції для визначення часової мітки, розширення будуть додані автоматично. Будь-який інший текст буде збережено.';
 $strFileNameTemplateRemember = 'запам\'ятати шаблон';
 $strFixed = 'фіксований';
 $strFlushPrivilegesNote = 'Примітка: phpMyAdmin отримує права користувачів безпосередньо з таблиці прав MySQL. Зміст цієї таблиці може відрізнятися від прав, які використовуються сервером, якщо в цю таблицю вносилися зміни вручну. У цьому випадку Вам необхідно %sперезавантажити права%s перед продовженням.';
@@ -257,7 +255,6 @@ $strIgnore = 'Ігноруровати';
 $strIgnoringFile = 'Проіґноровано файл %s';
 $strImportDocSQL = 'Імпортувати docSQL файли';
 $strImportFiles = 'Імпорт файлів';
-$strImportFinished = 'Імпорт завершено';
 $strInUse = 'використовується';
 $strIndex = 'Індекс';
 $strIndexHasBeenDropped = 'Індекс %s було знищено';
@@ -317,9 +314,7 @@ $strMoveTableOK = 'Таблицю %s було перенесено в %s.';
 $strMoveTableSameNames = 'Не можу перенести таблицю саму в себе!';
 $strMultilingual = 'багатомовні';
 $strMySQLCharset = 'MySQL Charset';
-$strMySQLReloaded = 'MySQL перезавантажено.';
 $strMySQLSaid = 'Відповідь MySQL: ';
-$strMySQLServerProcess = 'MySQL %pma_s1% на %pma_s2% як %pma_s3%';
 $strMySQLShowProcess = 'Показати процеси';
 $strMySQLShowStatus = 'Показати стан MySQL';
 $strMySQLShowVars = 'Показати системні змінні MySQL';
@@ -443,7 +438,6 @@ $strRelationNotWorking = 'Додаткова можливість роботи 
 $strRelationView = 'Перегляд залежностей';
 $strRelationalSchema = 'Схема зв\'язків';
 $strRelations = 'Зв\'язки';
-$strReloadFailed = 'Не вдалось перезавантажити MySQL.';
 $strReloadMySQL = 'Перезавантажити MySQL';
 $strReloadingThePrivileges = 'Перезавантаження прав';
 $strRemoveSelectedUsers = 'Усунути відмічених користувачів';
@@ -804,7 +798,6 @@ $strImportFormat = 'Format of imported file';  //to translate
 $strFileToImport = 'File to import';  //to translate
 $strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
 $strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
-$strEnclosingOptional = 'Enclosing of fields is optional';  //to translate
 $strCSVImportOptions = 'CSV options';  //to translate
 $strPartialImport = 'Partial import';  //to translate
 $strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
@@ -816,7 +809,6 @@ $strNothingToImport = 'You didn\'t enter any data to import!';  //to translate
 $strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
 $strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
 $strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
-$strInvalidCSVInput = 'Invalid CSV input, could not parse!';  //to translate
 $strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
 $strErrorInZipFile = 'Error in ZIP archive:';  //to translate
 $strFlushQueryCache = 'Flush query cache';  //to translate
@@ -957,4 +949,34 @@ $strBookmarkCreated = 'Bookmark %s created';  //to translate
 $strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
 $strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
 $strEsperanto = 'Esperanto';  //to translate
+$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate
+$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
+$strFileNameTemplateDescriptionTable = 'table name';  //to translate
+$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
+$strFileNameTemplateDescriptionServer = 'server name';  //to translate
+$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
+$strProtocolVersion = 'Protocol version';  //to translate
+$strMysqlClientVersion = 'MySQL client version';  //to translate
+$strUsedPhpExtensions = 'Used PHP extensions';  //to translate
+$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
+$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
+$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
+$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
+$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
+$strPDF = 'PDF';  //to translate
+$strPDFOptions = 'PDF options';  //to translate
+$strPDFReportTitle = 'Report title';  //to translate
+$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
+$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
+$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
+$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
+$strThemeNotFound = 'Theme %s not found!';  //to translate
+$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
+$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
+$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
+$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
+$strSQLImportOptions = 'SQL options';  //to translate
+$strBrowseDistinctValues = 'Browse distinct values';  //to translate
+$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
+$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
 ?>
